;;; thing-at-point-utils.el  --- more th-at-point edit functions

;; Version: 1.10

;; Copyright (C) 2006, 2007 Andreas Roehler

;; Author: Andreas Roehler <andreas.roehler@easy-emacs.de>

;; Keywords: convenience

;; This file is free software; you can redistribute it

;; and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3, or (at your option) any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; Information is given with thingatpt-utils-base.el

(require 'thingatpt-utils-base)



;;;###autoload
(defun alnum-atpt (&optional arg ispec) 
  "Returns alnum at point if any, nil otherwise"
  (interactive "P\np")
  (th 'alnum arg ispec))

(defalias 'bounds-of-alnum-atpt 'alnum-bounds-atpt)
;;;###autoload
(defun alnum-bounds-atpt (&optional arg ispec) 
  "Returns borders of alnum at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'alnum arg ispec))

;;;###autoload
(defun alnum-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'alnum arg ispec))

;;;###autoload
(defun alnum-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'alnum arg ispec))

(defalias 'beginning-of-alnum-atpt 'alnum-beginning-atpt)
;;;###autoload
(defun alnum-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'alnum arg ispec))

(defalias 'end-of-alnum-atpt 'alnum-end-atpt)
;;;###autoload
(defun alnum-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'alnum arg ispec))

(defalias 'length-of-alnum-atpt 'alnum-length-atpt)
;;;###autoload
(defun alnum-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'alnum arg ispec))

(defalias 'copy-alnum-atpt 'alnum-copy-atpt)
;;;###autoload
(defun alnum-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'alnum arg ispec))

(defalias 'escape-alnum-atpt 'alnum-escape-atpt)
;;;###autoload
(defun alnum-escape-atpt (arg) 
  "Makes a copy of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'alnum arg))

(defalias 'doublequote-alnum-atpt 'alnum-doublequote-atpt)
;;;###autoload
(defun alnum-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'alnum at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'alnum arg ispec))

(defalias 'dollar-alnum-atpt 'alnum-dollar-atpt)
;;;###autoload
(defun alnum-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'alnum at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'alnum arg ispec))

(defalias 'backslash-alnum-atpt 'alnum-backslash-atpt)
;;;###autoload
(defun alnum-backslash-atpt (&optional arg ispec) 
  "Backslash 'alnum at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'alnum arg ispec)) 

(defalias 'brace-alnum-atpt 'alnum-brace-atpt)
;;;###autoload
(defun alnum-brace-atpt (&optional arg ispec) 
  "Braces 'alnum at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'alnum arg ispec))

(defalias 'bracket-alnum-atpt 'alnum-bracket-atpt)
;;;###autoload
(defun alnum-bracket-atpt (&optional arg ispec) 
  "Brackets 'alnum after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'alnum arg ispec))

(defalias 'commented-alnum-atpt 'alnum-comment-atpt)
;;;###autoload
(defun alnum-comment-atpt (&optional arg ispec) 
  "Comments 'alnum at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'alnum arg ispec))

(defalias 'mark-alnum-atpt 'alnum-mark-atpt)
;;;###autoload
(defun alnum-mark-atpt (&optional arg) 
  "Marks 'alnum at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'alnum arg))

(defalias 'kill-alnum-atpt 'alnum-kill-atpt)
;;;###autoload
(defun alnum-kill-atpt (arg)
  "Kills alnum at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'alnum arg))

(defalias 'parentize-alnum-atpt 'alnum-parentize-atpt)
;;;###autoload
(defun alnum-parentize-atpt (&optional arg ispec) 
  "Parentizes 'alnum at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'alnum arg ispec))

(defalias 'separate-alnum-atpt 'alnum-separate-atpt)
;;;###autoload
(defun alnum-separate-atpt (&optional arg ispec) 
  "Separates 'alnum at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'alnum arg ispec))

(defalias 'singlequote-alnum-atpt 'alnum-singlequote-atpt)
;;;###autoload
(defun alnum-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'alnum at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'alnum arg ispec))

(defalias 'slash-alnum-atpt 'alnum-slash-atpt)
;;;###autoload
(defun alnum-slash-atpt (&optional arg ispec) 
  "Slash 'alnum at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'alnum arg ispec))

(defalias 'trim-alnum-atpt 'alnum-trim-atpt)
;;;###autoload
(defun alnum-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'alnum t t))

(defalias 'trim-alnum-left-atpt 'alnum-left-trim-atpt)
;;;###autoload
(defun alnum-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'alnum t nil))

(defalias 'trim-alnum-right-atpt 'alnum-right-trim-atpt)
;;;###autoload
(defun alnum-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'alnum nil t))

(defalias 'forward-alnum-atpt 'alnum-forward-atpt)
;;;###autoload
(defun alnum-forward-atpt (&optional arg ispec) 
  "Moves forward over alnum at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'alnum arg ispec))

(defalias 'backward-alnum-atpt 'alnum-backward-atpt)
;;;###autoload
(defun alnum-backward-atpt (&optional arg ispec) 
  "Moves backward over alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'alnum arg ispec))

(defalias 'transpose-alnum-atpt 'alnum-transpose-atpt)
;;;###autoload
(defun alnum-transpose-atpt (&optional arg) 
  "Transposes alnum with alnum before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'alnum arg))

(defalias 'sort-alnum-atpt 'alnum-sort-atpt)
;;;###autoload
(defun alnum-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts alnum's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'alnum reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-alnum-atpt 'alnum-check-atpt)
;;;###autoload
(defun alnum-check-atpt (&optional arg ispec) 
  " alnum at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "alnum" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "alnum" "-end-position-atpt")))))
    (th-check 'alnum arg ispec)))
   

;;;###autoload
(defun alpha-atpt (&optional arg ispec) 
  "Returns alpha at point if any, nil otherwise"
  (interactive "P\np")
  (th 'alpha arg ispec))

(defalias 'bounds-of-alpha-atpt 'alpha-bounds-atpt)
;;;###autoload
(defun alpha-bounds-atpt (&optional arg ispec) 
  "Returns borders of alpha at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'alpha arg ispec))

;;;###autoload
(defun alpha-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'alpha arg ispec))

;;;###autoload
(defun alpha-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'alpha arg ispec))

(defalias 'beginning-of-alpha-atpt 'alpha-beginning-atpt)
;;;###autoload
(defun alpha-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'alpha arg ispec))

(defalias 'end-of-alpha-atpt 'alpha-end-atpt)
;;;###autoload
(defun alpha-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'alpha arg ispec))

(defalias 'length-of-alpha-atpt 'alpha-length-atpt)
;;;###autoload
(defun alpha-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'alpha arg ispec))

(defalias 'copy-alpha-atpt 'alpha-copy-atpt)
;;;###autoload
(defun alpha-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'alpha arg ispec))

(defalias 'escape-alpha-atpt 'alpha-escape-atpt)
;;;###autoload
(defun alpha-escape-atpt (arg) 
  "Makes a copy of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'alpha arg))

(defalias 'doublequote-alpha-atpt 'alpha-doublequote-atpt)
;;;###autoload
(defun alpha-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'alpha at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'alpha arg ispec))

(defalias 'dollar-alpha-atpt 'alpha-dollar-atpt)
;;;###autoload
(defun alpha-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'alpha at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'alpha arg ispec))

(defalias 'backslash-alpha-atpt 'alpha-backslash-atpt)
;;;###autoload
(defun alpha-backslash-atpt (&optional arg ispec) 
  "Backslash 'alpha at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'alpha arg ispec)) 

(defalias 'brace-alpha-atpt 'alpha-brace-atpt)
;;;###autoload
(defun alpha-brace-atpt (&optional arg ispec) 
  "Braces 'alpha at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'alpha arg ispec))

(defalias 'bracket-alpha-atpt 'alpha-bracket-atpt)
;;;###autoload
(defun alpha-bracket-atpt (&optional arg ispec) 
  "Brackets 'alpha after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'alpha arg ispec))

(defalias 'commented-alpha-atpt 'alpha-comment-atpt)
;;;###autoload
(defun alpha-comment-atpt (&optional arg ispec) 
  "Comments 'alpha at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'alpha arg ispec))

(defalias 'mark-alpha-atpt 'alpha-mark-atpt)
;;;###autoload
(defun alpha-mark-atpt (&optional arg) 
  "Marks 'alpha at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'alpha arg))

(defalias 'kill-alpha-atpt 'alpha-kill-atpt)
;;;###autoload
(defun alpha-kill-atpt (arg)
  "Kills alpha at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'alpha arg))

(defalias 'parentize-alpha-atpt 'alpha-parentize-atpt)
;;;###autoload
(defun alpha-parentize-atpt (&optional arg ispec) 
  "Parentizes 'alpha at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'alpha arg ispec))

(defalias 'separate-alpha-atpt 'alpha-separate-atpt)
;;;###autoload
(defun alpha-separate-atpt (&optional arg ispec) 
  "Separates 'alpha at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'alpha arg ispec))

(defalias 'singlequote-alpha-atpt 'alpha-singlequote-atpt)
;;;###autoload
(defun alpha-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'alpha at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'alpha arg ispec))

(defalias 'slash-alpha-atpt 'alpha-slash-atpt)
;;;###autoload
(defun alpha-slash-atpt (&optional arg ispec) 
  "Slash 'alpha at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'alpha arg ispec))

(defalias 'trim-alpha-atpt 'alpha-trim-atpt)
;;;###autoload
(defun alpha-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'alpha t t))

(defalias 'trim-alpha-left-atpt 'alpha-left-trim-atpt)
;;;###autoload
(defun alpha-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'alpha t nil))

(defalias 'trim-alpha-right-atpt 'alpha-right-trim-atpt)
;;;###autoload
(defun alpha-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'alpha nil t))

(defalias 'forward-alpha-atpt 'alpha-forward-atpt)
;;;###autoload
(defun alpha-forward-atpt (&optional arg ispec) 
  "Moves forward over alpha at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'alpha arg ispec))

(defalias 'backward-alpha-atpt 'alpha-backward-atpt)
;;;###autoload
(defun alpha-backward-atpt (&optional arg ispec) 
  "Moves backward over alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'alpha arg ispec))

(defalias 'transpose-alpha-atpt 'alpha-transpose-atpt)
;;;###autoload
(defun alpha-transpose-atpt (&optional arg) 
  "Transposes alpha with alpha before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'alpha arg))

(defalias 'sort-alpha-atpt 'alpha-sort-atpt)
;;;###autoload
(defun alpha-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts alpha's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'alpha reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-alpha-atpt 'alpha-check-atpt)
;;;###autoload
(defun alpha-check-atpt (&optional arg ispec) 
  " alpha at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "alpha" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "alpha" "-end-position-atpt")))))
    (th-check 'alpha arg ispec)))
   

;;;###autoload
(defun ascii-atpt (&optional arg ispec) 
  "Returns ascii at point if any, nil otherwise"
  (interactive "P\np")
  (th 'ascii arg ispec))

(defalias 'bounds-of-ascii-atpt 'ascii-bounds-atpt)
;;;###autoload
(defun ascii-bounds-atpt (&optional arg ispec) 
  "Returns borders of ascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'ascii arg ispec))

;;;###autoload
(defun ascii-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'ascii arg ispec))

;;;###autoload
(defun ascii-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'ascii arg ispec))

(defalias 'beginning-of-ascii-atpt 'ascii-beginning-atpt)
;;;###autoload
(defun ascii-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'ascii arg ispec))

(defalias 'end-of-ascii-atpt 'ascii-end-atpt)
;;;###autoload
(defun ascii-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'ascii arg ispec))

(defalias 'length-of-ascii-atpt 'ascii-length-atpt)
;;;###autoload
(defun ascii-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'ascii arg ispec))

(defalias 'copy-ascii-atpt 'ascii-copy-atpt)
;;;###autoload
(defun ascii-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'ascii arg ispec))

(defalias 'escape-ascii-atpt 'ascii-escape-atpt)
;;;###autoload
(defun ascii-escape-atpt (arg) 
  "Makes a copy of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'ascii arg))

(defalias 'doublequote-ascii-atpt 'ascii-doublequote-atpt)
;;;###autoload
(defun ascii-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'ascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'ascii arg ispec))

(defalias 'dollar-ascii-atpt 'ascii-dollar-atpt)
;;;###autoload
(defun ascii-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'ascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'ascii arg ispec))

(defalias 'backslash-ascii-atpt 'ascii-backslash-atpt)
;;;###autoload
(defun ascii-backslash-atpt (&optional arg ispec) 
  "Backslash 'ascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'ascii arg ispec)) 

(defalias 'brace-ascii-atpt 'ascii-brace-atpt)
;;;###autoload
(defun ascii-brace-atpt (&optional arg ispec) 
  "Braces 'ascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'ascii arg ispec))

(defalias 'bracket-ascii-atpt 'ascii-bracket-atpt)
;;;###autoload
(defun ascii-bracket-atpt (&optional arg ispec) 
  "Brackets 'ascii after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'ascii arg ispec))

(defalias 'commented-ascii-atpt 'ascii-comment-atpt)
;;;###autoload
(defun ascii-comment-atpt (&optional arg ispec) 
  "Comments 'ascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'ascii arg ispec))

(defalias 'mark-ascii-atpt 'ascii-mark-atpt)
;;;###autoload
(defun ascii-mark-atpt (&optional arg) 
  "Marks 'ascii at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'ascii arg))

(defalias 'kill-ascii-atpt 'ascii-kill-atpt)
;;;###autoload
(defun ascii-kill-atpt (arg)
  "Kills ascii at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'ascii arg))

(defalias 'parentize-ascii-atpt 'ascii-parentize-atpt)
;;;###autoload
(defun ascii-parentize-atpt (&optional arg ispec) 
  "Parentizes 'ascii at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'ascii arg ispec))

(defalias 'separate-ascii-atpt 'ascii-separate-atpt)
;;;###autoload
(defun ascii-separate-atpt (&optional arg ispec) 
  "Separates 'ascii at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'ascii arg ispec))

(defalias 'singlequote-ascii-atpt 'ascii-singlequote-atpt)
;;;###autoload
(defun ascii-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'ascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'ascii arg ispec))

(defalias 'slash-ascii-atpt 'ascii-slash-atpt)
;;;###autoload
(defun ascii-slash-atpt (&optional arg ispec) 
  "Slash 'ascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'ascii arg ispec))

(defalias 'trim-ascii-atpt 'ascii-trim-atpt)
;;;###autoload
(defun ascii-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ascii t t))

(defalias 'trim-ascii-left-atpt 'ascii-left-trim-atpt)
;;;###autoload
(defun ascii-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ascii t nil))

(defalias 'trim-ascii-right-atpt 'ascii-right-trim-atpt)
;;;###autoload
(defun ascii-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ascii nil t))

(defalias 'forward-ascii-atpt 'ascii-forward-atpt)
;;;###autoload
(defun ascii-forward-atpt (&optional arg ispec) 
  "Moves forward over ascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'ascii arg ispec))

(defalias 'backward-ascii-atpt 'ascii-backward-atpt)
;;;###autoload
(defun ascii-backward-atpt (&optional arg ispec) 
  "Moves backward over ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'ascii arg ispec))

(defalias 'transpose-ascii-atpt 'ascii-transpose-atpt)
;;;###autoload
(defun ascii-transpose-atpt (&optional arg) 
  "Transposes ascii with ascii before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'ascii arg))

(defalias 'sort-ascii-atpt 'ascii-sort-atpt)
;;;###autoload
(defun ascii-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts ascii's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'ascii reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-ascii-atpt 'ascii-check-atpt)
;;;###autoload
(defun ascii-check-atpt (&optional arg ispec) 
  " ascii at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "ascii" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "ascii" "-end-position-atpt")))))
    (th-check 'ascii arg ispec)))
   

;;;###autoload
(defun backslashed-atpt (&optional arg ispec) 
  "Returns backslashed at point if any, nil otherwise"
  (interactive "P\np")
  (th 'backslashed arg ispec))

(defalias 'bounds-of-backslashed-atpt 'backslashed-bounds-atpt)
;;;###autoload
(defun backslashed-bounds-atpt (&optional arg ispec) 
  "Returns borders of backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'backslashed arg ispec))

;;;###autoload
(defun backslashed-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'backslashed arg ispec))

;;;###autoload
(defun backslashed-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'backslashed arg ispec))

(defalias 'beginning-of-backslashed-atpt 'backslashed-beginning-atpt)
;;;###autoload
(defun backslashed-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'backslashed arg ispec))

(defalias 'end-of-backslashed-atpt 'backslashed-end-atpt)
;;;###autoload
(defun backslashed-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'backslashed arg ispec))

(defalias 'length-of-backslashed-atpt 'backslashed-length-atpt)
;;;###autoload
(defun backslashed-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'backslashed arg ispec))

(defalias 'copy-backslashed-atpt 'backslashed-copy-atpt)
;;;###autoload
(defun backslashed-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'backslashed arg ispec))

(defalias 'escape-backslashed-atpt 'backslashed-escape-atpt)
;;;###autoload
(defun backslashed-escape-atpt (arg) 
  "Makes a copy of symbol or char-class backslashed at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'backslashed arg))

(defalias 'doublequote-backslashed-atpt 'backslashed-doublequote-atpt)
;;;###autoload
(defun backslashed-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'backslashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'backslashed arg ispec))

(defalias 'dollar-backslashed-atpt 'backslashed-dollar-atpt)
;;;###autoload
(defun backslashed-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'backslashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'backslashed arg ispec))

(defalias 'backslash-backslashed-atpt 'backslashed-backslash-atpt)
;;;###autoload
(defun backslashed-backslash-atpt (&optional arg ispec) 
  "Backslash 'backslashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'backslashed arg ispec)) 

(defalias 'brace-backslashed-atpt 'backslashed-brace-atpt)
;;;###autoload
(defun backslashed-brace-atpt (&optional arg ispec) 
  "Braces 'backslashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'backslashed arg ispec))

(defalias 'bracket-backslashed-atpt 'backslashed-bracket-atpt)
;;;###autoload
(defun backslashed-bracket-atpt (&optional arg ispec) 
  "Brackets 'backslashed after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'backslashed arg ispec))

(defalias 'commented-backslashed-atpt 'backslashed-comment-atpt)
;;;###autoload
(defun backslashed-comment-atpt (&optional arg ispec) 
  "Comments 'backslashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'backslashed arg ispec))

(defalias 'mark-backslashed-atpt 'backslashed-mark-atpt)
;;;###autoload
(defun backslashed-mark-atpt (&optional arg) 
  "Marks 'backslashed at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'backslashed arg))

(defalias 'kill-backslashed-atpt 'backslashed-kill-atpt)
;;;###autoload
(defun backslashed-kill-atpt (arg)
  "Kills backslashed at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'backslashed arg))

(defalias 'parentize-backslashed-atpt 'backslashed-parentize-atpt)
;;;###autoload
(defun backslashed-parentize-atpt (&optional arg ispec) 
  "Parentizes 'backslashed at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'backslashed arg ispec))

(defalias 'separate-backslashed-atpt 'backslashed-separate-atpt)
;;;###autoload
(defun backslashed-separate-atpt (&optional arg ispec) 
  "Separates 'backslashed at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'backslashed arg ispec))

(defalias 'singlequote-backslashed-atpt 'backslashed-singlequote-atpt)
;;;###autoload
(defun backslashed-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'backslashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'backslashed arg ispec))

(defalias 'slash-backslashed-atpt 'backslashed-slash-atpt)
;;;###autoload
(defun backslashed-slash-atpt (&optional arg ispec) 
  "Slash 'backslashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'backslashed arg ispec))

(defalias 'trim-backslashed-atpt 'backslashed-trim-atpt)
;;;###autoload
(defun backslashed-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'backslashed t t))

(defalias 'trim-backslashed-left-atpt 'backslashed-left-trim-atpt)
;;;###autoload
(defun backslashed-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'backslashed t nil))

(defalias 'trim-backslashed-right-atpt 'backslashed-right-trim-atpt)
;;;###autoload
(defun backslashed-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'backslashed nil t))

(defalias 'forward-backslashed-atpt 'backslashed-forward-atpt)
;;;###autoload
(defun backslashed-forward-atpt (&optional arg ispec) 
  "Moves forward over backslashed at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'backslashed arg ispec))

(defalias 'backward-backslashed-atpt 'backslashed-backward-atpt)
;;;###autoload
(defun backslashed-backward-atpt (&optional arg ispec) 
  "Moves backward over backslashed before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'backslashed arg ispec))

(defalias 'transpose-backslashed-atpt 'backslashed-transpose-atpt)
;;;###autoload
(defun backslashed-transpose-atpt (&optional arg) 
  "Transposes backslashed with backslashed before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'backslashed arg))

(defalias 'sort-backslashed-atpt 'backslashed-sort-atpt)
;;;###autoload
(defun backslashed-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts backslashed's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'backslashed reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-backslashed-atpt 'backslashed-check-atpt)
;;;###autoload
(defun backslashed-check-atpt (&optional arg ispec) 
  " backslashed at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "backslashed" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "backslashed" "-end-position-atpt")))))
    (th-check 'backslashed arg ispec)))
   

;;;###autoload
(defun blank-atpt (&optional arg ispec) 
  "Returns blank at point if any, nil otherwise"
  (interactive "P\np")
  (th 'blank arg ispec))

(defalias 'bounds-of-blank-atpt 'blank-bounds-atpt)
;;;###autoload
(defun blank-bounds-atpt (&optional arg ispec) 
  "Returns borders of blank at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'blank arg ispec))

;;;###autoload
(defun blank-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'blank arg ispec))

;;;###autoload
(defun blank-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'blank arg ispec))

(defalias 'beginning-of-blank-atpt 'blank-beginning-atpt)
;;;###autoload
(defun blank-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'blank arg ispec))

(defalias 'end-of-blank-atpt 'blank-end-atpt)
;;;###autoload
(defun blank-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'blank arg ispec))

(defalias 'length-of-blank-atpt 'blank-length-atpt)
;;;###autoload
(defun blank-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'blank arg ispec))

(defalias 'copy-blank-atpt 'blank-copy-atpt)
;;;###autoload
(defun blank-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'blank arg ispec))

(defalias 'escape-blank-atpt 'blank-escape-atpt)
;;;###autoload
(defun blank-escape-atpt (arg) 
  "Makes a copy of symbol or char-class blank at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'blank arg))

(defalias 'doublequote-blank-atpt 'blank-doublequote-atpt)
;;;###autoload
(defun blank-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'blank at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'blank arg ispec))

(defalias 'dollar-blank-atpt 'blank-dollar-atpt)
;;;###autoload
(defun blank-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'blank at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'blank arg ispec))

(defalias 'backslash-blank-atpt 'blank-backslash-atpt)
;;;###autoload
(defun blank-backslash-atpt (&optional arg ispec) 
  "Backslash 'blank at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'blank arg ispec)) 

(defalias 'brace-blank-atpt 'blank-brace-atpt)
;;;###autoload
(defun blank-brace-atpt (&optional arg ispec) 
  "Braces 'blank at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'blank arg ispec))

(defalias 'bracket-blank-atpt 'blank-bracket-atpt)
;;;###autoload
(defun blank-bracket-atpt (&optional arg ispec) 
  "Brackets 'blank after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'blank arg ispec))

(defalias 'commented-blank-atpt 'blank-comment-atpt)
;;;###autoload
(defun blank-comment-atpt (&optional arg ispec) 
  "Comments 'blank at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'blank arg ispec))

(defalias 'mark-blank-atpt 'blank-mark-atpt)
;;;###autoload
(defun blank-mark-atpt (&optional arg) 
  "Marks 'blank at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'blank arg))

(defalias 'kill-blank-atpt 'blank-kill-atpt)
;;;###autoload
(defun blank-kill-atpt (arg)
  "Kills blank at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'blank arg))

(defalias 'parentize-blank-atpt 'blank-parentize-atpt)
;;;###autoload
(defun blank-parentize-atpt (&optional arg ispec) 
  "Parentizes 'blank at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'blank arg ispec))

(defalias 'separate-blank-atpt 'blank-separate-atpt)
;;;###autoload
(defun blank-separate-atpt (&optional arg ispec) 
  "Separates 'blank at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'blank arg ispec))

(defalias 'singlequote-blank-atpt 'blank-singlequote-atpt)
;;;###autoload
(defun blank-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'blank at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'blank arg ispec))

(defalias 'slash-blank-atpt 'blank-slash-atpt)
;;;###autoload
(defun blank-slash-atpt (&optional arg ispec) 
  "Slash 'blank at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'blank arg ispec))

(defalias 'trim-blank-atpt 'blank-trim-atpt)
;;;###autoload
(defun blank-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'blank t t))

(defalias 'trim-blank-left-atpt 'blank-left-trim-atpt)
;;;###autoload
(defun blank-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'blank t nil))

(defalias 'trim-blank-right-atpt 'blank-right-trim-atpt)
;;;###autoload
(defun blank-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'blank nil t))

(defalias 'forward-blank-atpt 'blank-forward-atpt)
;;;###autoload
(defun blank-forward-atpt (&optional arg ispec) 
  "Moves forward over blank at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'blank arg ispec))

(defalias 'backward-blank-atpt 'blank-backward-atpt)
;;;###autoload
(defun blank-backward-atpt (&optional arg ispec) 
  "Moves backward over blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'blank arg ispec))

(defalias 'transpose-blank-atpt 'blank-transpose-atpt)
;;;###autoload
(defun blank-transpose-atpt (&optional arg) 
  "Transposes blank with blank before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'blank arg))

(defalias 'sort-blank-atpt 'blank-sort-atpt)
;;;###autoload
(defun blank-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts blank's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'blank reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-blank-atpt 'blank-check-atpt)
;;;###autoload
(defun blank-check-atpt (&optional arg ispec) 
  " blank at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "blank" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "blank" "-end-position-atpt")))))
    (th-check 'blank arg ispec)))
   

;;;###autoload
(defun braced-atpt (&optional arg ispec) 
  "Returns braced at point if any, nil otherwise"
  (interactive "P\np")
  (th 'braced arg ispec))

(defalias 'bounds-of-braced-atpt 'braced-bounds-atpt)
;;;###autoload
(defun braced-bounds-atpt (&optional arg ispec) 
  "Returns borders of braced at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'braced arg ispec))

;;;###autoload
(defun braced-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class braced at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'braced arg ispec))

;;;###autoload
(defun braced-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class braced at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'braced arg ispec))

(defalias 'beginning-of-braced-atpt 'braced-beginning-atpt)
;;;###autoload
(defun braced-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class braced at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'braced arg ispec))

(defalias 'end-of-braced-atpt 'braced-end-atpt)
;;;###autoload
(defun braced-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class braced at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'braced arg ispec))

(defalias 'length-of-braced-atpt 'braced-length-atpt)
;;;###autoload
(defun braced-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class braced at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'braced arg ispec))

(defalias 'copy-braced-atpt 'braced-copy-atpt)
;;;###autoload
(defun braced-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class braced at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'braced arg ispec))

(defalias 'escape-braced-atpt 'braced-escape-atpt)
;;;###autoload
(defun braced-escape-atpt (arg) 
  "Makes a copy of symbol or char-class braced at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'braced arg))

(defalias 'doublequote-braced-atpt 'braced-doublequote-atpt)
;;;###autoload
(defun braced-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'braced at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'braced arg ispec))

(defalias 'dollar-braced-atpt 'braced-dollar-atpt)
;;;###autoload
(defun braced-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'braced at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'braced arg ispec))

(defalias 'backslash-braced-atpt 'braced-backslash-atpt)
;;;###autoload
(defun braced-backslash-atpt (&optional arg ispec) 
  "Backslash 'braced at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'braced arg ispec)) 

(defalias 'brace-braced-atpt 'braced-brace-atpt)
;;;###autoload
(defun braced-brace-atpt (&optional arg ispec) 
  "Braces 'braced at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'braced arg ispec))

(defalias 'bracket-braced-atpt 'braced-bracket-atpt)
;;;###autoload
(defun braced-bracket-atpt (&optional arg ispec) 
  "Brackets 'braced after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'braced arg ispec))

(defalias 'commented-braced-atpt 'braced-comment-atpt)
;;;###autoload
(defun braced-comment-atpt (&optional arg ispec) 
  "Comments 'braced at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'braced arg ispec))

(defalias 'mark-braced-atpt 'braced-mark-atpt)
;;;###autoload
(defun braced-mark-atpt (&optional arg) 
  "Marks 'braced at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'braced arg))

(defalias 'kill-braced-atpt 'braced-kill-atpt)
;;;###autoload
(defun braced-kill-atpt (arg)
  "Kills braced at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'braced arg))

(defalias 'parentize-braced-atpt 'braced-parentize-atpt)
;;;###autoload
(defun braced-parentize-atpt (&optional arg ispec) 
  "Parentizes 'braced at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'braced arg ispec))

(defalias 'separate-braced-atpt 'braced-separate-atpt)
;;;###autoload
(defun braced-separate-atpt (&optional arg ispec) 
  "Separates 'braced at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'braced arg ispec))

(defalias 'singlequote-braced-atpt 'braced-singlequote-atpt)
;;;###autoload
(defun braced-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'braced at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'braced arg ispec))

(defalias 'slash-braced-atpt 'braced-slash-atpt)
;;;###autoload
(defun braced-slash-atpt (&optional arg ispec) 
  "Slash 'braced at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'braced arg ispec))

(defalias 'trim-braced-atpt 'braced-trim-atpt)
;;;###autoload
(defun braced-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'braced t t))

(defalias 'trim-braced-left-atpt 'braced-left-trim-atpt)
;;;###autoload
(defun braced-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'braced t nil))

(defalias 'trim-braced-right-atpt 'braced-right-trim-atpt)
;;;###autoload
(defun braced-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'braced nil t))

(defalias 'forward-braced-atpt 'braced-forward-atpt)
;;;###autoload
(defun braced-forward-atpt (&optional arg ispec) 
  "Moves forward over braced at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'braced arg ispec))

(defalias 'backward-braced-atpt 'braced-backward-atpt)
;;;###autoload
(defun braced-backward-atpt (&optional arg ispec) 
  "Moves backward over braced before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'braced arg ispec))

(defalias 'transpose-braced-atpt 'braced-transpose-atpt)
;;;###autoload
(defun braced-transpose-atpt (&optional arg) 
  "Transposes braced with braced before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'braced arg))

(defalias 'sort-braced-atpt 'braced-sort-atpt)
;;;###autoload
(defun braced-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts braced's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'braced reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-braced-atpt 'braced-check-atpt)
;;;###autoload
(defun braced-check-atpt (&optional arg ispec) 
  " braced at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "braced" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "braced" "-end-position-atpt")))))
    (th-check 'braced arg ispec)))
   

;;;###autoload
(defun bracketed-atpt (&optional arg ispec) 
  "Returns bracketed at point if any, nil otherwise"
  (interactive "P\np")
  (th 'bracketed arg ispec))

(defalias 'bounds-of-bracketed-atpt 'bracketed-bounds-atpt)
;;;###autoload
(defun bracketed-bounds-atpt (&optional arg ispec) 
  "Returns borders of bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'bracketed arg ispec))

;;;###autoload
(defun bracketed-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'bracketed arg ispec))

;;;###autoload
(defun bracketed-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'bracketed arg ispec))

(defalias 'beginning-of-bracketed-atpt 'bracketed-beginning-atpt)
;;;###autoload
(defun bracketed-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'bracketed arg ispec))

(defalias 'end-of-bracketed-atpt 'bracketed-end-atpt)
;;;###autoload
(defun bracketed-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'bracketed arg ispec))

(defalias 'length-of-bracketed-atpt 'bracketed-length-atpt)
;;;###autoload
(defun bracketed-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'bracketed arg ispec))

(defalias 'copy-bracketed-atpt 'bracketed-copy-atpt)
;;;###autoload
(defun bracketed-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'bracketed arg ispec))

(defalias 'escape-bracketed-atpt 'bracketed-escape-atpt)
;;;###autoload
(defun bracketed-escape-atpt (arg) 
  "Makes a copy of symbol or char-class bracketed at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'bracketed arg))

(defalias 'doublequote-bracketed-atpt 'bracketed-doublequote-atpt)
;;;###autoload
(defun bracketed-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'bracketed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'bracketed arg ispec))

(defalias 'dollar-bracketed-atpt 'bracketed-dollar-atpt)
;;;###autoload
(defun bracketed-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'bracketed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'bracketed arg ispec))

(defalias 'backslash-bracketed-atpt 'bracketed-backslash-atpt)
;;;###autoload
(defun bracketed-backslash-atpt (&optional arg ispec) 
  "Backslash 'bracketed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'bracketed arg ispec)) 

(defalias 'brace-bracketed-atpt 'bracketed-brace-atpt)
;;;###autoload
(defun bracketed-brace-atpt (&optional arg ispec) 
  "Braces 'bracketed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'bracketed arg ispec))

(defalias 'bracket-bracketed-atpt 'bracketed-bracket-atpt)
;;;###autoload
(defun bracketed-bracket-atpt (&optional arg ispec) 
  "Brackets 'bracketed after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'bracketed arg ispec))

(defalias 'commented-bracketed-atpt 'bracketed-comment-atpt)
;;;###autoload
(defun bracketed-comment-atpt (&optional arg ispec) 
  "Comments 'bracketed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'bracketed arg ispec))

(defalias 'mark-bracketed-atpt 'bracketed-mark-atpt)
;;;###autoload
(defun bracketed-mark-atpt (&optional arg) 
  "Marks 'bracketed at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'bracketed arg))

(defalias 'kill-bracketed-atpt 'bracketed-kill-atpt)
;;;###autoload
(defun bracketed-kill-atpt (arg)
  "Kills bracketed at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'bracketed arg))

(defalias 'parentize-bracketed-atpt 'bracketed-parentize-atpt)
;;;###autoload
(defun bracketed-parentize-atpt (&optional arg ispec) 
  "Parentizes 'bracketed at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'bracketed arg ispec))

(defalias 'separate-bracketed-atpt 'bracketed-separate-atpt)
;;;###autoload
(defun bracketed-separate-atpt (&optional arg ispec) 
  "Separates 'bracketed at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'bracketed arg ispec))

(defalias 'singlequote-bracketed-atpt 'bracketed-singlequote-atpt)
;;;###autoload
(defun bracketed-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'bracketed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'bracketed arg ispec))

(defalias 'slash-bracketed-atpt 'bracketed-slash-atpt)
;;;###autoload
(defun bracketed-slash-atpt (&optional arg ispec) 
  "Slash 'bracketed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'bracketed arg ispec))

(defalias 'trim-bracketed-atpt 'bracketed-trim-atpt)
;;;###autoload
(defun bracketed-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'bracketed t t))

(defalias 'trim-bracketed-left-atpt 'bracketed-left-trim-atpt)
;;;###autoload
(defun bracketed-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'bracketed t nil))

(defalias 'trim-bracketed-right-atpt 'bracketed-right-trim-atpt)
;;;###autoload
(defun bracketed-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'bracketed nil t))

(defalias 'forward-bracketed-atpt 'bracketed-forward-atpt)
;;;###autoload
(defun bracketed-forward-atpt (&optional arg ispec) 
  "Moves forward over bracketed at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'bracketed arg ispec))

(defalias 'backward-bracketed-atpt 'bracketed-backward-atpt)
;;;###autoload
(defun bracketed-backward-atpt (&optional arg ispec) 
  "Moves backward over bracketed before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'bracketed arg ispec))

(defalias 'transpose-bracketed-atpt 'bracketed-transpose-atpt)
;;;###autoload
(defun bracketed-transpose-atpt (&optional arg) 
  "Transposes bracketed with bracketed before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'bracketed arg))

(defalias 'sort-bracketed-atpt 'bracketed-sort-atpt)
;;;###autoload
(defun bracketed-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts bracketed's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'bracketed reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-bracketed-atpt 'bracketed-check-atpt)
;;;###autoload
(defun bracketed-check-atpt (&optional arg ispec) 
  " bracketed at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "bracketed" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "bracketed" "-end-position-atpt")))))
    (th-check 'bracketed arg ispec)))
   

;;;###autoload
(defun cntrl-atpt (&optional arg ispec) 
  "Returns cntrl at point if any, nil otherwise"
  (interactive "P\np")
  (th 'cntrl arg ispec))

(defalias 'bounds-of-cntrl-atpt 'cntrl-bounds-atpt)
;;;###autoload
(defun cntrl-bounds-atpt (&optional arg ispec) 
  "Returns borders of cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'cntrl arg ispec))

;;;###autoload
(defun cntrl-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'cntrl arg ispec))

;;;###autoload
(defun cntrl-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'cntrl arg ispec))

(defalias 'beginning-of-cntrl-atpt 'cntrl-beginning-atpt)
;;;###autoload
(defun cntrl-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'cntrl arg ispec))

(defalias 'end-of-cntrl-atpt 'cntrl-end-atpt)
;;;###autoload
(defun cntrl-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'cntrl arg ispec))

(defalias 'length-of-cntrl-atpt 'cntrl-length-atpt)
;;;###autoload
(defun cntrl-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'cntrl arg ispec))

(defalias 'copy-cntrl-atpt 'cntrl-copy-atpt)
;;;###autoload
(defun cntrl-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'cntrl arg ispec))

(defalias 'escape-cntrl-atpt 'cntrl-escape-atpt)
;;;###autoload
(defun cntrl-escape-atpt (arg) 
  "Makes a copy of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'cntrl arg))

(defalias 'doublequote-cntrl-atpt 'cntrl-doublequote-atpt)
;;;###autoload
(defun cntrl-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'cntrl at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'cntrl arg ispec))

(defalias 'dollar-cntrl-atpt 'cntrl-dollar-atpt)
;;;###autoload
(defun cntrl-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'cntrl at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'cntrl arg ispec))

(defalias 'backslash-cntrl-atpt 'cntrl-backslash-atpt)
;;;###autoload
(defun cntrl-backslash-atpt (&optional arg ispec) 
  "Backslash 'cntrl at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'cntrl arg ispec)) 

(defalias 'brace-cntrl-atpt 'cntrl-brace-atpt)
;;;###autoload
(defun cntrl-brace-atpt (&optional arg ispec) 
  "Braces 'cntrl at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'cntrl arg ispec))

(defalias 'bracket-cntrl-atpt 'cntrl-bracket-atpt)
;;;###autoload
(defun cntrl-bracket-atpt (&optional arg ispec) 
  "Brackets 'cntrl after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'cntrl arg ispec))

(defalias 'commented-cntrl-atpt 'cntrl-comment-atpt)
;;;###autoload
(defun cntrl-comment-atpt (&optional arg ispec) 
  "Comments 'cntrl at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'cntrl arg ispec))

(defalias 'mark-cntrl-atpt 'cntrl-mark-atpt)
;;;###autoload
(defun cntrl-mark-atpt (&optional arg) 
  "Marks 'cntrl at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'cntrl arg))

(defalias 'kill-cntrl-atpt 'cntrl-kill-atpt)
;;;###autoload
(defun cntrl-kill-atpt (arg)
  "Kills cntrl at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'cntrl arg))

(defalias 'parentize-cntrl-atpt 'cntrl-parentize-atpt)
;;;###autoload
(defun cntrl-parentize-atpt (&optional arg ispec) 
  "Parentizes 'cntrl at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'cntrl arg ispec))

(defalias 'separate-cntrl-atpt 'cntrl-separate-atpt)
;;;###autoload
(defun cntrl-separate-atpt (&optional arg ispec) 
  "Separates 'cntrl at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'cntrl arg ispec))

(defalias 'singlequote-cntrl-atpt 'cntrl-singlequote-atpt)
;;;###autoload
(defun cntrl-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'cntrl at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'cntrl arg ispec))

(defalias 'slash-cntrl-atpt 'cntrl-slash-atpt)
;;;###autoload
(defun cntrl-slash-atpt (&optional arg ispec) 
  "Slash 'cntrl at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'cntrl arg ispec))

(defalias 'trim-cntrl-atpt 'cntrl-trim-atpt)
;;;###autoload
(defun cntrl-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'cntrl t t))

(defalias 'trim-cntrl-left-atpt 'cntrl-left-trim-atpt)
;;;###autoload
(defun cntrl-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'cntrl t nil))

(defalias 'trim-cntrl-right-atpt 'cntrl-right-trim-atpt)
;;;###autoload
(defun cntrl-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'cntrl nil t))

(defalias 'forward-cntrl-atpt 'cntrl-forward-atpt)
;;;###autoload
(defun cntrl-forward-atpt (&optional arg ispec) 
  "Moves forward over cntrl at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'cntrl arg ispec))

(defalias 'backward-cntrl-atpt 'cntrl-backward-atpt)
;;;###autoload
(defun cntrl-backward-atpt (&optional arg ispec) 
  "Moves backward over cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'cntrl arg ispec))

(defalias 'transpose-cntrl-atpt 'cntrl-transpose-atpt)
;;;###autoload
(defun cntrl-transpose-atpt (&optional arg) 
  "Transposes cntrl with cntrl before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'cntrl arg))

(defalias 'sort-cntrl-atpt 'cntrl-sort-atpt)
;;;###autoload
(defun cntrl-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts cntrl's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'cntrl reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-cntrl-atpt 'cntrl-check-atpt)
;;;###autoload
(defun cntrl-check-atpt (&optional arg ispec) 
  " cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "cntrl" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "cntrl" "-end-position-atpt")))))
    (th-check 'cntrl arg ispec)))
   

;;;###autoload
(defun comment-atpt (&optional arg ispec) 
  "Returns comment at point if any, nil otherwise"
  (interactive "P\np")
  (th 'comment arg ispec))

(defalias 'bounds-of-comment-atpt 'comment-bounds-atpt)
;;;###autoload
(defun comment-bounds-atpt (&optional arg ispec) 
  "Returns borders of comment at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'comment arg ispec))

;;;###autoload
(defun comment-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class comment at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'comment arg ispec))

;;;###autoload
(defun comment-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class comment at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'comment arg ispec))

(defalias 'beginning-of-comment-atpt 'comment-beginning-atpt)
;;;###autoload
(defun comment-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class comment at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'comment arg ispec))

(defalias 'end-of-comment-atpt 'comment-end-atpt)
;;;###autoload
(defun comment-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class comment at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'comment arg ispec))

(defalias 'length-of-comment-atpt 'comment-length-atpt)
;;;###autoload
(defun comment-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class comment at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'comment arg ispec))

(defalias 'copy-comment-atpt 'comment-copy-atpt)
;;;###autoload
(defun comment-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class comment at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'comment arg ispec))

(defalias 'escape-comment-atpt 'comment-escape-atpt)
;;;###autoload
(defun comment-escape-atpt (arg) 
  "Makes a copy of symbol or char-class comment at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'comment arg))

(defalias 'doublequote-comment-atpt 'comment-doublequote-atpt)
;;;###autoload
(defun comment-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'comment at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'comment arg ispec))

(defalias 'dollar-comment-atpt 'comment-dollar-atpt)
;;;###autoload
(defun comment-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'comment at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'comment arg ispec))

(defalias 'backslash-comment-atpt 'comment-backslash-atpt)
;;;###autoload
(defun comment-backslash-atpt (&optional arg ispec) 
  "Backslash 'comment at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'comment arg ispec)) 

(defalias 'brace-comment-atpt 'comment-brace-atpt)
;;;###autoload
(defun comment-brace-atpt (&optional arg ispec) 
  "Braces 'comment at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'comment arg ispec))

(defalias 'bracket-comment-atpt 'comment-bracket-atpt)
;;;###autoload
(defun comment-bracket-atpt (&optional arg ispec) 
  "Brackets 'comment after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'comment arg ispec))

(defalias 'commented-comment-atpt 'comment-comment-atpt)
;;;###autoload
(defun comment-comment-atpt (&optional arg ispec) 
  "Comments 'comment at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'comment arg ispec))

(defalias 'mark-comment-atpt 'comment-mark-atpt)
;;;###autoload
(defun comment-mark-atpt (&optional arg) 
  "Marks 'comment at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'comment arg))

(defalias 'kill-comment-atpt 'comment-kill-atpt)
;;;###autoload
(defun comment-kill-atpt (arg)
  "Kills comment at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'comment arg))

(defalias 'parentize-comment-atpt 'comment-parentize-atpt)
;;;###autoload
(defun comment-parentize-atpt (&optional arg ispec) 
  "Parentizes 'comment at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'comment arg ispec))

(defalias 'separate-comment-atpt 'comment-separate-atpt)
;;;###autoload
(defun comment-separate-atpt (&optional arg ispec) 
  "Separates 'comment at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'comment arg ispec))

(defalias 'singlequote-comment-atpt 'comment-singlequote-atpt)
;;;###autoload
(defun comment-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'comment at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'comment arg ispec))

(defalias 'slash-comment-atpt 'comment-slash-atpt)
;;;###autoload
(defun comment-slash-atpt (&optional arg ispec) 
  "Slash 'comment at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'comment arg ispec))

(defalias 'trim-comment-atpt 'comment-trim-atpt)
;;;###autoload
(defun comment-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'comment t t))

(defalias 'trim-comment-left-atpt 'comment-left-trim-atpt)
;;;###autoload
(defun comment-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'comment t nil))

(defalias 'trim-comment-right-atpt 'comment-right-trim-atpt)
;;;###autoload
(defun comment-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'comment nil t))

(defalias 'forward-comment-atpt 'comment-forward-atpt)
;;;###autoload
(defun comment-forward-atpt (&optional arg ispec) 
  "Moves forward over comment at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'comment arg ispec))

(defalias 'backward-comment-atpt 'comment-backward-atpt)
;;;###autoload
(defun comment-backward-atpt (&optional arg ispec) 
  "Moves backward over comment before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'comment arg ispec))

(defalias 'transpose-comment-atpt 'comment-transpose-atpt)
;;;###autoload
(defun comment-transpose-atpt (&optional arg) 
  "Transposes comment with comment before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'comment arg))

(defalias 'sort-comment-atpt 'comment-sort-atpt)
;;;###autoload
(defun comment-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts comment's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'comment reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-comment-atpt 'comment-check-atpt)
;;;###autoload
(defun comment-check-atpt (&optional arg ispec) 
  " comment at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "comment" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "comment" "-end-position-atpt")))))
    (th-check 'comment arg ispec)))
   

;;;###autoload
(defun csv-atpt (&optional arg ispec) 
  "Returns csv at point if any, nil otherwise"
  (interactive "P\np")
  (th 'csv arg ispec))

(defalias 'bounds-of-csv-atpt 'csv-bounds-atpt)
;;;###autoload
(defun csv-bounds-atpt (&optional arg ispec) 
  "Returns borders of csv at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'csv arg ispec))

;;;###autoload
(defun csv-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'csv arg ispec))

;;;###autoload
(defun csv-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'csv arg ispec))

(defalias 'beginning-of-csv-atpt 'csv-beginning-atpt)
;;;###autoload
(defun csv-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'csv arg ispec))

(defalias 'end-of-csv-atpt 'csv-end-atpt)
;;;###autoload
(defun csv-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'csv arg ispec))

(defalias 'length-of-csv-atpt 'csv-length-atpt)
;;;###autoload
(defun csv-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'csv arg ispec))

(defalias 'copy-csv-atpt 'csv-copy-atpt)
;;;###autoload
(defun csv-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'csv arg ispec))

(defalias 'escape-csv-atpt 'csv-escape-atpt)
;;;###autoload
(defun csv-escape-atpt (arg) 
  "Makes a copy of symbol or char-class csv at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'csv arg))

(defalias 'doublequote-csv-atpt 'csv-doublequote-atpt)
;;;###autoload
(defun csv-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'csv at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'csv arg ispec))

(defalias 'dollar-csv-atpt 'csv-dollar-atpt)
;;;###autoload
(defun csv-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'csv at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'csv arg ispec))

(defalias 'backslash-csv-atpt 'csv-backslash-atpt)
;;;###autoload
(defun csv-backslash-atpt (&optional arg ispec) 
  "Backslash 'csv at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'csv arg ispec)) 

(defalias 'brace-csv-atpt 'csv-brace-atpt)
;;;###autoload
(defun csv-brace-atpt (&optional arg ispec) 
  "Braces 'csv at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'csv arg ispec))

(defalias 'bracket-csv-atpt 'csv-bracket-atpt)
;;;###autoload
(defun csv-bracket-atpt (&optional arg ispec) 
  "Brackets 'csv after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'csv arg ispec))

(defalias 'commented-csv-atpt 'csv-comment-atpt)
;;;###autoload
(defun csv-comment-atpt (&optional arg ispec) 
  "Comments 'csv at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'csv arg ispec))

(defalias 'mark-csv-atpt 'csv-mark-atpt)
;;;###autoload
(defun csv-mark-atpt (&optional arg) 
  "Marks 'csv at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'csv arg))

(defalias 'kill-csv-atpt 'csv-kill-atpt)
;;;###autoload
(defun csv-kill-atpt (arg)
  "Kills csv at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'csv arg))

(defalias 'parentize-csv-atpt 'csv-parentize-atpt)
;;;###autoload
(defun csv-parentize-atpt (&optional arg ispec) 
  "Parentizes 'csv at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'csv arg ispec))

(defalias 'separate-csv-atpt 'csv-separate-atpt)
;;;###autoload
(defun csv-separate-atpt (&optional arg ispec) 
  "Separates 'csv at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'csv arg ispec))

(defalias 'singlequote-csv-atpt 'csv-singlequote-atpt)
;;;###autoload
(defun csv-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'csv at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'csv arg ispec))

(defalias 'slash-csv-atpt 'csv-slash-atpt)
;;;###autoload
(defun csv-slash-atpt (&optional arg ispec) 
  "Slash 'csv at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'csv arg ispec))

(defalias 'trim-csv-atpt 'csv-trim-atpt)
;;;###autoload
(defun csv-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'csv t t))

(defalias 'trim-csv-left-atpt 'csv-left-trim-atpt)
;;;###autoload
(defun csv-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'csv t nil))

(defalias 'trim-csv-right-atpt 'csv-right-trim-atpt)
;;;###autoload
(defun csv-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'csv nil t))

(defalias 'forward-csv-atpt 'csv-forward-atpt)
;;;###autoload
(defun csv-forward-atpt (&optional arg ispec) 
  "Moves forward over csv at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'csv arg ispec))

(defalias 'backward-csv-atpt 'csv-backward-atpt)
;;;###autoload
(defun csv-backward-atpt (&optional arg ispec) 
  "Moves backward over csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'csv arg ispec))

(defalias 'transpose-csv-atpt 'csv-transpose-atpt)
;;;###autoload
(defun csv-transpose-atpt (&optional arg) 
  "Transposes csv with csv before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'csv arg))

(defalias 'sort-csv-atpt 'csv-sort-atpt)
;;;###autoload
(defun csv-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts csv's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'csv reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-csv-atpt 'csv-check-atpt)
;;;###autoload
(defun csv-check-atpt (&optional arg ispec) 
  " csv at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "csv" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "csv" "-end-position-atpt")))))
    (th-check 'csv arg ispec)))
   

;;;###autoload
(defun date-atpt (&optional arg ispec) 
  "Returns date at point if any, nil otherwise"
  (interactive "P\np")
  (th 'date arg ispec))

(defalias 'bounds-of-date-atpt 'date-bounds-atpt)
;;;###autoload
(defun date-bounds-atpt (&optional arg ispec) 
  "Returns borders of date at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'date arg ispec))

;;;###autoload
(defun date-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'date arg ispec))

;;;###autoload
(defun date-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'date arg ispec))

(defalias 'beginning-of-date-atpt 'date-beginning-atpt)
;;;###autoload
(defun date-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'date arg ispec))

(defalias 'end-of-date-atpt 'date-end-atpt)
;;;###autoload
(defun date-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'date arg ispec))

(defalias 'length-of-date-atpt 'date-length-atpt)
;;;###autoload
(defun date-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'date arg ispec))

(defalias 'copy-date-atpt 'date-copy-atpt)
;;;###autoload
(defun date-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'date arg ispec))

(defalias 'escape-date-atpt 'date-escape-atpt)
;;;###autoload
(defun date-escape-atpt (arg) 
  "Makes a copy of symbol or char-class date at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'date arg))

(defalias 'doublequote-date-atpt 'date-doublequote-atpt)
;;;###autoload
(defun date-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'date at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'date arg ispec))

(defalias 'dollar-date-atpt 'date-dollar-atpt)
;;;###autoload
(defun date-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'date at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'date arg ispec))

(defalias 'backslash-date-atpt 'date-backslash-atpt)
;;;###autoload
(defun date-backslash-atpt (&optional arg ispec) 
  "Backslash 'date at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'date arg ispec)) 

(defalias 'brace-date-atpt 'date-brace-atpt)
;;;###autoload
(defun date-brace-atpt (&optional arg ispec) 
  "Braces 'date at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'date arg ispec))

(defalias 'bracket-date-atpt 'date-bracket-atpt)
;;;###autoload
(defun date-bracket-atpt (&optional arg ispec) 
  "Brackets 'date after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'date arg ispec))

(defalias 'commented-date-atpt 'date-comment-atpt)
;;;###autoload
(defun date-comment-atpt (&optional arg ispec) 
  "Comments 'date at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'date arg ispec))

(defalias 'mark-date-atpt 'date-mark-atpt)
;;;###autoload
(defun date-mark-atpt (&optional arg) 
  "Marks 'date at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'date arg))

(defalias 'kill-date-atpt 'date-kill-atpt)
;;;###autoload
(defun date-kill-atpt (arg)
  "Kills date at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'date arg))

(defalias 'parentize-date-atpt 'date-parentize-atpt)
;;;###autoload
(defun date-parentize-atpt (&optional arg ispec) 
  "Parentizes 'date at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'date arg ispec))

(defalias 'separate-date-atpt 'date-separate-atpt)
;;;###autoload
(defun date-separate-atpt (&optional arg ispec) 
  "Separates 'date at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'date arg ispec))

(defalias 'singlequote-date-atpt 'date-singlequote-atpt)
;;;###autoload
(defun date-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'date at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'date arg ispec))

(defalias 'slash-date-atpt 'date-slash-atpt)
;;;###autoload
(defun date-slash-atpt (&optional arg ispec) 
  "Slash 'date at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'date arg ispec))

(defalias 'trim-date-atpt 'date-trim-atpt)
;;;###autoload
(defun date-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'date t t))

(defalias 'trim-date-left-atpt 'date-left-trim-atpt)
;;;###autoload
(defun date-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'date t nil))

(defalias 'trim-date-right-atpt 'date-right-trim-atpt)
;;;###autoload
(defun date-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'date nil t))

(defalias 'forward-date-atpt 'date-forward-atpt)
;;;###autoload
(defun date-forward-atpt (&optional arg ispec) 
  "Moves forward over date at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'date arg ispec))

(defalias 'backward-date-atpt 'date-backward-atpt)
;;;###autoload
(defun date-backward-atpt (&optional arg ispec) 
  "Moves backward over date before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'date arg ispec))

(defalias 'transpose-date-atpt 'date-transpose-atpt)
;;;###autoload
(defun date-transpose-atpt (&optional arg) 
  "Transposes date with date before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'date arg))

(defalias 'sort-date-atpt 'date-sort-atpt)
;;;###autoload
(defun date-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts date's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'date reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-date-atpt 'date-check-atpt)
;;;###autoload
(defun date-check-atpt (&optional arg ispec) 
  " date at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "date" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "date" "-end-position-atpt")))))
    (th-check 'date arg ispec)))
   

;;;###autoload
(defun defun-atpt (&optional arg ispec) 
  "Returns defun at point if any, nil otherwise"
  (interactive "P\np")
  (th 'defun arg ispec))

(defalias 'bounds-of-defun-atpt 'defun-bounds-atpt)
;;;###autoload
(defun defun-bounds-atpt (&optional arg ispec) 
  "Returns borders of defun at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'defun arg ispec))

;;;###autoload
(defun defun-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'defun arg ispec))

;;;###autoload
(defun defun-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'defun arg ispec))

(defalias 'beginning-of-defun-atpt 'defun-beginning-atpt)
;;;###autoload
(defun defun-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'defun arg ispec))

(defalias 'end-of-defun-atpt 'defun-end-atpt)
;;;###autoload
(defun defun-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'defun arg ispec))

(defalias 'length-of-defun-atpt 'defun-length-atpt)
;;;###autoload
(defun defun-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'defun arg ispec))

(defalias 'copy-defun-atpt 'defun-copy-atpt)
;;;###autoload
(defun defun-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'defun arg ispec))

(defalias 'escape-defun-atpt 'defun-escape-atpt)
;;;###autoload
(defun defun-escape-atpt (arg) 
  "Makes a copy of symbol or char-class defun at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'defun arg))

(defalias 'doublequote-defun-atpt 'defun-doublequote-atpt)
;;;###autoload
(defun defun-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'defun at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'defun arg ispec))

(defalias 'dollar-defun-atpt 'defun-dollar-atpt)
;;;###autoload
(defun defun-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'defun at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'defun arg ispec))

(defalias 'backslash-defun-atpt 'defun-backslash-atpt)
;;;###autoload
(defun defun-backslash-atpt (&optional arg ispec) 
  "Backslash 'defun at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'defun arg ispec)) 

(defalias 'brace-defun-atpt 'defun-brace-atpt)
;;;###autoload
(defun defun-brace-atpt (&optional arg ispec) 
  "Braces 'defun at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'defun arg ispec))

(defalias 'bracket-defun-atpt 'defun-bracket-atpt)
;;;###autoload
(defun defun-bracket-atpt (&optional arg ispec) 
  "Brackets 'defun after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'defun arg ispec))

(defalias 'commented-defun-atpt 'defun-comment-atpt)
;;;###autoload
(defun defun-comment-atpt (&optional arg ispec) 
  "Comments 'defun at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'defun arg ispec))

(defalias 'mark-defun-atpt 'defun-mark-atpt)
;;;###autoload
(defun defun-mark-atpt (&optional arg) 
  "Marks 'defun at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'defun arg))

(defalias 'kill-defun-atpt 'defun-kill-atpt)
;;;###autoload
(defun defun-kill-atpt (arg)
  "Kills defun at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'defun arg))

(defalias 'parentize-defun-atpt 'defun-parentize-atpt)
;;;###autoload
(defun defun-parentize-atpt (&optional arg ispec) 
  "Parentizes 'defun at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'defun arg ispec))

(defalias 'separate-defun-atpt 'defun-separate-atpt)
;;;###autoload
(defun defun-separate-atpt (&optional arg ispec) 
  "Separates 'defun at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'defun arg ispec))

(defalias 'singlequote-defun-atpt 'defun-singlequote-atpt)
;;;###autoload
(defun defun-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'defun at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'defun arg ispec))

(defalias 'slash-defun-atpt 'defun-slash-atpt)
;;;###autoload
(defun defun-slash-atpt (&optional arg ispec) 
  "Slash 'defun at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'defun arg ispec))

(defalias 'trim-defun-atpt 'defun-trim-atpt)
;;;###autoload
(defun defun-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'defun t t))

(defalias 'trim-defun-left-atpt 'defun-left-trim-atpt)
;;;###autoload
(defun defun-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'defun t nil))

(defalias 'trim-defun-right-atpt 'defun-right-trim-atpt)
;;;###autoload
(defun defun-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'defun nil t))

(defalias 'forward-defun-atpt 'defun-forward-atpt)
;;;###autoload
(defun defun-forward-atpt (&optional arg ispec) 
  "Moves forward over defun at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'defun arg ispec))

(defalias 'backward-defun-atpt 'defun-backward-atpt)
;;;###autoload
(defun defun-backward-atpt (&optional arg ispec) 
  "Moves backward over defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'defun arg ispec))

(defalias 'transpose-defun-atpt 'defun-transpose-atpt)
;;;###autoload
(defun defun-transpose-atpt (&optional arg) 
  "Transposes defun with defun before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'defun arg))

(defalias 'sort-defun-atpt 'defun-sort-atpt)
;;;###autoload
(defun defun-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts defun's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'defun reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-defun-atpt 'defun-check-atpt)
;;;###autoload
(defun defun-check-atpt (&optional arg ispec) 
  " defun at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "defun" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "defun" "-end-position-atpt")))))
    (th-check 'defun arg ispec)))
   

;;;###autoload
(defun delimited-atpt (&optional arg ispec) 
  "Returns delimited at point if any, nil otherwise"
  (interactive "P\np")
  (th 'delimited arg ispec))

(defalias 'bounds-of-delimited-atpt 'delimited-bounds-atpt)
;;;###autoload
(defun delimited-bounds-atpt (&optional arg ispec) 
  "Returns borders of delimited at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'delimited arg ispec))

;;;###autoload
(defun delimited-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'delimited arg ispec))

;;;###autoload
(defun delimited-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'delimited arg ispec))

(defalias 'beginning-of-delimited-atpt 'delimited-beginning-atpt)
;;;###autoload
(defun delimited-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'delimited arg ispec))

(defalias 'end-of-delimited-atpt 'delimited-end-atpt)
;;;###autoload
(defun delimited-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'delimited arg ispec))

(defalias 'length-of-delimited-atpt 'delimited-length-atpt)
;;;###autoload
(defun delimited-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'delimited arg ispec))

(defalias 'copy-delimited-atpt 'delimited-copy-atpt)
;;;###autoload
(defun delimited-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'delimited arg ispec))

(defalias 'escape-delimited-atpt 'delimited-escape-atpt)
;;;###autoload
(defun delimited-escape-atpt (arg) 
  "Makes a copy of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'delimited arg))

(defalias 'doublequote-delimited-atpt 'delimited-doublequote-atpt)
;;;###autoload
(defun delimited-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'delimited at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'delimited arg ispec))

(defalias 'dollar-delimited-atpt 'delimited-dollar-atpt)
;;;###autoload
(defun delimited-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'delimited at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'delimited arg ispec))

(defalias 'backslash-delimited-atpt 'delimited-backslash-atpt)
;;;###autoload
(defun delimited-backslash-atpt (&optional arg ispec) 
  "Backslash 'delimited at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'delimited arg ispec)) 

(defalias 'brace-delimited-atpt 'delimited-brace-atpt)
;;;###autoload
(defun delimited-brace-atpt (&optional arg ispec) 
  "Braces 'delimited at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'delimited arg ispec))

(defalias 'bracket-delimited-atpt 'delimited-bracket-atpt)
;;;###autoload
(defun delimited-bracket-atpt (&optional arg ispec) 
  "Brackets 'delimited after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'delimited arg ispec))

(defalias 'commented-delimited-atpt 'delimited-comment-atpt)
;;;###autoload
(defun delimited-comment-atpt (&optional arg ispec) 
  "Comments 'delimited at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'delimited arg ispec))

(defalias 'mark-delimited-atpt 'delimited-mark-atpt)
;;;###autoload
(defun delimited-mark-atpt (&optional arg) 
  "Marks 'delimited at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'delimited arg))

(defalias 'kill-delimited-atpt 'delimited-kill-atpt)
;;;###autoload
(defun delimited-kill-atpt (arg)
  "Kills delimited at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'delimited arg))

(defalias 'parentize-delimited-atpt 'delimited-parentize-atpt)
;;;###autoload
(defun delimited-parentize-atpt (&optional arg ispec) 
  "Parentizes 'delimited at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'delimited arg ispec))

(defalias 'separate-delimited-atpt 'delimited-separate-atpt)
;;;###autoload
(defun delimited-separate-atpt (&optional arg ispec) 
  "Separates 'delimited at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'delimited arg ispec))

(defalias 'singlequote-delimited-atpt 'delimited-singlequote-atpt)
;;;###autoload
(defun delimited-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'delimited at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'delimited arg ispec))

(defalias 'slash-delimited-atpt 'delimited-slash-atpt)
;;;###autoload
(defun delimited-slash-atpt (&optional arg ispec) 
  "Slash 'delimited at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'delimited arg ispec))

(defalias 'trim-delimited-atpt 'delimited-trim-atpt)
;;;###autoload
(defun delimited-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'delimited t t))

(defalias 'trim-delimited-left-atpt 'delimited-left-trim-atpt)
;;;###autoload
(defun delimited-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'delimited t nil))

(defalias 'trim-delimited-right-atpt 'delimited-right-trim-atpt)
;;;###autoload
(defun delimited-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'delimited nil t))

(defalias 'forward-delimited-atpt 'delimited-forward-atpt)
;;;###autoload
(defun delimited-forward-atpt (&optional arg ispec) 
  "Moves forward over delimited at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'delimited arg ispec))

(defalias 'backward-delimited-atpt 'delimited-backward-atpt)
;;;###autoload
(defun delimited-backward-atpt (&optional arg ispec) 
  "Moves backward over delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'delimited arg ispec))

(defalias 'transpose-delimited-atpt 'delimited-transpose-atpt)
;;;###autoload
(defun delimited-transpose-atpt (&optional arg) 
  "Transposes delimited with delimited before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'delimited arg))

(defalias 'sort-delimited-atpt 'delimited-sort-atpt)
;;;###autoload
(defun delimited-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts delimited's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'delimited reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-delimited-atpt 'delimited-check-atpt)
;;;###autoload
(defun delimited-check-atpt (&optional arg ispec) 
  " delimited at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "delimited" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "delimited" "-end-position-atpt")))))
    (th-check 'delimited arg ispec)))
   

;;;###autoload
(defun digit-atpt (&optional arg ispec) 
  "Returns digit at point if any, nil otherwise"
  (interactive "P\np")
  (th 'digit arg ispec))

(defalias 'bounds-of-digit-atpt 'digit-bounds-atpt)
;;;###autoload
(defun digit-bounds-atpt (&optional arg ispec) 
  "Returns borders of digit at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'digit arg ispec))

;;;###autoload
(defun digit-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'digit arg ispec))

;;;###autoload
(defun digit-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'digit arg ispec))

(defalias 'beginning-of-digit-atpt 'digit-beginning-atpt)
;;;###autoload
(defun digit-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'digit arg ispec))

(defalias 'end-of-digit-atpt 'digit-end-atpt)
;;;###autoload
(defun digit-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'digit arg ispec))

(defalias 'length-of-digit-atpt 'digit-length-atpt)
;;;###autoload
(defun digit-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'digit arg ispec))

(defalias 'copy-digit-atpt 'digit-copy-atpt)
;;;###autoload
(defun digit-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'digit arg ispec))

(defalias 'escape-digit-atpt 'digit-escape-atpt)
;;;###autoload
(defun digit-escape-atpt (arg) 
  "Makes a copy of symbol or char-class digit at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'digit arg))

(defalias 'doublequote-digit-atpt 'digit-doublequote-atpt)
;;;###autoload
(defun digit-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'digit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'digit arg ispec))

(defalias 'dollar-digit-atpt 'digit-dollar-atpt)
;;;###autoload
(defun digit-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'digit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'digit arg ispec))

(defalias 'backslash-digit-atpt 'digit-backslash-atpt)
;;;###autoload
(defun digit-backslash-atpt (&optional arg ispec) 
  "Backslash 'digit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'digit arg ispec)) 

(defalias 'brace-digit-atpt 'digit-brace-atpt)
;;;###autoload
(defun digit-brace-atpt (&optional arg ispec) 
  "Braces 'digit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'digit arg ispec))

(defalias 'bracket-digit-atpt 'digit-bracket-atpt)
;;;###autoload
(defun digit-bracket-atpt (&optional arg ispec) 
  "Brackets 'digit after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'digit arg ispec))

(defalias 'commented-digit-atpt 'digit-comment-atpt)
;;;###autoload
(defun digit-comment-atpt (&optional arg ispec) 
  "Comments 'digit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'digit arg ispec))

(defalias 'mark-digit-atpt 'digit-mark-atpt)
;;;###autoload
(defun digit-mark-atpt (&optional arg) 
  "Marks 'digit at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'digit arg))

(defalias 'kill-digit-atpt 'digit-kill-atpt)
;;;###autoload
(defun digit-kill-atpt (arg)
  "Kills digit at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'digit arg))

(defalias 'parentize-digit-atpt 'digit-parentize-atpt)
;;;###autoload
(defun digit-parentize-atpt (&optional arg ispec) 
  "Parentizes 'digit at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'digit arg ispec))

(defalias 'separate-digit-atpt 'digit-separate-atpt)
;;;###autoload
(defun digit-separate-atpt (&optional arg ispec) 
  "Separates 'digit at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'digit arg ispec))

(defalias 'singlequote-digit-atpt 'digit-singlequote-atpt)
;;;###autoload
(defun digit-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'digit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'digit arg ispec))

(defalias 'slash-digit-atpt 'digit-slash-atpt)
;;;###autoload
(defun digit-slash-atpt (&optional arg ispec) 
  "Slash 'digit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'digit arg ispec))

(defalias 'trim-digit-atpt 'digit-trim-atpt)
;;;###autoload
(defun digit-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'digit t t))

(defalias 'trim-digit-left-atpt 'digit-left-trim-atpt)
;;;###autoload
(defun digit-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'digit t nil))

(defalias 'trim-digit-right-atpt 'digit-right-trim-atpt)
;;;###autoload
(defun digit-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'digit nil t))

(defalias 'forward-digit-atpt 'digit-forward-atpt)
;;;###autoload
(defun digit-forward-atpt (&optional arg ispec) 
  "Moves forward over digit at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'digit arg ispec))

(defalias 'backward-digit-atpt 'digit-backward-atpt)
;;;###autoload
(defun digit-backward-atpt (&optional arg ispec) 
  "Moves backward over digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'digit arg ispec))

(defalias 'transpose-digit-atpt 'digit-transpose-atpt)
;;;###autoload
(defun digit-transpose-atpt (&optional arg) 
  "Transposes digit with digit before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'digit arg))

(defalias 'sort-digit-atpt 'digit-sort-atpt)
;;;###autoload
(defun digit-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts digit's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'digit reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-digit-atpt 'digit-check-atpt)
;;;###autoload
(defun digit-check-atpt (&optional arg ispec) 
  " digit at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "digit" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "digit" "-end-position-atpt")))))
    (th-check 'digit arg ispec)))
   

;;;###autoload
(defun dollared-atpt (&optional arg ispec) 
  "Returns dollared at point if any, nil otherwise"
  (interactive "P\np")
  (th 'dollared arg ispec))

(defalias 'bounds-of-dollared-atpt 'dollared-bounds-atpt)
;;;###autoload
(defun dollared-bounds-atpt (&optional arg ispec) 
  "Returns borders of dollared at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'dollared arg ispec))

;;;###autoload
(defun dollared-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class dollared at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'dollared arg ispec))

;;;###autoload
(defun dollared-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class dollared at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'dollared arg ispec))

(defalias 'beginning-of-dollared-atpt 'dollared-beginning-atpt)
;;;###autoload
(defun dollared-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class dollared at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'dollared arg ispec))

(defalias 'end-of-dollared-atpt 'dollared-end-atpt)
;;;###autoload
(defun dollared-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class dollared at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'dollared arg ispec))

(defalias 'length-of-dollared-atpt 'dollared-length-atpt)
;;;###autoload
(defun dollared-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class dollared at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'dollared arg ispec))

(defalias 'copy-dollared-atpt 'dollared-copy-atpt)
;;;###autoload
(defun dollared-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class dollared at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'dollared arg ispec))

(defalias 'escape-dollared-atpt 'dollared-escape-atpt)
;;;###autoload
(defun dollared-escape-atpt (arg) 
  "Makes a copy of symbol or char-class dollared at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'dollared arg))

(defalias 'doublequote-dollared-atpt 'dollared-doublequote-atpt)
;;;###autoload
(defun dollared-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'dollared at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'dollared arg ispec))

(defalias 'dollar-dollared-atpt 'dollared-dollar-atpt)
;;;###autoload
(defun dollared-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'dollared at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'dollared arg ispec))

(defalias 'backslash-dollared-atpt 'dollared-backslash-atpt)
;;;###autoload
(defun dollared-backslash-atpt (&optional arg ispec) 
  "Backslash 'dollared at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'dollared arg ispec)) 

(defalias 'brace-dollared-atpt 'dollared-brace-atpt)
;;;###autoload
(defun dollared-brace-atpt (&optional arg ispec) 
  "Braces 'dollared at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'dollared arg ispec))

(defalias 'bracket-dollared-atpt 'dollared-bracket-atpt)
;;;###autoload
(defun dollared-bracket-atpt (&optional arg ispec) 
  "Brackets 'dollared after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'dollared arg ispec))

(defalias 'commented-dollared-atpt 'dollared-comment-atpt)
;;;###autoload
(defun dollared-comment-atpt (&optional arg ispec) 
  "Comments 'dollared at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'dollared arg ispec))

(defalias 'mark-dollared-atpt 'dollared-mark-atpt)
;;;###autoload
(defun dollared-mark-atpt (&optional arg) 
  "Marks 'dollared at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'dollared arg))

(defalias 'kill-dollared-atpt 'dollared-kill-atpt)
;;;###autoload
(defun dollared-kill-atpt (arg)
  "Kills dollared at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'dollared arg))

(defalias 'parentize-dollared-atpt 'dollared-parentize-atpt)
;;;###autoload
(defun dollared-parentize-atpt (&optional arg ispec) 
  "Parentizes 'dollared at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'dollared arg ispec))

(defalias 'separate-dollared-atpt 'dollared-separate-atpt)
;;;###autoload
(defun dollared-separate-atpt (&optional arg ispec) 
  "Separates 'dollared at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'dollared arg ispec))

(defalias 'singlequote-dollared-atpt 'dollared-singlequote-atpt)
;;;###autoload
(defun dollared-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'dollared at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'dollared arg ispec))

(defalias 'slash-dollared-atpt 'dollared-slash-atpt)
;;;###autoload
(defun dollared-slash-atpt (&optional arg ispec) 
  "Slash 'dollared at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'dollared arg ispec))

(defalias 'trim-dollared-atpt 'dollared-trim-atpt)
;;;###autoload
(defun dollared-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'dollared t t))

(defalias 'trim-dollared-left-atpt 'dollared-left-trim-atpt)
;;;###autoload
(defun dollared-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'dollared t nil))

(defalias 'trim-dollared-right-atpt 'dollared-right-trim-atpt)
;;;###autoload
(defun dollared-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'dollared nil t))

(defalias 'forward-dollared-atpt 'dollared-forward-atpt)
;;;###autoload
(defun dollared-forward-atpt (&optional arg ispec) 
  "Moves forward over dollared at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'dollared arg ispec))

(defalias 'backward-dollared-atpt 'dollared-backward-atpt)
;;;###autoload
(defun dollared-backward-atpt (&optional arg ispec) 
  "Moves backward over dollared before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'dollared arg ispec))

(defalias 'transpose-dollared-atpt 'dollared-transpose-atpt)
;;;###autoload
(defun dollared-transpose-atpt (&optional arg) 
  "Transposes dollared with dollared before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'dollared arg))

(defalias 'sort-dollared-atpt 'dollared-sort-atpt)
;;;###autoload
(defun dollared-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts dollared's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'dollared reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-dollared-atpt 'dollared-check-atpt)
;;;###autoload
(defun dollared-check-atpt (&optional arg ispec) 
  " dollared at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "dollared" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "dollared" "-end-position-atpt")))))
    (th-check 'dollared arg ispec)))
   

;;;###autoload
(defun doublequoted-atpt (&optional arg ispec) 
  "Returns doublequoted at point if any, nil otherwise"
  (interactive "P\np")
  (th 'doublequoted arg ispec))

(defalias 'bounds-of-doublequoted-atpt 'doublequoted-bounds-atpt)
;;;###autoload
(defun doublequoted-bounds-atpt (&optional arg ispec) 
  "Returns borders of doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'doublequoted arg ispec))

;;;###autoload
(defun doublequoted-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'doublequoted arg ispec))

;;;###autoload
(defun doublequoted-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'doublequoted arg ispec))

(defalias 'beginning-of-doublequoted-atpt 'doublequoted-beginning-atpt)
;;;###autoload
(defun doublequoted-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'doublequoted arg ispec))

(defalias 'end-of-doublequoted-atpt 'doublequoted-end-atpt)
;;;###autoload
(defun doublequoted-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'doublequoted arg ispec))

(defalias 'length-of-doublequoted-atpt 'doublequoted-length-atpt)
;;;###autoload
(defun doublequoted-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'doublequoted arg ispec))

(defalias 'copy-doublequoted-atpt 'doublequoted-copy-atpt)
;;;###autoload
(defun doublequoted-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'doublequoted arg ispec))

(defalias 'escape-doublequoted-atpt 'doublequoted-escape-atpt)
;;;###autoload
(defun doublequoted-escape-atpt (arg) 
  "Makes a copy of symbol or char-class doublequoted at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'doublequoted arg))

(defalias 'doublequote-doublequoted-atpt 'doublequoted-doublequote-atpt)
;;;###autoload
(defun doublequoted-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'doublequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'doublequoted arg ispec))

(defalias 'dollar-doublequoted-atpt 'doublequoted-dollar-atpt)
;;;###autoload
(defun doublequoted-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'doublequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'doublequoted arg ispec))

(defalias 'backslash-doublequoted-atpt 'doublequoted-backslash-atpt)
;;;###autoload
(defun doublequoted-backslash-atpt (&optional arg ispec) 
  "Backslash 'doublequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'doublequoted arg ispec)) 

(defalias 'brace-doublequoted-atpt 'doublequoted-brace-atpt)
;;;###autoload
(defun doublequoted-brace-atpt (&optional arg ispec) 
  "Braces 'doublequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'doublequoted arg ispec))

(defalias 'bracket-doublequoted-atpt 'doublequoted-bracket-atpt)
;;;###autoload
(defun doublequoted-bracket-atpt (&optional arg ispec) 
  "Brackets 'doublequoted after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'doublequoted arg ispec))

(defalias 'commented-doublequoted-atpt 'doublequoted-comment-atpt)
;;;###autoload
(defun doublequoted-comment-atpt (&optional arg ispec) 
  "Comments 'doublequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'doublequoted arg ispec))

(defalias 'mark-doublequoted-atpt 'doublequoted-mark-atpt)
;;;###autoload
(defun doublequoted-mark-atpt (&optional arg) 
  "Marks 'doublequoted at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'doublequoted arg))

(defalias 'kill-doublequoted-atpt 'doublequoted-kill-atpt)
;;;###autoload
(defun doublequoted-kill-atpt (arg)
  "Kills doublequoted at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'doublequoted arg))

(defalias 'parentize-doublequoted-atpt 'doublequoted-parentize-atpt)
;;;###autoload
(defun doublequoted-parentize-atpt (&optional arg ispec) 
  "Parentizes 'doublequoted at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'doublequoted arg ispec))

(defalias 'separate-doublequoted-atpt 'doublequoted-separate-atpt)
;;;###autoload
(defun doublequoted-separate-atpt (&optional arg ispec) 
  "Separates 'doublequoted at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'doublequoted arg ispec))

(defalias 'singlequote-doublequoted-atpt 'doublequoted-singlequote-atpt)
;;;###autoload
(defun doublequoted-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'doublequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'doublequoted arg ispec))

(defalias 'slash-doublequoted-atpt 'doublequoted-slash-atpt)
;;;###autoload
(defun doublequoted-slash-atpt (&optional arg ispec) 
  "Slash 'doublequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'doublequoted arg ispec))

(defalias 'trim-doublequoted-atpt 'doublequoted-trim-atpt)
;;;###autoload
(defun doublequoted-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'doublequoted t t))

(defalias 'trim-doublequoted-left-atpt 'doublequoted-left-trim-atpt)
;;;###autoload
(defun doublequoted-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'doublequoted t nil))

(defalias 'trim-doublequoted-right-atpt 'doublequoted-right-trim-atpt)
;;;###autoload
(defun doublequoted-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'doublequoted nil t))

(defalias 'forward-doublequoted-atpt 'doublequoted-forward-atpt)
;;;###autoload
(defun doublequoted-forward-atpt (&optional arg ispec) 
  "Moves forward over doublequoted at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'doublequoted arg ispec))

(defalias 'backward-doublequoted-atpt 'doublequoted-backward-atpt)
;;;###autoload
(defun doublequoted-backward-atpt (&optional arg ispec) 
  "Moves backward over doublequoted before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'doublequoted arg ispec))

(defalias 'transpose-doublequoted-atpt 'doublequoted-transpose-atpt)
;;;###autoload
(defun doublequoted-transpose-atpt (&optional arg) 
  "Transposes doublequoted with doublequoted before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'doublequoted arg))

(defalias 'sort-doublequoted-atpt 'doublequoted-sort-atpt)
;;;###autoload
(defun doublequoted-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts doublequoted's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'doublequoted reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-doublequoted-atpt 'doublequoted-check-atpt)
;;;###autoload
(defun doublequoted-check-atpt (&optional arg ispec) 
  " doublequoted at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "doublequoted" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "doublequoted" "-end-position-atpt")))))
    (th-check 'doublequoted arg ispec)))
   

;;;###autoload
(defun email-atpt (&optional arg ispec) 
  "Returns email at point if any, nil otherwise"
  (interactive "P\np")
  (th 'email arg ispec))

(defalias 'bounds-of-email-atpt 'email-bounds-atpt)
;;;###autoload
(defun email-bounds-atpt (&optional arg ispec) 
  "Returns borders of email at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'email arg ispec))

;;;###autoload
(defun email-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'email arg ispec))

;;;###autoload
(defun email-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'email arg ispec))

(defalias 'beginning-of-email-atpt 'email-beginning-atpt)
;;;###autoload
(defun email-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'email arg ispec))

(defalias 'end-of-email-atpt 'email-end-atpt)
;;;###autoload
(defun email-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'email arg ispec))

(defalias 'length-of-email-atpt 'email-length-atpt)
;;;###autoload
(defun email-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'email arg ispec))

(defalias 'copy-email-atpt 'email-copy-atpt)
;;;###autoload
(defun email-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'email arg ispec))

(defalias 'escape-email-atpt 'email-escape-atpt)
;;;###autoload
(defun email-escape-atpt (arg) 
  "Makes a copy of symbol or char-class email at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'email arg))

(defalias 'doublequote-email-atpt 'email-doublequote-atpt)
;;;###autoload
(defun email-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'email at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'email arg ispec))

(defalias 'dollar-email-atpt 'email-dollar-atpt)
;;;###autoload
(defun email-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'email at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'email arg ispec))

(defalias 'backslash-email-atpt 'email-backslash-atpt)
;;;###autoload
(defun email-backslash-atpt (&optional arg ispec) 
  "Backslash 'email at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'email arg ispec)) 

(defalias 'brace-email-atpt 'email-brace-atpt)
;;;###autoload
(defun email-brace-atpt (&optional arg ispec) 
  "Braces 'email at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'email arg ispec))

(defalias 'bracket-email-atpt 'email-bracket-atpt)
;;;###autoload
(defun email-bracket-atpt (&optional arg ispec) 
  "Brackets 'email after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'email arg ispec))

(defalias 'commented-email-atpt 'email-comment-atpt)
;;;###autoload
(defun email-comment-atpt (&optional arg ispec) 
  "Comments 'email at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'email arg ispec))

(defalias 'mark-email-atpt 'email-mark-atpt)
;;;###autoload
(defun email-mark-atpt (&optional arg) 
  "Marks 'email at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'email arg))

(defalias 'kill-email-atpt 'email-kill-atpt)
;;;###autoload
(defun email-kill-atpt (arg)
  "Kills email at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'email arg))

(defalias 'parentize-email-atpt 'email-parentize-atpt)
;;;###autoload
(defun email-parentize-atpt (&optional arg ispec) 
  "Parentizes 'email at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'email arg ispec))

(defalias 'separate-email-atpt 'email-separate-atpt)
;;;###autoload
(defun email-separate-atpt (&optional arg ispec) 
  "Separates 'email at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'email arg ispec))

(defalias 'singlequote-email-atpt 'email-singlequote-atpt)
;;;###autoload
(defun email-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'email at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'email arg ispec))

(defalias 'slash-email-atpt 'email-slash-atpt)
;;;###autoload
(defun email-slash-atpt (&optional arg ispec) 
  "Slash 'email at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'email arg ispec))

(defalias 'trim-email-atpt 'email-trim-atpt)
;;;###autoload
(defun email-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'email t t))

(defalias 'trim-email-left-atpt 'email-left-trim-atpt)
;;;###autoload
(defun email-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'email t nil))

(defalias 'trim-email-right-atpt 'email-right-trim-atpt)
;;;###autoload
(defun email-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'email nil t))

(defalias 'forward-email-atpt 'email-forward-atpt)
;;;###autoload
(defun email-forward-atpt (&optional arg ispec) 
  "Moves forward over email at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'email arg ispec))

(defalias 'backward-email-atpt 'email-backward-atpt)
;;;###autoload
(defun email-backward-atpt (&optional arg ispec) 
  "Moves backward over email before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'email arg ispec))

(defalias 'transpose-email-atpt 'email-transpose-atpt)
;;;###autoload
(defun email-transpose-atpt (&optional arg) 
  "Transposes email with email before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'email arg))

(defalias 'sort-email-atpt 'email-sort-atpt)
;;;###autoload
(defun email-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts email's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'email reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-email-atpt 'email-check-atpt)
;;;###autoload
(defun email-check-atpt (&optional arg ispec) 
  " email at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "email" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "email" "-end-position-atpt")))))
    (th-check 'email arg ispec)))
   

;;;###autoload
(defun filename-atpt (&optional arg ispec) 
  "Returns filename at point if any, nil otherwise"
  (interactive "P\np")
  (th 'filename arg ispec))

(defalias 'bounds-of-filename-atpt 'filename-bounds-atpt)
;;;###autoload
(defun filename-bounds-atpt (&optional arg ispec) 
  "Returns borders of filename at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'filename arg ispec))

;;;###autoload
(defun filename-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'filename arg ispec))

;;;###autoload
(defun filename-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'filename arg ispec))

(defalias 'beginning-of-filename-atpt 'filename-beginning-atpt)
;;;###autoload
(defun filename-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'filename arg ispec))

(defalias 'end-of-filename-atpt 'filename-end-atpt)
;;;###autoload
(defun filename-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'filename arg ispec))

(defalias 'length-of-filename-atpt 'filename-length-atpt)
;;;###autoload
(defun filename-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'filename arg ispec))

(defalias 'copy-filename-atpt 'filename-copy-atpt)
;;;###autoload
(defun filename-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'filename arg ispec))

(defalias 'escape-filename-atpt 'filename-escape-atpt)
;;;###autoload
(defun filename-escape-atpt (arg) 
  "Makes a copy of symbol or char-class filename at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'filename arg))

(defalias 'doublequote-filename-atpt 'filename-doublequote-atpt)
;;;###autoload
(defun filename-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'filename at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'filename arg ispec))

(defalias 'dollar-filename-atpt 'filename-dollar-atpt)
;;;###autoload
(defun filename-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'filename at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'filename arg ispec))

(defalias 'backslash-filename-atpt 'filename-backslash-atpt)
;;;###autoload
(defun filename-backslash-atpt (&optional arg ispec) 
  "Backslash 'filename at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'filename arg ispec)) 

(defalias 'brace-filename-atpt 'filename-brace-atpt)
;;;###autoload
(defun filename-brace-atpt (&optional arg ispec) 
  "Braces 'filename at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'filename arg ispec))

(defalias 'bracket-filename-atpt 'filename-bracket-atpt)
;;;###autoload
(defun filename-bracket-atpt (&optional arg ispec) 
  "Brackets 'filename after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'filename arg ispec))

(defalias 'commented-filename-atpt 'filename-comment-atpt)
;;;###autoload
(defun filename-comment-atpt (&optional arg ispec) 
  "Comments 'filename at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'filename arg ispec))

(defalias 'mark-filename-atpt 'filename-mark-atpt)
;;;###autoload
(defun filename-mark-atpt (&optional arg) 
  "Marks 'filename at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'filename arg))

(defalias 'kill-filename-atpt 'filename-kill-atpt)
;;;###autoload
(defun filename-kill-atpt (arg)
  "Kills filename at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'filename arg))

(defalias 'parentize-filename-atpt 'filename-parentize-atpt)
;;;###autoload
(defun filename-parentize-atpt (&optional arg ispec) 
  "Parentizes 'filename at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'filename arg ispec))

(defalias 'separate-filename-atpt 'filename-separate-atpt)
;;;###autoload
(defun filename-separate-atpt (&optional arg ispec) 
  "Separates 'filename at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'filename arg ispec))

(defalias 'singlequote-filename-atpt 'filename-singlequote-atpt)
;;;###autoload
(defun filename-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'filename at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'filename arg ispec))

(defalias 'slash-filename-atpt 'filename-slash-atpt)
;;;###autoload
(defun filename-slash-atpt (&optional arg ispec) 
  "Slash 'filename at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'filename arg ispec))

(defalias 'trim-filename-atpt 'filename-trim-atpt)
;;;###autoload
(defun filename-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'filename t t))

(defalias 'trim-filename-left-atpt 'filename-left-trim-atpt)
;;;###autoload
(defun filename-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'filename t nil))

(defalias 'trim-filename-right-atpt 'filename-right-trim-atpt)
;;;###autoload
(defun filename-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'filename nil t))

(defalias 'forward-filename-atpt 'filename-forward-atpt)
;;;###autoload
(defun filename-forward-atpt (&optional arg ispec) 
  "Moves forward over filename at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'filename arg ispec))

(defalias 'backward-filename-atpt 'filename-backward-atpt)
;;;###autoload
(defun filename-backward-atpt (&optional arg ispec) 
  "Moves backward over filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'filename arg ispec))

(defalias 'transpose-filename-atpt 'filename-transpose-atpt)
;;;###autoload
(defun filename-transpose-atpt (&optional arg) 
  "Transposes filename with filename before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'filename arg))

(defalias 'sort-filename-atpt 'filename-sort-atpt)
;;;###autoload
(defun filename-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts filename's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'filename reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-filename-atpt 'filename-check-atpt)
;;;###autoload
(defun filename-check-atpt (&optional arg ispec) 
  " filename at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "filename" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "filename" "-end-position-atpt")))))
    (th-check 'filename arg ispec)))
   

;;;###autoload
(defun float-atpt (&optional arg ispec) 
  "Returns float at point if any, nil otherwise"
  (interactive "P\np")
  (th 'float arg ispec))

(defalias 'bounds-of-float-atpt 'float-bounds-atpt)
;;;###autoload
(defun float-bounds-atpt (&optional arg ispec) 
  "Returns borders of float at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'float arg ispec))

;;;###autoload
(defun float-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'float arg ispec))

;;;###autoload
(defun float-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'float arg ispec))

(defalias 'beginning-of-float-atpt 'float-beginning-atpt)
;;;###autoload
(defun float-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'float arg ispec))

(defalias 'end-of-float-atpt 'float-end-atpt)
;;;###autoload
(defun float-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'float arg ispec))

(defalias 'length-of-float-atpt 'float-length-atpt)
;;;###autoload
(defun float-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'float arg ispec))

(defalias 'copy-float-atpt 'float-copy-atpt)
;;;###autoload
(defun float-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'float arg ispec))

(defalias 'escape-float-atpt 'float-escape-atpt)
;;;###autoload
(defun float-escape-atpt (arg) 
  "Makes a copy of symbol or char-class float at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'float arg))

(defalias 'doublequote-float-atpt 'float-doublequote-atpt)
;;;###autoload
(defun float-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'float at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'float arg ispec))

(defalias 'dollar-float-atpt 'float-dollar-atpt)
;;;###autoload
(defun float-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'float at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'float arg ispec))

(defalias 'backslash-float-atpt 'float-backslash-atpt)
;;;###autoload
(defun float-backslash-atpt (&optional arg ispec) 
  "Backslash 'float at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'float arg ispec)) 

(defalias 'brace-float-atpt 'float-brace-atpt)
;;;###autoload
(defun float-brace-atpt (&optional arg ispec) 
  "Braces 'float at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'float arg ispec))

(defalias 'bracket-float-atpt 'float-bracket-atpt)
;;;###autoload
(defun float-bracket-atpt (&optional arg ispec) 
  "Brackets 'float after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'float arg ispec))

(defalias 'commented-float-atpt 'float-comment-atpt)
;;;###autoload
(defun float-comment-atpt (&optional arg ispec) 
  "Comments 'float at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'float arg ispec))

(defalias 'mark-float-atpt 'float-mark-atpt)
;;;###autoload
(defun float-mark-atpt (&optional arg) 
  "Marks 'float at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'float arg))

(defalias 'kill-float-atpt 'float-kill-atpt)
;;;###autoload
(defun float-kill-atpt (arg)
  "Kills float at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'float arg))

(defalias 'parentize-float-atpt 'float-parentize-atpt)
;;;###autoload
(defun float-parentize-atpt (&optional arg ispec) 
  "Parentizes 'float at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'float arg ispec))

(defalias 'separate-float-atpt 'float-separate-atpt)
;;;###autoload
(defun float-separate-atpt (&optional arg ispec) 
  "Separates 'float at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'float arg ispec))

(defalias 'singlequote-float-atpt 'float-singlequote-atpt)
;;;###autoload
(defun float-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'float at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'float arg ispec))

(defalias 'slash-float-atpt 'float-slash-atpt)
;;;###autoload
(defun float-slash-atpt (&optional arg ispec) 
  "Slash 'float at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'float arg ispec))

(defalias 'trim-float-atpt 'float-trim-atpt)
;;;###autoload
(defun float-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'float t t))

(defalias 'trim-float-left-atpt 'float-left-trim-atpt)
;;;###autoload
(defun float-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'float t nil))

(defalias 'trim-float-right-atpt 'float-right-trim-atpt)
;;;###autoload
(defun float-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'float nil t))

(defalias 'forward-float-atpt 'float-forward-atpt)
;;;###autoload
(defun float-forward-atpt (&optional arg ispec) 
  "Moves forward over float at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'float arg ispec))

(defalias 'backward-float-atpt 'float-backward-atpt)
;;;###autoload
(defun float-backward-atpt (&optional arg ispec) 
  "Moves backward over float before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'float arg ispec))

(defalias 'transpose-float-atpt 'float-transpose-atpt)
;;;###autoload
(defun float-transpose-atpt (&optional arg) 
  "Transposes float with float before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'float arg))

(defalias 'sort-float-atpt 'float-sort-atpt)
;;;###autoload
(defun float-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts float's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'float reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-float-atpt 'float-check-atpt)
;;;###autoload
(defun float-check-atpt (&optional arg ispec) 
  " float at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "float" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "float" "-end-position-atpt")))))
    (th-check 'float arg ispec)))
   

;;;###autoload
(defun function-atpt (&optional arg ispec) 
  "Returns function at point if any, nil otherwise"
  (interactive "P\np")
  (th 'function arg ispec))

(defalias 'bounds-of-function-atpt 'function-bounds-atpt)
;;;###autoload
(defun function-bounds-atpt (&optional arg ispec) 
  "Returns borders of function at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'function arg ispec))

;;;###autoload
(defun function-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class function at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'function arg ispec))

;;;###autoload
(defun function-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class function at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'function arg ispec))

(defalias 'beginning-of-function-atpt 'function-beginning-atpt)
;;;###autoload
(defun function-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class function at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'function arg ispec))

(defalias 'end-of-function-atpt 'function-end-atpt)
;;;###autoload
(defun function-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class function at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'function arg ispec))

(defalias 'length-of-function-atpt 'function-length-atpt)
;;;###autoload
(defun function-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class function at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'function arg ispec))

(defalias 'copy-function-atpt 'function-copy-atpt)
;;;###autoload
(defun function-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class function at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'function arg ispec))

(defalias 'escape-function-atpt 'function-escape-atpt)
;;;###autoload
(defun function-escape-atpt (arg) 
  "Makes a copy of symbol or char-class function at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'function arg))

(defalias 'doublequote-function-atpt 'function-doublequote-atpt)
;;;###autoload
(defun function-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'function at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'function arg ispec))

(defalias 'dollar-function-atpt 'function-dollar-atpt)
;;;###autoload
(defun function-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'function at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'function arg ispec))

(defalias 'backslash-function-atpt 'function-backslash-atpt)
;;;###autoload
(defun function-backslash-atpt (&optional arg ispec) 
  "Backslash 'function at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'function arg ispec)) 

(defalias 'brace-function-atpt 'function-brace-atpt)
;;;###autoload
(defun function-brace-atpt (&optional arg ispec) 
  "Braces 'function at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'function arg ispec))

(defalias 'bracket-function-atpt 'function-bracket-atpt)
;;;###autoload
(defun function-bracket-atpt (&optional arg ispec) 
  "Brackets 'function after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'function arg ispec))

(defalias 'commented-function-atpt 'function-comment-atpt)
;;;###autoload
(defun function-comment-atpt (&optional arg ispec) 
  "Comments 'function at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'function arg ispec))

(defalias 'mark-function-atpt 'function-mark-atpt)
;;;###autoload
(defun function-mark-atpt (&optional arg) 
  "Marks 'function at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'function arg))

(defalias 'kill-function-atpt 'function-kill-atpt)
;;;###autoload
(defun function-kill-atpt (arg)
  "Kills function at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'function arg))

(defalias 'parentize-function-atpt 'function-parentize-atpt)
;;;###autoload
(defun function-parentize-atpt (&optional arg ispec) 
  "Parentizes 'function at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'function arg ispec))

(defalias 'separate-function-atpt 'function-separate-atpt)
;;;###autoload
(defun function-separate-atpt (&optional arg ispec) 
  "Separates 'function at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'function arg ispec))

(defalias 'singlequote-function-atpt 'function-singlequote-atpt)
;;;###autoload
(defun function-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'function at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'function arg ispec))

(defalias 'slash-function-atpt 'function-slash-atpt)
;;;###autoload
(defun function-slash-atpt (&optional arg ispec) 
  "Slash 'function at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'function arg ispec))

(defalias 'trim-function-atpt 'function-trim-atpt)
;;;###autoload
(defun function-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'function t t))

(defalias 'trim-function-left-atpt 'function-left-trim-atpt)
;;;###autoload
(defun function-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'function t nil))

(defalias 'trim-function-right-atpt 'function-right-trim-atpt)
;;;###autoload
(defun function-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'function nil t))

(defalias 'forward-function-atpt 'function-forward-atpt)
;;;###autoload
(defun function-forward-atpt (&optional arg ispec) 
  "Moves forward over function at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'function arg ispec))

(defalias 'backward-function-atpt 'function-backward-atpt)
;;;###autoload
(defun function-backward-atpt (&optional arg ispec) 
  "Moves backward over function before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'function arg ispec))

(defalias 'transpose-function-atpt 'function-transpose-atpt)
;;;###autoload
(defun function-transpose-atpt (&optional arg) 
  "Transposes function with function before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'function arg))

(defalias 'sort-function-atpt 'function-sort-atpt)
;;;###autoload
(defun function-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts function's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'function reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-function-atpt 'function-check-atpt)
;;;###autoload
(defun function-check-atpt (&optional arg ispec) 
  " function at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "function" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "function" "-end-position-atpt")))))
    (th-check 'function arg ispec)))
   

;;;###autoload
(defun graph-atpt (&optional arg ispec) 
  "Returns graph at point if any, nil otherwise"
  (interactive "P\np")
  (th 'graph arg ispec))

(defalias 'bounds-of-graph-atpt 'graph-bounds-atpt)
;;;###autoload
(defun graph-bounds-atpt (&optional arg ispec) 
  "Returns borders of graph at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'graph arg ispec))

;;;###autoload
(defun graph-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'graph arg ispec))

;;;###autoload
(defun graph-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'graph arg ispec))

(defalias 'beginning-of-graph-atpt 'graph-beginning-atpt)
;;;###autoload
(defun graph-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'graph arg ispec))

(defalias 'end-of-graph-atpt 'graph-end-atpt)
;;;###autoload
(defun graph-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'graph arg ispec))

(defalias 'length-of-graph-atpt 'graph-length-atpt)
;;;###autoload
(defun graph-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'graph arg ispec))

(defalias 'copy-graph-atpt 'graph-copy-atpt)
;;;###autoload
(defun graph-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'graph arg ispec))

(defalias 'escape-graph-atpt 'graph-escape-atpt)
;;;###autoload
(defun graph-escape-atpt (arg) 
  "Makes a copy of symbol or char-class graph at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'graph arg))

(defalias 'doublequote-graph-atpt 'graph-doublequote-atpt)
;;;###autoload
(defun graph-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'graph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'graph arg ispec))

(defalias 'dollar-graph-atpt 'graph-dollar-atpt)
;;;###autoload
(defun graph-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'graph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'graph arg ispec))

(defalias 'backslash-graph-atpt 'graph-backslash-atpt)
;;;###autoload
(defun graph-backslash-atpt (&optional arg ispec) 
  "Backslash 'graph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'graph arg ispec)) 

(defalias 'brace-graph-atpt 'graph-brace-atpt)
;;;###autoload
(defun graph-brace-atpt (&optional arg ispec) 
  "Braces 'graph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'graph arg ispec))

(defalias 'bracket-graph-atpt 'graph-bracket-atpt)
;;;###autoload
(defun graph-bracket-atpt (&optional arg ispec) 
  "Brackets 'graph after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'graph arg ispec))

(defalias 'commented-graph-atpt 'graph-comment-atpt)
;;;###autoload
(defun graph-comment-atpt (&optional arg ispec) 
  "Comments 'graph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'graph arg ispec))

(defalias 'mark-graph-atpt 'graph-mark-atpt)
;;;###autoload
(defun graph-mark-atpt (&optional arg) 
  "Marks 'graph at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'graph arg))

(defalias 'kill-graph-atpt 'graph-kill-atpt)
;;;###autoload
(defun graph-kill-atpt (arg)
  "Kills graph at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'graph arg))

(defalias 'parentize-graph-atpt 'graph-parentize-atpt)
;;;###autoload
(defun graph-parentize-atpt (&optional arg ispec) 
  "Parentizes 'graph at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'graph arg ispec))

(defalias 'separate-graph-atpt 'graph-separate-atpt)
;;;###autoload
(defun graph-separate-atpt (&optional arg ispec) 
  "Separates 'graph at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'graph arg ispec))

(defalias 'singlequote-graph-atpt 'graph-singlequote-atpt)
;;;###autoload
(defun graph-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'graph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'graph arg ispec))

(defalias 'slash-graph-atpt 'graph-slash-atpt)
;;;###autoload
(defun graph-slash-atpt (&optional arg ispec) 
  "Slash 'graph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'graph arg ispec))

(defalias 'trim-graph-atpt 'graph-trim-atpt)
;;;###autoload
(defun graph-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'graph t t))

(defalias 'trim-graph-left-atpt 'graph-left-trim-atpt)
;;;###autoload
(defun graph-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'graph t nil))

(defalias 'trim-graph-right-atpt 'graph-right-trim-atpt)
;;;###autoload
(defun graph-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'graph nil t))

(defalias 'forward-graph-atpt 'graph-forward-atpt)
;;;###autoload
(defun graph-forward-atpt (&optional arg ispec) 
  "Moves forward over graph at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'graph arg ispec))

(defalias 'backward-graph-atpt 'graph-backward-atpt)
;;;###autoload
(defun graph-backward-atpt (&optional arg ispec) 
  "Moves backward over graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'graph arg ispec))

(defalias 'transpose-graph-atpt 'graph-transpose-atpt)
;;;###autoload
(defun graph-transpose-atpt (&optional arg) 
  "Transposes graph with graph before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'graph arg))

(defalias 'sort-graph-atpt 'graph-sort-atpt)
;;;###autoload
(defun graph-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts graph's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'graph reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-graph-atpt 'graph-check-atpt)
;;;###autoload
(defun graph-check-atpt (&optional arg ispec) 
  " graph at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "graph" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "graph" "-end-position-atpt")))))
    (th-check 'graph arg ispec)))
   

;;;###autoload
(defun ip-atpt (&optional arg ispec) 
  "Returns ip at point if any, nil otherwise"
  (interactive "P\np")
  (th 'ip arg ispec))

(defalias 'bounds-of-ip-atpt 'ip-bounds-atpt)
;;;###autoload
(defun ip-bounds-atpt (&optional arg ispec) 
  "Returns borders of ip at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'ip arg ispec))

;;;###autoload
(defun ip-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class ip at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'ip arg ispec))

;;;###autoload
(defun ip-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class ip at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'ip arg ispec))

(defalias 'beginning-of-ip-atpt 'ip-beginning-atpt)
;;;###autoload
(defun ip-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class ip at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'ip arg ispec))

(defalias 'end-of-ip-atpt 'ip-end-atpt)
;;;###autoload
(defun ip-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class ip at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'ip arg ispec))

(defalias 'length-of-ip-atpt 'ip-length-atpt)
;;;###autoload
(defun ip-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class ip at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'ip arg ispec))

(defalias 'copy-ip-atpt 'ip-copy-atpt)
;;;###autoload
(defun ip-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class ip at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'ip arg ispec))

(defalias 'escape-ip-atpt 'ip-escape-atpt)
;;;###autoload
(defun ip-escape-atpt (arg) 
  "Makes a copy of symbol or char-class ip at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'ip arg))

(defalias 'doublequote-ip-atpt 'ip-doublequote-atpt)
;;;###autoload
(defun ip-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'ip at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'ip arg ispec))

(defalias 'dollar-ip-atpt 'ip-dollar-atpt)
;;;###autoload
(defun ip-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'ip at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'ip arg ispec))

(defalias 'backslash-ip-atpt 'ip-backslash-atpt)
;;;###autoload
(defun ip-backslash-atpt (&optional arg ispec) 
  "Backslash 'ip at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'ip arg ispec)) 

(defalias 'brace-ip-atpt 'ip-brace-atpt)
;;;###autoload
(defun ip-brace-atpt (&optional arg ispec) 
  "Braces 'ip at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'ip arg ispec))

(defalias 'bracket-ip-atpt 'ip-bracket-atpt)
;;;###autoload
(defun ip-bracket-atpt (&optional arg ispec) 
  "Brackets 'ip after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'ip arg ispec))

(defalias 'commented-ip-atpt 'ip-comment-atpt)
;;;###autoload
(defun ip-comment-atpt (&optional arg ispec) 
  "Comments 'ip at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'ip arg ispec))

(defalias 'mark-ip-atpt 'ip-mark-atpt)
;;;###autoload
(defun ip-mark-atpt (&optional arg) 
  "Marks 'ip at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'ip arg))

(defalias 'kill-ip-atpt 'ip-kill-atpt)
;;;###autoload
(defun ip-kill-atpt (arg)
  "Kills ip at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'ip arg))

(defalias 'parentize-ip-atpt 'ip-parentize-atpt)
;;;###autoload
(defun ip-parentize-atpt (&optional arg ispec) 
  "Parentizes 'ip at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'ip arg ispec))

(defalias 'separate-ip-atpt 'ip-separate-atpt)
;;;###autoload
(defun ip-separate-atpt (&optional arg ispec) 
  "Separates 'ip at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'ip arg ispec))

(defalias 'singlequote-ip-atpt 'ip-singlequote-atpt)
;;;###autoload
(defun ip-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'ip at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'ip arg ispec))

(defalias 'slash-ip-atpt 'ip-slash-atpt)
;;;###autoload
(defun ip-slash-atpt (&optional arg ispec) 
  "Slash 'ip at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'ip arg ispec))

(defalias 'trim-ip-atpt 'ip-trim-atpt)
;;;###autoload
(defun ip-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ip t t))

(defalias 'trim-ip-left-atpt 'ip-left-trim-atpt)
;;;###autoload
(defun ip-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ip t nil))

(defalias 'trim-ip-right-atpt 'ip-right-trim-atpt)
;;;###autoload
(defun ip-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ip nil t))

(defalias 'forward-ip-atpt 'ip-forward-atpt)
;;;###autoload
(defun ip-forward-atpt (&optional arg ispec) 
  "Moves forward over ip at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'ip arg ispec))

(defalias 'backward-ip-atpt 'ip-backward-atpt)
;;;###autoload
(defun ip-backward-atpt (&optional arg ispec) 
  "Moves backward over ip before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'ip arg ispec))

(defalias 'transpose-ip-atpt 'ip-transpose-atpt)
;;;###autoload
(defun ip-transpose-atpt (&optional arg) 
  "Transposes ip with ip before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'ip arg))

(defalias 'sort-ip-atpt 'ip-sort-atpt)
;;;###autoload
(defun ip-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts ip's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'ip reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-ip-atpt 'ip-check-atpt)
;;;###autoload
(defun ip-check-atpt (&optional arg ispec) 
  " ip at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "ip" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "ip" "-end-position-atpt")))))
    (th-check 'ip arg ispec)))
   

;;;###autoload
(defun isbn-atpt (&optional arg ispec) 
  "Returns isbn at point if any, nil otherwise"
  (interactive "P\np")
  (th 'isbn arg ispec))

(defalias 'bounds-of-isbn-atpt 'isbn-bounds-atpt)
;;;###autoload
(defun isbn-bounds-atpt (&optional arg ispec) 
  "Returns borders of isbn at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'isbn arg ispec))

;;;###autoload
(defun isbn-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'isbn arg ispec))

;;;###autoload
(defun isbn-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'isbn arg ispec))

(defalias 'beginning-of-isbn-atpt 'isbn-beginning-atpt)
;;;###autoload
(defun isbn-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'isbn arg ispec))

(defalias 'end-of-isbn-atpt 'isbn-end-atpt)
;;;###autoload
(defun isbn-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'isbn arg ispec))

(defalias 'length-of-isbn-atpt 'isbn-length-atpt)
;;;###autoload
(defun isbn-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'isbn arg ispec))

(defalias 'copy-isbn-atpt 'isbn-copy-atpt)
;;;###autoload
(defun isbn-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'isbn arg ispec))

(defalias 'escape-isbn-atpt 'isbn-escape-atpt)
;;;###autoload
(defun isbn-escape-atpt (arg) 
  "Makes a copy of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'isbn arg))

(defalias 'doublequote-isbn-atpt 'isbn-doublequote-atpt)
;;;###autoload
(defun isbn-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'isbn at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'isbn arg ispec))

(defalias 'dollar-isbn-atpt 'isbn-dollar-atpt)
;;;###autoload
(defun isbn-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'isbn at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'isbn arg ispec))

(defalias 'backslash-isbn-atpt 'isbn-backslash-atpt)
;;;###autoload
(defun isbn-backslash-atpt (&optional arg ispec) 
  "Backslash 'isbn at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'isbn arg ispec)) 

(defalias 'brace-isbn-atpt 'isbn-brace-atpt)
;;;###autoload
(defun isbn-brace-atpt (&optional arg ispec) 
  "Braces 'isbn at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'isbn arg ispec))

(defalias 'bracket-isbn-atpt 'isbn-bracket-atpt)
;;;###autoload
(defun isbn-bracket-atpt (&optional arg ispec) 
  "Brackets 'isbn after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'isbn arg ispec))

(defalias 'commented-isbn-atpt 'isbn-comment-atpt)
;;;###autoload
(defun isbn-comment-atpt (&optional arg ispec) 
  "Comments 'isbn at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'isbn arg ispec))

(defalias 'mark-isbn-atpt 'isbn-mark-atpt)
;;;###autoload
(defun isbn-mark-atpt (&optional arg) 
  "Marks 'isbn at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'isbn arg))

(defalias 'kill-isbn-atpt 'isbn-kill-atpt)
;;;###autoload
(defun isbn-kill-atpt (arg)
  "Kills isbn at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'isbn arg))

(defalias 'parentize-isbn-atpt 'isbn-parentize-atpt)
;;;###autoload
(defun isbn-parentize-atpt (&optional arg ispec) 
  "Parentizes 'isbn at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'isbn arg ispec))

(defalias 'separate-isbn-atpt 'isbn-separate-atpt)
;;;###autoload
(defun isbn-separate-atpt (&optional arg ispec) 
  "Separates 'isbn at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'isbn arg ispec))

(defalias 'singlequote-isbn-atpt 'isbn-singlequote-atpt)
;;;###autoload
(defun isbn-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'isbn at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'isbn arg ispec))

(defalias 'slash-isbn-atpt 'isbn-slash-atpt)
;;;###autoload
(defun isbn-slash-atpt (&optional arg ispec) 
  "Slash 'isbn at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'isbn arg ispec))

(defalias 'trim-isbn-atpt 'isbn-trim-atpt)
;;;###autoload
(defun isbn-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'isbn t t))

(defalias 'trim-isbn-left-atpt 'isbn-left-trim-atpt)
;;;###autoload
(defun isbn-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'isbn t nil))

(defalias 'trim-isbn-right-atpt 'isbn-right-trim-atpt)
;;;###autoload
(defun isbn-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'isbn nil t))

(defalias 'forward-isbn-atpt 'isbn-forward-atpt)
;;;###autoload
(defun isbn-forward-atpt (&optional arg ispec) 
  "Moves forward over isbn at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'isbn arg ispec))

(defalias 'backward-isbn-atpt 'isbn-backward-atpt)
;;;###autoload
(defun isbn-backward-atpt (&optional arg ispec) 
  "Moves backward over isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'isbn arg ispec))

(defalias 'transpose-isbn-atpt 'isbn-transpose-atpt)
;;;###autoload
(defun isbn-transpose-atpt (&optional arg) 
  "Transposes isbn with isbn before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'isbn arg))

(defalias 'sort-isbn-atpt 'isbn-sort-atpt)
;;;###autoload
(defun isbn-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts isbn's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'isbn reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-isbn-atpt 'isbn-check-atpt)
;;;###autoload
(defun isbn-check-atpt (&optional arg ispec) 
  " isbn at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "isbn" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "isbn" "-end-position-atpt")))))
    (th-check 'isbn arg ispec)))
   

;;;###autoload
(defun line-atpt (&optional arg ispec) 
  "Returns line at point if any, nil otherwise"
  (interactive "P\np")
  (th 'line arg ispec))

(defalias 'bounds-of-line-atpt 'line-bounds-atpt)
;;;###autoload
(defun line-bounds-atpt (&optional arg ispec) 
  "Returns borders of line at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'line arg ispec))

;;;###autoload
(defun line-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'line arg ispec))

;;;###autoload
(defun line-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'line arg ispec))

(defalias 'beginning-of-line-atpt 'line-beginning-atpt)
;;;###autoload
(defun line-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'line arg ispec))

(defalias 'end-of-line-atpt 'line-end-atpt)
;;;###autoload
(defun line-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'line arg ispec))

(defalias 'length-of-line-atpt 'line-length-atpt)
;;;###autoload
(defun line-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'line arg ispec))

(defalias 'copy-line-atpt 'line-copy-atpt)
;;;###autoload
(defun line-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'line arg ispec))

(defalias 'escape-line-atpt 'line-escape-atpt)
;;;###autoload
(defun line-escape-atpt (arg) 
  "Makes a copy of symbol or char-class line at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'line arg))

(defalias 'doublequote-line-atpt 'line-doublequote-atpt)
;;;###autoload
(defun line-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'line at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'line arg ispec))

(defalias 'dollar-line-atpt 'line-dollar-atpt)
;;;###autoload
(defun line-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'line at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'line arg ispec))

(defalias 'backslash-line-atpt 'line-backslash-atpt)
;;;###autoload
(defun line-backslash-atpt (&optional arg ispec) 
  "Backslash 'line at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'line arg ispec)) 

(defalias 'brace-line-atpt 'line-brace-atpt)
;;;###autoload
(defun line-brace-atpt (&optional arg ispec) 
  "Braces 'line at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'line arg ispec))

(defalias 'bracket-line-atpt 'line-bracket-atpt)
;;;###autoload
(defun line-bracket-atpt (&optional arg ispec) 
  "Brackets 'line after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'line arg ispec))

(defalias 'commented-line-atpt 'line-comment-atpt)
;;;###autoload
(defun line-comment-atpt (&optional arg ispec) 
  "Comments 'line at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'line arg ispec))

(defalias 'mark-line-atpt 'line-mark-atpt)
;;;###autoload
(defun line-mark-atpt (&optional arg) 
  "Marks 'line at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'line arg))

(defalias 'kill-line-atpt 'line-kill-atpt)
;;;###autoload
(defun line-kill-atpt (arg)
  "Kills line at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'line arg))

(defalias 'parentize-line-atpt 'line-parentize-atpt)
;;;###autoload
(defun line-parentize-atpt (&optional arg ispec) 
  "Parentizes 'line at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'line arg ispec))

(defalias 'separate-line-atpt 'line-separate-atpt)
;;;###autoload
(defun line-separate-atpt (&optional arg ispec) 
  "Separates 'line at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'line arg ispec))

(defalias 'singlequote-line-atpt 'line-singlequote-atpt)
;;;###autoload
(defun line-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'line at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'line arg ispec))

(defalias 'slash-line-atpt 'line-slash-atpt)
;;;###autoload
(defun line-slash-atpt (&optional arg ispec) 
  "Slash 'line at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'line arg ispec))

(defalias 'trim-line-atpt 'line-trim-atpt)
;;;###autoload
(defun line-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'line t t))

(defalias 'trim-line-left-atpt 'line-left-trim-atpt)
;;;###autoload
(defun line-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'line t nil))

(defalias 'trim-line-right-atpt 'line-right-trim-atpt)
;;;###autoload
(defun line-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'line nil t))

(defalias 'forward-line-atpt 'line-forward-atpt)
;;;###autoload
(defun line-forward-atpt (&optional arg ispec) 
  "Moves forward over line at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'line arg ispec))

(defalias 'backward-line-atpt 'line-backward-atpt)
;;;###autoload
(defun line-backward-atpt (&optional arg ispec) 
  "Moves backward over line before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'line arg ispec))

(defalias 'transpose-line-atpt 'line-transpose-atpt)
;;;###autoload
(defun line-transpose-atpt (&optional arg) 
  "Transposes line with line before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'line arg))

(defalias 'sort-line-atpt 'line-sort-atpt)
;;;###autoload
(defun line-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts line's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'line reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-line-atpt 'line-check-atpt)
;;;###autoload
(defun line-check-atpt (&optional arg ispec) 
  " line at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "line" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "line" "-end-position-atpt")))))
    (th-check 'line arg ispec)))
   

;;;###autoload
(defun list-atpt (&optional arg ispec) 
  "Returns list at point if any, nil otherwise"
  (interactive "P\np")
  (th 'list arg ispec))

(defalias 'bounds-of-list-atpt 'list-bounds-atpt)
;;;###autoload
(defun list-bounds-atpt (&optional arg ispec) 
  "Returns borders of list at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'list arg ispec))

;;;###autoload
(defun list-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'list arg ispec))

;;;###autoload
(defun list-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'list arg ispec))

(defalias 'beginning-of-list-atpt 'list-beginning-atpt)
;;;###autoload
(defun list-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'list arg ispec))

(defalias 'end-of-list-atpt 'list-end-atpt)
;;;###autoload
(defun list-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'list arg ispec))

(defalias 'length-of-list-atpt 'list-length-atpt)
;;;###autoload
(defun list-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'list arg ispec))

(defalias 'copy-list-atpt 'list-copy-atpt)
;;;###autoload
(defun list-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'list arg ispec))

(defalias 'escape-list-atpt 'list-escape-atpt)
;;;###autoload
(defun list-escape-atpt (arg) 
  "Makes a copy of symbol or char-class list at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'list arg))

(defalias 'doublequote-list-atpt 'list-doublequote-atpt)
;;;###autoload
(defun list-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'list at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'list arg ispec))

(defalias 'dollar-list-atpt 'list-dollar-atpt)
;;;###autoload
(defun list-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'list at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'list arg ispec))

(defalias 'backslash-list-atpt 'list-backslash-atpt)
;;;###autoload
(defun list-backslash-atpt (&optional arg ispec) 
  "Backslash 'list at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'list arg ispec)) 

(defalias 'brace-list-atpt 'list-brace-atpt)
;;;###autoload
(defun list-brace-atpt (&optional arg ispec) 
  "Braces 'list at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'list arg ispec))

(defalias 'bracket-list-atpt 'list-bracket-atpt)
;;;###autoload
(defun list-bracket-atpt (&optional arg ispec) 
  "Brackets 'list after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'list arg ispec))

(defalias 'commented-list-atpt 'list-comment-atpt)
;;;###autoload
(defun list-comment-atpt (&optional arg ispec) 
  "Comments 'list at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'list arg ispec))

(defalias 'mark-list-atpt 'list-mark-atpt)
;;;###autoload
(defun list-mark-atpt (&optional arg) 
  "Marks 'list at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'list arg))

(defalias 'kill-list-atpt 'list-kill-atpt)
;;;###autoload
(defun list-kill-atpt (arg)
  "Kills list at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'list arg))

(defalias 'parentize-list-atpt 'list-parentize-atpt)
;;;###autoload
(defun list-parentize-atpt (&optional arg ispec) 
  "Parentizes 'list at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'list arg ispec))

(defalias 'separate-list-atpt 'list-separate-atpt)
;;;###autoload
(defun list-separate-atpt (&optional arg ispec) 
  "Separates 'list at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'list arg ispec))

(defalias 'singlequote-list-atpt 'list-singlequote-atpt)
;;;###autoload
(defun list-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'list at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'list arg ispec))

(defalias 'slash-list-atpt 'list-slash-atpt)
;;;###autoload
(defun list-slash-atpt (&optional arg ispec) 
  "Slash 'list at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'list arg ispec))

(defalias 'trim-list-atpt 'list-trim-atpt)
;;;###autoload
(defun list-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'list t t))

(defalias 'trim-list-left-atpt 'list-left-trim-atpt)
;;;###autoload
(defun list-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'list t nil))

(defalias 'trim-list-right-atpt 'list-right-trim-atpt)
;;;###autoload
(defun list-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'list nil t))

(defalias 'forward-list-atpt 'list-forward-atpt)
;;;###autoload
(defun list-forward-atpt (&optional arg ispec) 
  "Moves forward over list at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'list arg ispec))

(defalias 'backward-list-atpt 'list-backward-atpt)
;;;###autoload
(defun list-backward-atpt (&optional arg ispec) 
  "Moves backward over list before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'list arg ispec))

(defalias 'transpose-list-atpt 'list-transpose-atpt)
;;;###autoload
(defun list-transpose-atpt (&optional arg) 
  "Transposes list with list before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'list arg))

(defalias 'sort-list-atpt 'list-sort-atpt)
;;;###autoload
(defun list-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts list's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'list reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-list-atpt 'list-check-atpt)
;;;###autoload
(defun list-check-atpt (&optional arg ispec) 
  " list at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "list" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "list" "-end-position-atpt")))))
    (th-check 'list arg ispec)))
   

;;;###autoload
(defun lower-atpt (&optional arg ispec) 
  "Returns lower at point if any, nil otherwise"
  (interactive "P\np")
  (th 'lower arg ispec))

(defalias 'bounds-of-lower-atpt 'lower-bounds-atpt)
;;;###autoload
(defun lower-bounds-atpt (&optional arg ispec) 
  "Returns borders of lower at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'lower arg ispec))

;;;###autoload
(defun lower-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'lower arg ispec))

;;;###autoload
(defun lower-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'lower arg ispec))

(defalias 'beginning-of-lower-atpt 'lower-beginning-atpt)
;;;###autoload
(defun lower-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'lower arg ispec))

(defalias 'end-of-lower-atpt 'lower-end-atpt)
;;;###autoload
(defun lower-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'lower arg ispec))

(defalias 'length-of-lower-atpt 'lower-length-atpt)
;;;###autoload
(defun lower-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'lower arg ispec))

(defalias 'copy-lower-atpt 'lower-copy-atpt)
;;;###autoload
(defun lower-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'lower arg ispec))

(defalias 'escape-lower-atpt 'lower-escape-atpt)
;;;###autoload
(defun lower-escape-atpt (arg) 
  "Makes a copy of symbol or char-class lower at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'lower arg))

(defalias 'doublequote-lower-atpt 'lower-doublequote-atpt)
;;;###autoload
(defun lower-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'lower at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'lower arg ispec))

(defalias 'dollar-lower-atpt 'lower-dollar-atpt)
;;;###autoload
(defun lower-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'lower at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'lower arg ispec))

(defalias 'backslash-lower-atpt 'lower-backslash-atpt)
;;;###autoload
(defun lower-backslash-atpt (&optional arg ispec) 
  "Backslash 'lower at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'lower arg ispec)) 

(defalias 'brace-lower-atpt 'lower-brace-atpt)
;;;###autoload
(defun lower-brace-atpt (&optional arg ispec) 
  "Braces 'lower at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'lower arg ispec))

(defalias 'bracket-lower-atpt 'lower-bracket-atpt)
;;;###autoload
(defun lower-bracket-atpt (&optional arg ispec) 
  "Brackets 'lower after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'lower arg ispec))

(defalias 'commented-lower-atpt 'lower-comment-atpt)
;;;###autoload
(defun lower-comment-atpt (&optional arg ispec) 
  "Comments 'lower at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'lower arg ispec))

(defalias 'mark-lower-atpt 'lower-mark-atpt)
;;;###autoload
(defun lower-mark-atpt (&optional arg) 
  "Marks 'lower at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'lower arg))

(defalias 'kill-lower-atpt 'lower-kill-atpt)
;;;###autoload
(defun lower-kill-atpt (arg)
  "Kills lower at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'lower arg))

(defalias 'parentize-lower-atpt 'lower-parentize-atpt)
;;;###autoload
(defun lower-parentize-atpt (&optional arg ispec) 
  "Parentizes 'lower at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'lower arg ispec))

(defalias 'separate-lower-atpt 'lower-separate-atpt)
;;;###autoload
(defun lower-separate-atpt (&optional arg ispec) 
  "Separates 'lower at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'lower arg ispec))

(defalias 'singlequote-lower-atpt 'lower-singlequote-atpt)
;;;###autoload
(defun lower-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'lower at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'lower arg ispec))

(defalias 'slash-lower-atpt 'lower-slash-atpt)
;;;###autoload
(defun lower-slash-atpt (&optional arg ispec) 
  "Slash 'lower at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'lower arg ispec))

(defalias 'trim-lower-atpt 'lower-trim-atpt)
;;;###autoload
(defun lower-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'lower t t))

(defalias 'trim-lower-left-atpt 'lower-left-trim-atpt)
;;;###autoload
(defun lower-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'lower t nil))

(defalias 'trim-lower-right-atpt 'lower-right-trim-atpt)
;;;###autoload
(defun lower-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'lower nil t))

(defalias 'forward-lower-atpt 'lower-forward-atpt)
;;;###autoload
(defun lower-forward-atpt (&optional arg ispec) 
  "Moves forward over lower at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'lower arg ispec))

(defalias 'backward-lower-atpt 'lower-backward-atpt)
;;;###autoload
(defun lower-backward-atpt (&optional arg ispec) 
  "Moves backward over lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'lower arg ispec))

(defalias 'transpose-lower-atpt 'lower-transpose-atpt)
;;;###autoload
(defun lower-transpose-atpt (&optional arg) 
  "Transposes lower with lower before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'lower arg))

(defalias 'sort-lower-atpt 'lower-sort-atpt)
;;;###autoload
(defun lower-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts lower's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'lower reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-lower-atpt 'lower-check-atpt)
;;;###autoload
(defun lower-check-atpt (&optional arg ispec) 
  " lower at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "lower" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "lower" "-end-position-atpt")))))
    (th-check 'lower arg ispec)))
   

;;;###autoload
(defun ml-text-atpt (&optional arg ispec) 
  "Returns ml-text at point if any, nil otherwise"
  (interactive "P\np")
  (th 'ml-text arg ispec))

(defalias 'bounds-of-ml-text-atpt 'ml-text-bounds-atpt)
;;;###autoload
(defun ml-text-bounds-atpt (&optional arg ispec) 
  "Returns borders of ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'ml-text arg ispec))

;;;###autoload
(defun ml-text-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'ml-text arg ispec))

;;;###autoload
(defun ml-text-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'ml-text arg ispec))

(defalias 'beginning-of-ml-text-atpt 'ml-text-beginning-atpt)
;;;###autoload
(defun ml-text-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'ml-text arg ispec))

(defalias 'end-of-ml-text-atpt 'ml-text-end-atpt)
;;;###autoload
(defun ml-text-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'ml-text arg ispec))

(defalias 'length-of-ml-text-atpt 'ml-text-length-atpt)
;;;###autoload
(defun ml-text-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'ml-text arg ispec))

(defalias 'copy-ml-text-atpt 'ml-text-copy-atpt)
;;;###autoload
(defun ml-text-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'ml-text arg ispec))

(defalias 'escape-ml-text-atpt 'ml-text-escape-atpt)
;;;###autoload
(defun ml-text-escape-atpt (arg) 
  "Makes a copy of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'ml-text arg))

(defalias 'doublequote-ml-text-atpt 'ml-text-doublequote-atpt)
;;;###autoload
(defun ml-text-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'ml-text at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'ml-text arg ispec))

(defalias 'dollar-ml-text-atpt 'ml-text-dollar-atpt)
;;;###autoload
(defun ml-text-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'ml-text at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'ml-text arg ispec))

(defalias 'backslash-ml-text-atpt 'ml-text-backslash-atpt)
;;;###autoload
(defun ml-text-backslash-atpt (&optional arg ispec) 
  "Backslash 'ml-text at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'ml-text arg ispec)) 

(defalias 'brace-ml-text-atpt 'ml-text-brace-atpt)
;;;###autoload
(defun ml-text-brace-atpt (&optional arg ispec) 
  "Braces 'ml-text at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'ml-text arg ispec))

(defalias 'bracket-ml-text-atpt 'ml-text-bracket-atpt)
;;;###autoload
(defun ml-text-bracket-atpt (&optional arg ispec) 
  "Brackets 'ml-text after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'ml-text arg ispec))

(defalias 'commented-ml-text-atpt 'ml-text-comment-atpt)
;;;###autoload
(defun ml-text-comment-atpt (&optional arg ispec) 
  "Comments 'ml-text at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'ml-text arg ispec))

(defalias 'mark-ml-text-atpt 'ml-text-mark-atpt)
;;;###autoload
(defun ml-text-mark-atpt (&optional arg) 
  "Marks 'ml-text at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'ml-text arg))

(defalias 'kill-ml-text-atpt 'ml-text-kill-atpt)
;;;###autoload
(defun ml-text-kill-atpt (arg)
  "Kills ml-text at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'ml-text arg))

(defalias 'parentize-ml-text-atpt 'ml-text-parentize-atpt)
;;;###autoload
(defun ml-text-parentize-atpt (&optional arg ispec) 
  "Parentizes 'ml-text at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'ml-text arg ispec))

(defalias 'separate-ml-text-atpt 'ml-text-separate-atpt)
;;;###autoload
(defun ml-text-separate-atpt (&optional arg ispec) 
  "Separates 'ml-text at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'ml-text arg ispec))

(defalias 'singlequote-ml-text-atpt 'ml-text-singlequote-atpt)
;;;###autoload
(defun ml-text-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'ml-text at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'ml-text arg ispec))

(defalias 'slash-ml-text-atpt 'ml-text-slash-atpt)
;;;###autoload
(defun ml-text-slash-atpt (&optional arg ispec) 
  "Slash 'ml-text at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'ml-text arg ispec))

(defalias 'trim-ml-text-atpt 'ml-text-trim-atpt)
;;;###autoload
(defun ml-text-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ml-text t t))

(defalias 'trim-ml-text-left-atpt 'ml-text-left-trim-atpt)
;;;###autoload
(defun ml-text-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ml-text t nil))

(defalias 'trim-ml-text-right-atpt 'ml-text-right-trim-atpt)
;;;###autoload
(defun ml-text-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'ml-text nil t))

(defalias 'forward-ml-text-atpt 'ml-text-forward-atpt)
;;;###autoload
(defun ml-text-forward-atpt (&optional arg ispec) 
  "Moves forward over ml-text at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'ml-text arg ispec))

(defalias 'backward-ml-text-atpt 'ml-text-backward-atpt)
;;;###autoload
(defun ml-text-backward-atpt (&optional arg ispec) 
  "Moves backward over ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'ml-text arg ispec))

(defalias 'transpose-ml-text-atpt 'ml-text-transpose-atpt)
;;;###autoload
(defun ml-text-transpose-atpt (&optional arg) 
  "Transposes ml-text with ml-text before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'ml-text arg))

(defalias 'sort-ml-text-atpt 'ml-text-sort-atpt)
;;;###autoload
(defun ml-text-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts ml-text's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'ml-text reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-ml-text-atpt 'ml-text-check-atpt)
;;;###autoload
(defun ml-text-check-atpt (&optional arg ispec) 
  " ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "ml-text" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "ml-text" "-end-position-atpt")))))
    (th-check 'ml-text arg ispec)))
   

;;;###autoload
(defun multibyte-atpt (&optional arg ispec) 
  "Returns multibyte at point if any, nil otherwise"
  (interactive "P\np")
  (th 'multibyte arg ispec))

(defalias 'bounds-of-multibyte-atpt 'multibyte-bounds-atpt)
;;;###autoload
(defun multibyte-bounds-atpt (&optional arg ispec) 
  "Returns borders of multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'multibyte arg ispec))

;;;###autoload
(defun multibyte-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'multibyte arg ispec))

;;;###autoload
(defun multibyte-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'multibyte arg ispec))

(defalias 'beginning-of-multibyte-atpt 'multibyte-beginning-atpt)
;;;###autoload
(defun multibyte-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'multibyte arg ispec))

(defalias 'end-of-multibyte-atpt 'multibyte-end-atpt)
;;;###autoload
(defun multibyte-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'multibyte arg ispec))

(defalias 'length-of-multibyte-atpt 'multibyte-length-atpt)
;;;###autoload
(defun multibyte-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'multibyte arg ispec))

(defalias 'copy-multibyte-atpt 'multibyte-copy-atpt)
;;;###autoload
(defun multibyte-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'multibyte arg ispec))

(defalias 'escape-multibyte-atpt 'multibyte-escape-atpt)
;;;###autoload
(defun multibyte-escape-atpt (arg) 
  "Makes a copy of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'multibyte arg))

(defalias 'doublequote-multibyte-atpt 'multibyte-doublequote-atpt)
;;;###autoload
(defun multibyte-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'multibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'multibyte arg ispec))

(defalias 'dollar-multibyte-atpt 'multibyte-dollar-atpt)
;;;###autoload
(defun multibyte-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'multibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'multibyte arg ispec))

(defalias 'backslash-multibyte-atpt 'multibyte-backslash-atpt)
;;;###autoload
(defun multibyte-backslash-atpt (&optional arg ispec) 
  "Backslash 'multibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'multibyte arg ispec)) 

(defalias 'brace-multibyte-atpt 'multibyte-brace-atpt)
;;;###autoload
(defun multibyte-brace-atpt (&optional arg ispec) 
  "Braces 'multibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'multibyte arg ispec))

(defalias 'bracket-multibyte-atpt 'multibyte-bracket-atpt)
;;;###autoload
(defun multibyte-bracket-atpt (&optional arg ispec) 
  "Brackets 'multibyte after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'multibyte arg ispec))

(defalias 'commented-multibyte-atpt 'multibyte-comment-atpt)
;;;###autoload
(defun multibyte-comment-atpt (&optional arg ispec) 
  "Comments 'multibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'multibyte arg ispec))

(defalias 'mark-multibyte-atpt 'multibyte-mark-atpt)
;;;###autoload
(defun multibyte-mark-atpt (&optional arg) 
  "Marks 'multibyte at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'multibyte arg))

(defalias 'kill-multibyte-atpt 'multibyte-kill-atpt)
;;;###autoload
(defun multibyte-kill-atpt (arg)
  "Kills multibyte at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'multibyte arg))

(defalias 'parentize-multibyte-atpt 'multibyte-parentize-atpt)
;;;###autoload
(defun multibyte-parentize-atpt (&optional arg ispec) 
  "Parentizes 'multibyte at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'multibyte arg ispec))

(defalias 'separate-multibyte-atpt 'multibyte-separate-atpt)
;;;###autoload
(defun multibyte-separate-atpt (&optional arg ispec) 
  "Separates 'multibyte at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'multibyte arg ispec))

(defalias 'singlequote-multibyte-atpt 'multibyte-singlequote-atpt)
;;;###autoload
(defun multibyte-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'multibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'multibyte arg ispec))

(defalias 'slash-multibyte-atpt 'multibyte-slash-atpt)
;;;###autoload
(defun multibyte-slash-atpt (&optional arg ispec) 
  "Slash 'multibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'multibyte arg ispec))

(defalias 'trim-multibyte-atpt 'multibyte-trim-atpt)
;;;###autoload
(defun multibyte-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'multibyte t t))

(defalias 'trim-multibyte-left-atpt 'multibyte-left-trim-atpt)
;;;###autoload
(defun multibyte-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'multibyte t nil))

(defalias 'trim-multibyte-right-atpt 'multibyte-right-trim-atpt)
;;;###autoload
(defun multibyte-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'multibyte nil t))

(defalias 'forward-multibyte-atpt 'multibyte-forward-atpt)
;;;###autoload
(defun multibyte-forward-atpt (&optional arg ispec) 
  "Moves forward over multibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'multibyte arg ispec))

(defalias 'backward-multibyte-atpt 'multibyte-backward-atpt)
;;;###autoload
(defun multibyte-backward-atpt (&optional arg ispec) 
  "Moves backward over multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'multibyte arg ispec))

(defalias 'transpose-multibyte-atpt 'multibyte-transpose-atpt)
;;;###autoload
(defun multibyte-transpose-atpt (&optional arg) 
  "Transposes multibyte with multibyte before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'multibyte arg))

(defalias 'sort-multibyte-atpt 'multibyte-sort-atpt)
;;;###autoload
(defun multibyte-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts multibyte's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'multibyte reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-multibyte-atpt 'multibyte-check-atpt)
;;;###autoload
(defun multibyte-check-atpt (&optional arg ispec) 
  " multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "multibyte" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "multibyte" "-end-position-atpt")))))
    (th-check 'multibyte arg ispec)))
   

;;;###autoload
(defun nonascii-atpt (&optional arg ispec) 
  "Returns nonascii at point if any, nil otherwise"
  (interactive "P\np")
  (th 'nonascii arg ispec))

(defalias 'bounds-of-nonascii-atpt 'nonascii-bounds-atpt)
;;;###autoload
(defun nonascii-bounds-atpt (&optional arg ispec) 
  "Returns borders of nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'nonascii arg ispec))

;;;###autoload
(defun nonascii-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'nonascii arg ispec))

;;;###autoload
(defun nonascii-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'nonascii arg ispec))

(defalias 'beginning-of-nonascii-atpt 'nonascii-beginning-atpt)
;;;###autoload
(defun nonascii-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'nonascii arg ispec))

(defalias 'end-of-nonascii-atpt 'nonascii-end-atpt)
;;;###autoload
(defun nonascii-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'nonascii arg ispec))

(defalias 'length-of-nonascii-atpt 'nonascii-length-atpt)
;;;###autoload
(defun nonascii-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'nonascii arg ispec))

(defalias 'copy-nonascii-atpt 'nonascii-copy-atpt)
;;;###autoload
(defun nonascii-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'nonascii arg ispec))

(defalias 'escape-nonascii-atpt 'nonascii-escape-atpt)
;;;###autoload
(defun nonascii-escape-atpt (arg) 
  "Makes a copy of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'nonascii arg))

(defalias 'doublequote-nonascii-atpt 'nonascii-doublequote-atpt)
;;;###autoload
(defun nonascii-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'nonascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'nonascii arg ispec))

(defalias 'dollar-nonascii-atpt 'nonascii-dollar-atpt)
;;;###autoload
(defun nonascii-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'nonascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'nonascii arg ispec))

(defalias 'backslash-nonascii-atpt 'nonascii-backslash-atpt)
;;;###autoload
(defun nonascii-backslash-atpt (&optional arg ispec) 
  "Backslash 'nonascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'nonascii arg ispec)) 

(defalias 'brace-nonascii-atpt 'nonascii-brace-atpt)
;;;###autoload
(defun nonascii-brace-atpt (&optional arg ispec) 
  "Braces 'nonascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'nonascii arg ispec))

(defalias 'bracket-nonascii-atpt 'nonascii-bracket-atpt)
;;;###autoload
(defun nonascii-bracket-atpt (&optional arg ispec) 
  "Brackets 'nonascii after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'nonascii arg ispec))

(defalias 'commented-nonascii-atpt 'nonascii-comment-atpt)
;;;###autoload
(defun nonascii-comment-atpt (&optional arg ispec) 
  "Comments 'nonascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'nonascii arg ispec))

(defalias 'mark-nonascii-atpt 'nonascii-mark-atpt)
;;;###autoload
(defun nonascii-mark-atpt (&optional arg) 
  "Marks 'nonascii at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'nonascii arg))

(defalias 'kill-nonascii-atpt 'nonascii-kill-atpt)
;;;###autoload
(defun nonascii-kill-atpt (arg)
  "Kills nonascii at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'nonascii arg))

(defalias 'parentize-nonascii-atpt 'nonascii-parentize-atpt)
;;;###autoload
(defun nonascii-parentize-atpt (&optional arg ispec) 
  "Parentizes 'nonascii at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'nonascii arg ispec))

(defalias 'separate-nonascii-atpt 'nonascii-separate-atpt)
;;;###autoload
(defun nonascii-separate-atpt (&optional arg ispec) 
  "Separates 'nonascii at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'nonascii arg ispec))

(defalias 'singlequote-nonascii-atpt 'nonascii-singlequote-atpt)
;;;###autoload
(defun nonascii-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'nonascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'nonascii arg ispec))

(defalias 'slash-nonascii-atpt 'nonascii-slash-atpt)
;;;###autoload
(defun nonascii-slash-atpt (&optional arg ispec) 
  "Slash 'nonascii at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'nonascii arg ispec))

(defalias 'trim-nonascii-atpt 'nonascii-trim-atpt)
;;;###autoload
(defun nonascii-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'nonascii t t))

(defalias 'trim-nonascii-left-atpt 'nonascii-left-trim-atpt)
;;;###autoload
(defun nonascii-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'nonascii t nil))

(defalias 'trim-nonascii-right-atpt 'nonascii-right-trim-atpt)
;;;###autoload
(defun nonascii-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'nonascii nil t))

(defalias 'forward-nonascii-atpt 'nonascii-forward-atpt)
;;;###autoload
(defun nonascii-forward-atpt (&optional arg ispec) 
  "Moves forward over nonascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'nonascii arg ispec))

(defalias 'backward-nonascii-atpt 'nonascii-backward-atpt)
;;;###autoload
(defun nonascii-backward-atpt (&optional arg ispec) 
  "Moves backward over nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'nonascii arg ispec))

(defalias 'transpose-nonascii-atpt 'nonascii-transpose-atpt)
;;;###autoload
(defun nonascii-transpose-atpt (&optional arg) 
  "Transposes nonascii with nonascii before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'nonascii arg))

(defalias 'sort-nonascii-atpt 'nonascii-sort-atpt)
;;;###autoload
(defun nonascii-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts nonascii's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'nonascii reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-nonascii-atpt 'nonascii-check-atpt)
;;;###autoload
(defun nonascii-check-atpt (&optional arg ispec) 
  " nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "nonascii" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "nonascii" "-end-position-atpt")))))
    (th-check 'nonascii arg ispec)))
   

;;;###autoload
(defun number-atpt (&optional arg ispec) 
  "Returns number at point if any, nil otherwise"
  (interactive "P\np")
  (th 'number arg ispec))

(defalias 'bounds-of-number-atpt 'number-bounds-atpt)
;;;###autoload
(defun number-bounds-atpt (&optional arg ispec) 
  "Returns borders of number at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'number arg ispec))

;;;###autoload
(defun number-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'number arg ispec))

;;;###autoload
(defun number-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'number arg ispec))

(defalias 'beginning-of-number-atpt 'number-beginning-atpt)
;;;###autoload
(defun number-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'number arg ispec))

(defalias 'end-of-number-atpt 'number-end-atpt)
;;;###autoload
(defun number-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'number arg ispec))

(defalias 'length-of-number-atpt 'number-length-atpt)
;;;###autoload
(defun number-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'number arg ispec))

(defalias 'copy-number-atpt 'number-copy-atpt)
;;;###autoload
(defun number-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'number arg ispec))

(defalias 'escape-number-atpt 'number-escape-atpt)
;;;###autoload
(defun number-escape-atpt (arg) 
  "Makes a copy of symbol or char-class number at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'number arg))

(defalias 'doublequote-number-atpt 'number-doublequote-atpt)
;;;###autoload
(defun number-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'number at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'number arg ispec))

(defalias 'dollar-number-atpt 'number-dollar-atpt)
;;;###autoload
(defun number-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'number at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'number arg ispec))

(defalias 'backslash-number-atpt 'number-backslash-atpt)
;;;###autoload
(defun number-backslash-atpt (&optional arg ispec) 
  "Backslash 'number at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'number arg ispec)) 

(defalias 'brace-number-atpt 'number-brace-atpt)
;;;###autoload
(defun number-brace-atpt (&optional arg ispec) 
  "Braces 'number at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'number arg ispec))

(defalias 'bracket-number-atpt 'number-bracket-atpt)
;;;###autoload
(defun number-bracket-atpt (&optional arg ispec) 
  "Brackets 'number after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'number arg ispec))

(defalias 'commented-number-atpt 'number-comment-atpt)
;;;###autoload
(defun number-comment-atpt (&optional arg ispec) 
  "Comments 'number at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'number arg ispec))

(defalias 'mark-number-atpt 'number-mark-atpt)
;;;###autoload
(defun number-mark-atpt (&optional arg) 
  "Marks 'number at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'number arg))

(defalias 'kill-number-atpt 'number-kill-atpt)
;;;###autoload
(defun number-kill-atpt (arg)
  "Kills number at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'number arg))

(defalias 'parentize-number-atpt 'number-parentize-atpt)
;;;###autoload
(defun number-parentize-atpt (&optional arg ispec) 
  "Parentizes 'number at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'number arg ispec))

(defalias 'separate-number-atpt 'number-separate-atpt)
;;;###autoload
(defun number-separate-atpt (&optional arg ispec) 
  "Separates 'number at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'number arg ispec))

(defalias 'singlequote-number-atpt 'number-singlequote-atpt)
;;;###autoload
(defun number-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'number at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'number arg ispec))

(defalias 'slash-number-atpt 'number-slash-atpt)
;;;###autoload
(defun number-slash-atpt (&optional arg ispec) 
  "Slash 'number at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'number arg ispec))

(defalias 'trim-number-atpt 'number-trim-atpt)
;;;###autoload
(defun number-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'number t t))

(defalias 'trim-number-left-atpt 'number-left-trim-atpt)
;;;###autoload
(defun number-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'number t nil))

(defalias 'trim-number-right-atpt 'number-right-trim-atpt)
;;;###autoload
(defun number-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'number nil t))

(defalias 'forward-number-atpt 'number-forward-atpt)
;;;###autoload
(defun number-forward-atpt (&optional arg ispec) 
  "Moves forward over number at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'number arg ispec))

(defalias 'backward-number-atpt 'number-backward-atpt)
;;;###autoload
(defun number-backward-atpt (&optional arg ispec) 
  "Moves backward over number before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'number arg ispec))

(defalias 'transpose-number-atpt 'number-transpose-atpt)
;;;###autoload
(defun number-transpose-atpt (&optional arg) 
  "Transposes number with number before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'number arg))

(defalias 'sort-number-atpt 'number-sort-atpt)
;;;###autoload
(defun number-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts number's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'number reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-number-atpt 'number-check-atpt)
;;;###autoload
(defun number-check-atpt (&optional arg ispec) 
  " number at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "number" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "number" "-end-position-atpt")))))
    (th-check 'number arg ispec)))
   

;;;###autoload
(defun page-atpt (&optional arg ispec) 
  "Returns page at point if any, nil otherwise"
  (interactive "P\np")
  (th 'page arg ispec))

(defalias 'bounds-of-page-atpt 'page-bounds-atpt)
;;;###autoload
(defun page-bounds-atpt (&optional arg ispec) 
  "Returns borders of page at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'page arg ispec))

;;;###autoload
(defun page-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'page arg ispec))

;;;###autoload
(defun page-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'page arg ispec))

(defalias 'beginning-of-page-atpt 'page-beginning-atpt)
;;;###autoload
(defun page-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'page arg ispec))

(defalias 'end-of-page-atpt 'page-end-atpt)
;;;###autoload
(defun page-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'page arg ispec))

(defalias 'length-of-page-atpt 'page-length-atpt)
;;;###autoload
(defun page-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'page arg ispec))

(defalias 'copy-page-atpt 'page-copy-atpt)
;;;###autoload
(defun page-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'page arg ispec))

(defalias 'escape-page-atpt 'page-escape-atpt)
;;;###autoload
(defun page-escape-atpt (arg) 
  "Makes a copy of symbol or char-class page at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'page arg))

(defalias 'doublequote-page-atpt 'page-doublequote-atpt)
;;;###autoload
(defun page-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'page at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'page arg ispec))

(defalias 'dollar-page-atpt 'page-dollar-atpt)
;;;###autoload
(defun page-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'page at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'page arg ispec))

(defalias 'backslash-page-atpt 'page-backslash-atpt)
;;;###autoload
(defun page-backslash-atpt (&optional arg ispec) 
  "Backslash 'page at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'page arg ispec)) 

(defalias 'brace-page-atpt 'page-brace-atpt)
;;;###autoload
(defun page-brace-atpt (&optional arg ispec) 
  "Braces 'page at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'page arg ispec))

(defalias 'bracket-page-atpt 'page-bracket-atpt)
;;;###autoload
(defun page-bracket-atpt (&optional arg ispec) 
  "Brackets 'page after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'page arg ispec))

(defalias 'commented-page-atpt 'page-comment-atpt)
;;;###autoload
(defun page-comment-atpt (&optional arg ispec) 
  "Comments 'page at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'page arg ispec))

(defalias 'mark-page-atpt 'page-mark-atpt)
;;;###autoload
(defun page-mark-atpt (&optional arg) 
  "Marks 'page at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'page arg))

(defalias 'kill-page-atpt 'page-kill-atpt)
;;;###autoload
(defun page-kill-atpt (arg)
  "Kills page at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'page arg))

(defalias 'parentize-page-atpt 'page-parentize-atpt)
;;;###autoload
(defun page-parentize-atpt (&optional arg ispec) 
  "Parentizes 'page at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'page arg ispec))

(defalias 'separate-page-atpt 'page-separate-atpt)
;;;###autoload
(defun page-separate-atpt (&optional arg ispec) 
  "Separates 'page at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'page arg ispec))

(defalias 'singlequote-page-atpt 'page-singlequote-atpt)
;;;###autoload
(defun page-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'page at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'page arg ispec))

(defalias 'slash-page-atpt 'page-slash-atpt)
;;;###autoload
(defun page-slash-atpt (&optional arg ispec) 
  "Slash 'page at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'page arg ispec))

(defalias 'trim-page-atpt 'page-trim-atpt)
;;;###autoload
(defun page-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'page t t))

(defalias 'trim-page-left-atpt 'page-left-trim-atpt)
;;;###autoload
(defun page-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'page t nil))

(defalias 'trim-page-right-atpt 'page-right-trim-atpt)
;;;###autoload
(defun page-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'page nil t))

(defalias 'forward-page-atpt 'page-forward-atpt)
;;;###autoload
(defun page-forward-atpt (&optional arg ispec) 
  "Moves forward over page at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'page arg ispec))

(defalias 'backward-page-atpt 'page-backward-atpt)
;;;###autoload
(defun page-backward-atpt (&optional arg ispec) 
  "Moves backward over page before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'page arg ispec))

(defalias 'transpose-page-atpt 'page-transpose-atpt)
;;;###autoload
(defun page-transpose-atpt (&optional arg) 
  "Transposes page with page before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'page arg))

(defalias 'sort-page-atpt 'page-sort-atpt)
;;;###autoload
(defun page-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts page's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'page reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-page-atpt 'page-check-atpt)
;;;###autoload
(defun page-check-atpt (&optional arg ispec) 
  " page at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "page" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "page" "-end-position-atpt")))))
    (th-check 'page arg ispec)))
   

;;;###autoload
(defun paragraph-atpt (&optional arg ispec) 
  "Returns paragraph at point if any, nil otherwise"
  (interactive "P\np")
  (th 'paragraph arg ispec))

(defalias 'bounds-of-paragraph-atpt 'paragraph-bounds-atpt)
;;;###autoload
(defun paragraph-bounds-atpt (&optional arg ispec) 
  "Returns borders of paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'paragraph arg ispec))

;;;###autoload
(defun paragraph-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'paragraph arg ispec))

;;;###autoload
(defun paragraph-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'paragraph arg ispec))

(defalias 'beginning-of-paragraph-atpt 'paragraph-beginning-atpt)
;;;###autoload
(defun paragraph-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'paragraph arg ispec))

(defalias 'end-of-paragraph-atpt 'paragraph-end-atpt)
;;;###autoload
(defun paragraph-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'paragraph arg ispec))

(defalias 'length-of-paragraph-atpt 'paragraph-length-atpt)
;;;###autoload
(defun paragraph-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'paragraph arg ispec))

(defalias 'copy-paragraph-atpt 'paragraph-copy-atpt)
;;;###autoload
(defun paragraph-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'paragraph arg ispec))

(defalias 'escape-paragraph-atpt 'paragraph-escape-atpt)
;;;###autoload
(defun paragraph-escape-atpt (arg) 
  "Makes a copy of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'paragraph arg))

(defalias 'doublequote-paragraph-atpt 'paragraph-doublequote-atpt)
;;;###autoload
(defun paragraph-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'paragraph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'paragraph arg ispec))

(defalias 'dollar-paragraph-atpt 'paragraph-dollar-atpt)
;;;###autoload
(defun paragraph-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'paragraph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'paragraph arg ispec))

(defalias 'backslash-paragraph-atpt 'paragraph-backslash-atpt)
;;;###autoload
(defun paragraph-backslash-atpt (&optional arg ispec) 
  "Backslash 'paragraph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'paragraph arg ispec)) 

(defalias 'brace-paragraph-atpt 'paragraph-brace-atpt)
;;;###autoload
(defun paragraph-brace-atpt (&optional arg ispec) 
  "Braces 'paragraph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'paragraph arg ispec))

(defalias 'bracket-paragraph-atpt 'paragraph-bracket-atpt)
;;;###autoload
(defun paragraph-bracket-atpt (&optional arg ispec) 
  "Brackets 'paragraph after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'paragraph arg ispec))

(defalias 'commented-paragraph-atpt 'paragraph-comment-atpt)
;;;###autoload
(defun paragraph-comment-atpt (&optional arg ispec) 
  "Comments 'paragraph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'paragraph arg ispec))

(defalias 'mark-paragraph-atpt 'paragraph-mark-atpt)
;;;###autoload
(defun paragraph-mark-atpt (&optional arg) 
  "Marks 'paragraph at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'paragraph arg))

(defalias 'kill-paragraph-atpt 'paragraph-kill-atpt)
;;;###autoload
(defun paragraph-kill-atpt (arg)
  "Kills paragraph at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'paragraph arg))

(defalias 'parentize-paragraph-atpt 'paragraph-parentize-atpt)
;;;###autoload
(defun paragraph-parentize-atpt (&optional arg ispec) 
  "Parentizes 'paragraph at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'paragraph arg ispec))

(defalias 'separate-paragraph-atpt 'paragraph-separate-atpt)
;;;###autoload
(defun paragraph-separate-atpt (&optional arg ispec) 
  "Separates 'paragraph at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'paragraph arg ispec))

(defalias 'singlequote-paragraph-atpt 'paragraph-singlequote-atpt)
;;;###autoload
(defun paragraph-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'paragraph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'paragraph arg ispec))

(defalias 'slash-paragraph-atpt 'paragraph-slash-atpt)
;;;###autoload
(defun paragraph-slash-atpt (&optional arg ispec) 
  "Slash 'paragraph at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'paragraph arg ispec))

(defalias 'trim-paragraph-atpt 'paragraph-trim-atpt)
;;;###autoload
(defun paragraph-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'paragraph t t))

(defalias 'trim-paragraph-left-atpt 'paragraph-left-trim-atpt)
;;;###autoload
(defun paragraph-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'paragraph t nil))

(defalias 'trim-paragraph-right-atpt 'paragraph-right-trim-atpt)
;;;###autoload
(defun paragraph-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'paragraph nil t))

(defalias 'forward-paragraph-atpt 'paragraph-forward-atpt)
;;;###autoload
(defun paragraph-forward-atpt (&optional arg ispec) 
  "Moves forward over paragraph at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'paragraph arg ispec))

(defalias 'backward-paragraph-atpt 'paragraph-backward-atpt)
;;;###autoload
(defun paragraph-backward-atpt (&optional arg ispec) 
  "Moves backward over paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'paragraph arg ispec))

(defalias 'transpose-paragraph-atpt 'paragraph-transpose-atpt)
;;;###autoload
(defun paragraph-transpose-atpt (&optional arg) 
  "Transposes paragraph with paragraph before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'paragraph arg))

(defalias 'sort-paragraph-atpt 'paragraph-sort-atpt)
;;;###autoload
(defun paragraph-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts paragraph's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'paragraph reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-paragraph-atpt 'paragraph-check-atpt)
;;;###autoload
(defun paragraph-check-atpt (&optional arg ispec) 
  " paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "paragraph" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "paragraph" "-end-position-atpt")))))
    (th-check 'paragraph arg ispec)))
   

;;;###autoload
(defun paren-atpt (&optional arg ispec) 
  "Returns paren at point if any, nil otherwise"
  (interactive "P\np")
  (th 'paren arg ispec))

(defalias 'bounds-of-paren-atpt 'paren-bounds-atpt)
;;;###autoload
(defun paren-bounds-atpt (&optional arg ispec) 
  "Returns borders of paren at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'paren arg ispec))

;;;###autoload
(defun paren-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class paren at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'paren arg ispec))

;;;###autoload
(defun paren-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class paren at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'paren arg ispec))

(defalias 'beginning-of-paren-atpt 'paren-beginning-atpt)
;;;###autoload
(defun paren-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class paren at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'paren arg ispec))

(defalias 'end-of-paren-atpt 'paren-end-atpt)
;;;###autoload
(defun paren-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class paren at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'paren arg ispec))

(defalias 'length-of-paren-atpt 'paren-length-atpt)
;;;###autoload
(defun paren-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class paren at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'paren arg ispec))

(defalias 'copy-paren-atpt 'paren-copy-atpt)
;;;###autoload
(defun paren-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class paren at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'paren arg ispec))

(defalias 'escape-paren-atpt 'paren-escape-atpt)
;;;###autoload
(defun paren-escape-atpt (arg) 
  "Makes a copy of symbol or char-class paren at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'paren arg))

(defalias 'doublequote-paren-atpt 'paren-doublequote-atpt)
;;;###autoload
(defun paren-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'paren at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'paren arg ispec))

(defalias 'dollar-paren-atpt 'paren-dollar-atpt)
;;;###autoload
(defun paren-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'paren at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'paren arg ispec))

(defalias 'backslash-paren-atpt 'paren-backslash-atpt)
;;;###autoload
(defun paren-backslash-atpt (&optional arg ispec) 
  "Backslash 'paren at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'paren arg ispec)) 

(defalias 'brace-paren-atpt 'paren-brace-atpt)
;;;###autoload
(defun paren-brace-atpt (&optional arg ispec) 
  "Braces 'paren at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'paren arg ispec))

(defalias 'bracket-paren-atpt 'paren-bracket-atpt)
;;;###autoload
(defun paren-bracket-atpt (&optional arg ispec) 
  "Brackets 'paren after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'paren arg ispec))

(defalias 'commented-paren-atpt 'paren-comment-atpt)
;;;###autoload
(defun paren-comment-atpt (&optional arg ispec) 
  "Comments 'paren at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'paren arg ispec))

(defalias 'mark-paren-atpt 'paren-mark-atpt)
;;;###autoload
(defun paren-mark-atpt (&optional arg) 
  "Marks 'paren at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'paren arg))

(defalias 'kill-paren-atpt 'paren-kill-atpt)
;;;###autoload
(defun paren-kill-atpt (arg)
  "Kills paren at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'paren arg))

(defalias 'parentize-paren-atpt 'paren-parentize-atpt)
;;;###autoload
(defun paren-parentize-atpt (&optional arg ispec) 
  "Parentizes 'paren at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'paren arg ispec))

(defalias 'separate-paren-atpt 'paren-separate-atpt)
;;;###autoload
(defun paren-separate-atpt (&optional arg ispec) 
  "Separates 'paren at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'paren arg ispec))

(defalias 'singlequote-paren-atpt 'paren-singlequote-atpt)
;;;###autoload
(defun paren-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'paren at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'paren arg ispec))

(defalias 'slash-paren-atpt 'paren-slash-atpt)
;;;###autoload
(defun paren-slash-atpt (&optional arg ispec) 
  "Slash 'paren at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'paren arg ispec))

(defalias 'trim-paren-atpt 'paren-trim-atpt)
;;;###autoload
(defun paren-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'paren t t))

(defalias 'trim-paren-left-atpt 'paren-left-trim-atpt)
;;;###autoload
(defun paren-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'paren t nil))

(defalias 'trim-paren-right-atpt 'paren-right-trim-atpt)
;;;###autoload
(defun paren-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'paren nil t))

(defalias 'forward-paren-atpt 'paren-forward-atpt)
;;;###autoload
(defun paren-forward-atpt (&optional arg ispec) 
  "Moves forward over paren at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'paren arg ispec))

(defalias 'backward-paren-atpt 'paren-backward-atpt)
;;;###autoload
(defun paren-backward-atpt (&optional arg ispec) 
  "Moves backward over paren before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'paren arg ispec))

(defalias 'transpose-paren-atpt 'paren-transpose-atpt)
;;;###autoload
(defun paren-transpose-atpt (&optional arg) 
  "Transposes paren with paren before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'paren arg))

(defalias 'sort-paren-atpt 'paren-sort-atpt)
;;;###autoload
(defun paren-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts paren's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'paren reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-paren-atpt 'paren-check-atpt)
;;;###autoload
(defun paren-check-atpt (&optional arg ispec) 
  " paren at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "paren" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "paren" "-end-position-atpt")))))
    (th-check 'paren arg ispec)))
   

;;;###autoload
(defun parentized-atpt (&optional arg ispec) 
  "Returns parentized at point if any, nil otherwise"
  (interactive "P\np")
  (th 'parentized arg ispec))

(defalias 'bounds-of-parentized-atpt 'parentized-bounds-atpt)
;;;###autoload
(defun parentized-bounds-atpt (&optional arg ispec) 
  "Returns borders of parentized at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'parentized arg ispec))

;;;###autoload
(defun parentized-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class parentized at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'parentized arg ispec))

;;;###autoload
(defun parentized-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class parentized at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'parentized arg ispec))

(defalias 'beginning-of-parentized-atpt 'parentized-beginning-atpt)
;;;###autoload
(defun parentized-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class parentized at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'parentized arg ispec))

(defalias 'end-of-parentized-atpt 'parentized-end-atpt)
;;;###autoload
(defun parentized-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class parentized at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'parentized arg ispec))

(defalias 'length-of-parentized-atpt 'parentized-length-atpt)
;;;###autoload
(defun parentized-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class parentized at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'parentized arg ispec))

(defalias 'copy-parentized-atpt 'parentized-copy-atpt)
;;;###autoload
(defun parentized-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class parentized at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'parentized arg ispec))

(defalias 'escape-parentized-atpt 'parentized-escape-atpt)
;;;###autoload
(defun parentized-escape-atpt (arg) 
  "Makes a copy of symbol or char-class parentized at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'parentized arg))

(defalias 'doublequote-parentized-atpt 'parentized-doublequote-atpt)
;;;###autoload
(defun parentized-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'parentized at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'parentized arg ispec))

(defalias 'dollar-parentized-atpt 'parentized-dollar-atpt)
;;;###autoload
(defun parentized-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'parentized at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'parentized arg ispec))

(defalias 'backslash-parentized-atpt 'parentized-backslash-atpt)
;;;###autoload
(defun parentized-backslash-atpt (&optional arg ispec) 
  "Backslash 'parentized at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'parentized arg ispec)) 

(defalias 'brace-parentized-atpt 'parentized-brace-atpt)
;;;###autoload
(defun parentized-brace-atpt (&optional arg ispec) 
  "Braces 'parentized at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'parentized arg ispec))

(defalias 'bracket-parentized-atpt 'parentized-bracket-atpt)
;;;###autoload
(defun parentized-bracket-atpt (&optional arg ispec) 
  "Brackets 'parentized after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'parentized arg ispec))

(defalias 'commented-parentized-atpt 'parentized-comment-atpt)
;;;###autoload
(defun parentized-comment-atpt (&optional arg ispec) 
  "Comments 'parentized at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'parentized arg ispec))

(defalias 'mark-parentized-atpt 'parentized-mark-atpt)
;;;###autoload
(defun parentized-mark-atpt (&optional arg) 
  "Marks 'parentized at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'parentized arg))

(defalias 'kill-parentized-atpt 'parentized-kill-atpt)
;;;###autoload
(defun parentized-kill-atpt (arg)
  "Kills parentized at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'parentized arg))

(defalias 'parentize-parentized-atpt 'parentized-parentize-atpt)
;;;###autoload
(defun parentized-parentize-atpt (&optional arg ispec) 
  "Parentizes 'parentized at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'parentized arg ispec))

(defalias 'separate-parentized-atpt 'parentized-separate-atpt)
;;;###autoload
(defun parentized-separate-atpt (&optional arg ispec) 
  "Separates 'parentized at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'parentized arg ispec))

(defalias 'singlequote-parentized-atpt 'parentized-singlequote-atpt)
;;;###autoload
(defun parentized-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'parentized at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'parentized arg ispec))

(defalias 'slash-parentized-atpt 'parentized-slash-atpt)
;;;###autoload
(defun parentized-slash-atpt (&optional arg ispec) 
  "Slash 'parentized at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'parentized arg ispec))

(defalias 'trim-parentized-atpt 'parentized-trim-atpt)
;;;###autoload
(defun parentized-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'parentized t t))

(defalias 'trim-parentized-left-atpt 'parentized-left-trim-atpt)
;;;###autoload
(defun parentized-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'parentized t nil))

(defalias 'trim-parentized-right-atpt 'parentized-right-trim-atpt)
;;;###autoload
(defun parentized-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'parentized nil t))

(defalias 'forward-parentized-atpt 'parentized-forward-atpt)
;;;###autoload
(defun parentized-forward-atpt (&optional arg ispec) 
  "Moves forward over parentized at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'parentized arg ispec))

(defalias 'backward-parentized-atpt 'parentized-backward-atpt)
;;;###autoload
(defun parentized-backward-atpt (&optional arg ispec) 
  "Moves backward over parentized before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'parentized arg ispec))

(defalias 'transpose-parentized-atpt 'parentized-transpose-atpt)
;;;###autoload
(defun parentized-transpose-atpt (&optional arg) 
  "Transposes parentized with parentized before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'parentized arg))

(defalias 'sort-parentized-atpt 'parentized-sort-atpt)
;;;###autoload
(defun parentized-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts parentized's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'parentized reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-parentized-atpt 'parentized-check-atpt)
;;;###autoload
(defun parentized-check-atpt (&optional arg ispec) 
  " parentized at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "parentized" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "parentized" "-end-position-atpt")))))
    (th-check 'parentized arg ispec)))
   

;;;###autoload
(defun phone-atpt (&optional arg ispec) 
  "Returns phone at point if any, nil otherwise"
  (interactive "P\np")
  (th 'phone arg ispec))

(defalias 'bounds-of-phone-atpt 'phone-bounds-atpt)
;;;###autoload
(defun phone-bounds-atpt (&optional arg ispec) 
  "Returns borders of phone at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'phone arg ispec))

;;;###autoload
(defun phone-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'phone arg ispec))

;;;###autoload
(defun phone-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'phone arg ispec))

(defalias 'beginning-of-phone-atpt 'phone-beginning-atpt)
;;;###autoload
(defun phone-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'phone arg ispec))

(defalias 'end-of-phone-atpt 'phone-end-atpt)
;;;###autoload
(defun phone-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'phone arg ispec))

(defalias 'length-of-phone-atpt 'phone-length-atpt)
;;;###autoload
(defun phone-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'phone arg ispec))

(defalias 'copy-phone-atpt 'phone-copy-atpt)
;;;###autoload
(defun phone-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'phone arg ispec))

(defalias 'escape-phone-atpt 'phone-escape-atpt)
;;;###autoload
(defun phone-escape-atpt (arg) 
  "Makes a copy of symbol or char-class phone at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'phone arg))

(defalias 'doublequote-phone-atpt 'phone-doublequote-atpt)
;;;###autoload
(defun phone-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'phone at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'phone arg ispec))

(defalias 'dollar-phone-atpt 'phone-dollar-atpt)
;;;###autoload
(defun phone-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'phone at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'phone arg ispec))

(defalias 'backslash-phone-atpt 'phone-backslash-atpt)
;;;###autoload
(defun phone-backslash-atpt (&optional arg ispec) 
  "Backslash 'phone at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'phone arg ispec)) 

(defalias 'brace-phone-atpt 'phone-brace-atpt)
;;;###autoload
(defun phone-brace-atpt (&optional arg ispec) 
  "Braces 'phone at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'phone arg ispec))

(defalias 'bracket-phone-atpt 'phone-bracket-atpt)
;;;###autoload
(defun phone-bracket-atpt (&optional arg ispec) 
  "Brackets 'phone after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'phone arg ispec))

(defalias 'commented-phone-atpt 'phone-comment-atpt)
;;;###autoload
(defun phone-comment-atpt (&optional arg ispec) 
  "Comments 'phone at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'phone arg ispec))

(defalias 'mark-phone-atpt 'phone-mark-atpt)
;;;###autoload
(defun phone-mark-atpt (&optional arg) 
  "Marks 'phone at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'phone arg))

(defalias 'kill-phone-atpt 'phone-kill-atpt)
;;;###autoload
(defun phone-kill-atpt (arg)
  "Kills phone at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'phone arg))

(defalias 'parentize-phone-atpt 'phone-parentize-atpt)
;;;###autoload
(defun phone-parentize-atpt (&optional arg ispec) 
  "Parentizes 'phone at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'phone arg ispec))

(defalias 'separate-phone-atpt 'phone-separate-atpt)
;;;###autoload
(defun phone-separate-atpt (&optional arg ispec) 
  "Separates 'phone at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'phone arg ispec))

(defalias 'singlequote-phone-atpt 'phone-singlequote-atpt)
;;;###autoload
(defun phone-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'phone at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'phone arg ispec))

(defalias 'slash-phone-atpt 'phone-slash-atpt)
;;;###autoload
(defun phone-slash-atpt (&optional arg ispec) 
  "Slash 'phone at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'phone arg ispec))

(defalias 'trim-phone-atpt 'phone-trim-atpt)
;;;###autoload
(defun phone-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'phone t t))

(defalias 'trim-phone-left-atpt 'phone-left-trim-atpt)
;;;###autoload
(defun phone-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'phone t nil))

(defalias 'trim-phone-right-atpt 'phone-right-trim-atpt)
;;;###autoload
(defun phone-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'phone nil t))

(defalias 'forward-phone-atpt 'phone-forward-atpt)
;;;###autoload
(defun phone-forward-atpt (&optional arg ispec) 
  "Moves forward over phone at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'phone arg ispec))

(defalias 'backward-phone-atpt 'phone-backward-atpt)
;;;###autoload
(defun phone-backward-atpt (&optional arg ispec) 
  "Moves backward over phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'phone arg ispec))

(defalias 'transpose-phone-atpt 'phone-transpose-atpt)
;;;###autoload
(defun phone-transpose-atpt (&optional arg) 
  "Transposes phone with phone before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'phone arg))

(defalias 'sort-phone-atpt 'phone-sort-atpt)
;;;###autoload
(defun phone-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts phone's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'phone reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-phone-atpt 'phone-check-atpt)
;;;###autoload
(defun phone-check-atpt (&optional arg ispec) 
  " phone at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "phone" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "phone" "-end-position-atpt")))))
    (th-check 'phone arg ispec)))
   

;;;###autoload
(defun print-atpt (&optional arg ispec) 
  "Returns print at point if any, nil otherwise"
  (interactive "P\np")
  (th 'print arg ispec))

(defalias 'bounds-of-print-atpt 'print-bounds-atpt)
;;;###autoload
(defun print-bounds-atpt (&optional arg ispec) 
  "Returns borders of print at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'print arg ispec))

;;;###autoload
(defun print-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'print arg ispec))

;;;###autoload
(defun print-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'print arg ispec))

(defalias 'beginning-of-print-atpt 'print-beginning-atpt)
;;;###autoload
(defun print-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'print arg ispec))

(defalias 'end-of-print-atpt 'print-end-atpt)
;;;###autoload
(defun print-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'print arg ispec))

(defalias 'length-of-print-atpt 'print-length-atpt)
;;;###autoload
(defun print-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'print arg ispec))

(defalias 'copy-print-atpt 'print-copy-atpt)
;;;###autoload
(defun print-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'print arg ispec))

(defalias 'escape-print-atpt 'print-escape-atpt)
;;;###autoload
(defun print-escape-atpt (arg) 
  "Makes a copy of symbol or char-class print at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'print arg))

(defalias 'doublequote-print-atpt 'print-doublequote-atpt)
;;;###autoload
(defun print-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'print at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'print arg ispec))

(defalias 'dollar-print-atpt 'print-dollar-atpt)
;;;###autoload
(defun print-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'print at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'print arg ispec))

(defalias 'backslash-print-atpt 'print-backslash-atpt)
;;;###autoload
(defun print-backslash-atpt (&optional arg ispec) 
  "Backslash 'print at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'print arg ispec)) 

(defalias 'brace-print-atpt 'print-brace-atpt)
;;;###autoload
(defun print-brace-atpt (&optional arg ispec) 
  "Braces 'print at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'print arg ispec))

(defalias 'bracket-print-atpt 'print-bracket-atpt)
;;;###autoload
(defun print-bracket-atpt (&optional arg ispec) 
  "Brackets 'print after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'print arg ispec))

(defalias 'commented-print-atpt 'print-comment-atpt)
;;;###autoload
(defun print-comment-atpt (&optional arg ispec) 
  "Comments 'print at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'print arg ispec))

(defalias 'mark-print-atpt 'print-mark-atpt)
;;;###autoload
(defun print-mark-atpt (&optional arg) 
  "Marks 'print at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'print arg))

(defalias 'kill-print-atpt 'print-kill-atpt)
;;;###autoload
(defun print-kill-atpt (arg)
  "Kills print at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'print arg))

(defalias 'parentize-print-atpt 'print-parentize-atpt)
;;;###autoload
(defun print-parentize-atpt (&optional arg ispec) 
  "Parentizes 'print at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'print arg ispec))

(defalias 'separate-print-atpt 'print-separate-atpt)
;;;###autoload
(defun print-separate-atpt (&optional arg ispec) 
  "Separates 'print at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'print arg ispec))

(defalias 'singlequote-print-atpt 'print-singlequote-atpt)
;;;###autoload
(defun print-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'print at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'print arg ispec))

(defalias 'slash-print-atpt 'print-slash-atpt)
;;;###autoload
(defun print-slash-atpt (&optional arg ispec) 
  "Slash 'print at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'print arg ispec))

(defalias 'trim-print-atpt 'print-trim-atpt)
;;;###autoload
(defun print-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'print t t))

(defalias 'trim-print-left-atpt 'print-left-trim-atpt)
;;;###autoload
(defun print-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'print t nil))

(defalias 'trim-print-right-atpt 'print-right-trim-atpt)
;;;###autoload
(defun print-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'print nil t))

(defalias 'forward-print-atpt 'print-forward-atpt)
;;;###autoload
(defun print-forward-atpt (&optional arg ispec) 
  "Moves forward over print at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'print arg ispec))

(defalias 'backward-print-atpt 'print-backward-atpt)
;;;###autoload
(defun print-backward-atpt (&optional arg ispec) 
  "Moves backward over print before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'print arg ispec))

(defalias 'transpose-print-atpt 'print-transpose-atpt)
;;;###autoload
(defun print-transpose-atpt (&optional arg) 
  "Transposes print with print before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'print arg))

(defalias 'sort-print-atpt 'print-sort-atpt)
;;;###autoload
(defun print-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts print's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'print reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-print-atpt 'print-check-atpt)
;;;###autoload
(defun print-check-atpt (&optional arg ispec) 
  " print at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "print" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "print" "-end-position-atpt")))))
    (th-check 'print arg ispec)))
   

;;;###autoload
(defun punct-atpt (&optional arg ispec) 
  "Returns punct at point if any, nil otherwise"
  (interactive "P\np")
  (th 'punct arg ispec))

(defalias 'bounds-of-punct-atpt 'punct-bounds-atpt)
;;;###autoload
(defun punct-bounds-atpt (&optional arg ispec) 
  "Returns borders of punct at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'punct arg ispec))

;;;###autoload
(defun punct-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'punct arg ispec))

;;;###autoload
(defun punct-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'punct arg ispec))

(defalias 'beginning-of-punct-atpt 'punct-beginning-atpt)
;;;###autoload
(defun punct-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'punct arg ispec))

(defalias 'end-of-punct-atpt 'punct-end-atpt)
;;;###autoload
(defun punct-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'punct arg ispec))

(defalias 'length-of-punct-atpt 'punct-length-atpt)
;;;###autoload
(defun punct-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'punct arg ispec))

(defalias 'copy-punct-atpt 'punct-copy-atpt)
;;;###autoload
(defun punct-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'punct arg ispec))

(defalias 'escape-punct-atpt 'punct-escape-atpt)
;;;###autoload
(defun punct-escape-atpt (arg) 
  "Makes a copy of symbol or char-class punct at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'punct arg))

(defalias 'doublequote-punct-atpt 'punct-doublequote-atpt)
;;;###autoload
(defun punct-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'punct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'punct arg ispec))

(defalias 'dollar-punct-atpt 'punct-dollar-atpt)
;;;###autoload
(defun punct-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'punct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'punct arg ispec))

(defalias 'backslash-punct-atpt 'punct-backslash-atpt)
;;;###autoload
(defun punct-backslash-atpt (&optional arg ispec) 
  "Backslash 'punct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'punct arg ispec)) 

(defalias 'brace-punct-atpt 'punct-brace-atpt)
;;;###autoload
(defun punct-brace-atpt (&optional arg ispec) 
  "Braces 'punct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'punct arg ispec))

(defalias 'bracket-punct-atpt 'punct-bracket-atpt)
;;;###autoload
(defun punct-bracket-atpt (&optional arg ispec) 
  "Brackets 'punct after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'punct arg ispec))

(defalias 'commented-punct-atpt 'punct-comment-atpt)
;;;###autoload
(defun punct-comment-atpt (&optional arg ispec) 
  "Comments 'punct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'punct arg ispec))

(defalias 'mark-punct-atpt 'punct-mark-atpt)
;;;###autoload
(defun punct-mark-atpt (&optional arg) 
  "Marks 'punct at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'punct arg))

(defalias 'kill-punct-atpt 'punct-kill-atpt)
;;;###autoload
(defun punct-kill-atpt (arg)
  "Kills punct at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'punct arg))

(defalias 'parentize-punct-atpt 'punct-parentize-atpt)
;;;###autoload
(defun punct-parentize-atpt (&optional arg ispec) 
  "Parentizes 'punct at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'punct arg ispec))

(defalias 'separate-punct-atpt 'punct-separate-atpt)
;;;###autoload
(defun punct-separate-atpt (&optional arg ispec) 
  "Separates 'punct at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'punct arg ispec))

(defalias 'singlequote-punct-atpt 'punct-singlequote-atpt)
;;;###autoload
(defun punct-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'punct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'punct arg ispec))

(defalias 'slash-punct-atpt 'punct-slash-atpt)
;;;###autoload
(defun punct-slash-atpt (&optional arg ispec) 
  "Slash 'punct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'punct arg ispec))

(defalias 'trim-punct-atpt 'punct-trim-atpt)
;;;###autoload
(defun punct-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'punct t t))

(defalias 'trim-punct-left-atpt 'punct-left-trim-atpt)
;;;###autoload
(defun punct-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'punct t nil))

(defalias 'trim-punct-right-atpt 'punct-right-trim-atpt)
;;;###autoload
(defun punct-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'punct nil t))

(defalias 'forward-punct-atpt 'punct-forward-atpt)
;;;###autoload
(defun punct-forward-atpt (&optional arg ispec) 
  "Moves forward over punct at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'punct arg ispec))

(defalias 'backward-punct-atpt 'punct-backward-atpt)
;;;###autoload
(defun punct-backward-atpt (&optional arg ispec) 
  "Moves backward over punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'punct arg ispec))

(defalias 'transpose-punct-atpt 'punct-transpose-atpt)
;;;###autoload
(defun punct-transpose-atpt (&optional arg) 
  "Transposes punct with punct before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'punct arg))

(defalias 'sort-punct-atpt 'punct-sort-atpt)
;;;###autoload
(defun punct-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts punct's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'punct reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-punct-atpt 'punct-check-atpt)
;;;###autoload
(defun punct-check-atpt (&optional arg ispec) 
  " punct at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "punct" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "punct" "-end-position-atpt")))))
    (th-check 'punct arg ispec)))
   

;;;###autoload
(defun region-atpt (&optional arg ispec) 
  "Returns region at point if any, nil otherwise"
  (interactive "P\np")
  (th 'region arg ispec))

(defalias 'bounds-of-region-atpt 'region-bounds-atpt)
;;;###autoload
(defun region-bounds-atpt (&optional arg ispec) 
  "Returns borders of region at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'region arg ispec))

;;;###autoload
(defun region-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'region arg ispec))

;;;###autoload
(defun region-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'region arg ispec))

(defalias 'beginning-of-region-atpt 'region-beginning-atpt)
;;;###autoload
(defun region-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'region arg ispec))

(defalias 'end-of-region-atpt 'region-end-atpt)
;;;###autoload
(defun region-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'region arg ispec))

(defalias 'length-of-region-atpt 'region-length-atpt)
;;;###autoload
(defun region-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'region arg ispec))

(defalias 'copy-region-atpt 'region-copy-atpt)
;;;###autoload
(defun region-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'region arg ispec))

(defalias 'escape-region-atpt 'region-escape-atpt)
;;;###autoload
(defun region-escape-atpt (arg) 
  "Makes a copy of symbol or char-class region at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'region arg))

(defalias 'doublequote-region-atpt 'region-doublequote-atpt)
;;;###autoload
(defun region-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'region at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'region arg ispec))

(defalias 'dollar-region-atpt 'region-dollar-atpt)
;;;###autoload
(defun region-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'region at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'region arg ispec))

(defalias 'backslash-region-atpt 'region-backslash-atpt)
;;;###autoload
(defun region-backslash-atpt (&optional arg ispec) 
  "Backslash 'region at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'region arg ispec)) 

(defalias 'brace-region-atpt 'region-brace-atpt)
;;;###autoload
(defun region-brace-atpt (&optional arg ispec) 
  "Braces 'region at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'region arg ispec))

(defalias 'bracket-region-atpt 'region-bracket-atpt)
;;;###autoload
(defun region-bracket-atpt (&optional arg ispec) 
  "Brackets 'region after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'region arg ispec))

(defalias 'commented-region-atpt 'region-comment-atpt)
;;;###autoload
(defun region-comment-atpt (&optional arg ispec) 
  "Comments 'region at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'region arg ispec))

(defalias 'mark-region-atpt 'region-mark-atpt)
;;;###autoload
(defun region-mark-atpt (&optional arg) 
  "Marks 'region at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'region arg))

(defalias 'kill-region-atpt 'region-kill-atpt)
;;;###autoload
(defun region-kill-atpt (arg)
  "Kills region at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'region arg))

(defalias 'parentize-region-atpt 'region-parentize-atpt)
;;;###autoload
(defun region-parentize-atpt (&optional arg ispec) 
  "Parentizes 'region at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'region arg ispec))

(defalias 'separate-region-atpt 'region-separate-atpt)
;;;###autoload
(defun region-separate-atpt (&optional arg ispec) 
  "Separates 'region at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'region arg ispec))

(defalias 'singlequote-region-atpt 'region-singlequote-atpt)
;;;###autoload
(defun region-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'region at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'region arg ispec))

(defalias 'slash-region-atpt 'region-slash-atpt)
;;;###autoload
(defun region-slash-atpt (&optional arg ispec) 
  "Slash 'region at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'region arg ispec))

(defalias 'trim-region-atpt 'region-trim-atpt)
;;;###autoload
(defun region-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'region t t))

(defalias 'trim-region-left-atpt 'region-left-trim-atpt)
;;;###autoload
(defun region-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'region t nil))

(defalias 'trim-region-right-atpt 'region-right-trim-atpt)
;;;###autoload
(defun region-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'region nil t))

(defalias 'forward-region-atpt 'region-forward-atpt)
;;;###autoload
(defun region-forward-atpt (&optional arg ispec) 
  "Moves forward over region at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'region arg ispec))

(defalias 'backward-region-atpt 'region-backward-atpt)
;;;###autoload
(defun region-backward-atpt (&optional arg ispec) 
  "Moves backward over region before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'region arg ispec))

(defalias 'transpose-region-atpt 'region-transpose-atpt)
;;;###autoload
(defun region-transpose-atpt (&optional arg) 
  "Transposes region with region before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'region arg))

(defalias 'sort-region-atpt 'region-sort-atpt)
;;;###autoload
(defun region-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts region's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'region reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-region-atpt 'region-check-atpt)
;;;###autoload
(defun region-check-atpt (&optional arg ispec) 
  " region at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "region" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "region" "-end-position-atpt")))))
    (th-check 'region arg ispec)))
   

;;;###autoload
(defun sentence-atpt (&optional arg ispec) 
  "Returns sentence at point if any, nil otherwise"
  (interactive "P\np")
  (th 'sentence arg ispec))

(defalias 'bounds-of-sentence-atpt 'sentence-bounds-atpt)
;;;###autoload
(defun sentence-bounds-atpt (&optional arg ispec) 
  "Returns borders of sentence at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'sentence arg ispec))

;;;###autoload
(defun sentence-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'sentence arg ispec))

;;;###autoload
(defun sentence-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'sentence arg ispec))

(defalias 'beginning-of-sentence-atpt 'sentence-beginning-atpt)
;;;###autoload
(defun sentence-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'sentence arg ispec))

(defalias 'end-of-sentence-atpt 'sentence-end-atpt)
;;;###autoload
(defun sentence-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'sentence arg ispec))

(defalias 'length-of-sentence-atpt 'sentence-length-atpt)
;;;###autoload
(defun sentence-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'sentence arg ispec))

(defalias 'copy-sentence-atpt 'sentence-copy-atpt)
;;;###autoload
(defun sentence-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'sentence arg ispec))

(defalias 'escape-sentence-atpt 'sentence-escape-atpt)
;;;###autoload
(defun sentence-escape-atpt (arg) 
  "Makes a copy of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'sentence arg))

(defalias 'doublequote-sentence-atpt 'sentence-doublequote-atpt)
;;;###autoload
(defun sentence-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'sentence at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'sentence arg ispec))

(defalias 'dollar-sentence-atpt 'sentence-dollar-atpt)
;;;###autoload
(defun sentence-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'sentence at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'sentence arg ispec))

(defalias 'backslash-sentence-atpt 'sentence-backslash-atpt)
;;;###autoload
(defun sentence-backslash-atpt (&optional arg ispec) 
  "Backslash 'sentence at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'sentence arg ispec)) 

(defalias 'brace-sentence-atpt 'sentence-brace-atpt)
;;;###autoload
(defun sentence-brace-atpt (&optional arg ispec) 
  "Braces 'sentence at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'sentence arg ispec))

(defalias 'bracket-sentence-atpt 'sentence-bracket-atpt)
;;;###autoload
(defun sentence-bracket-atpt (&optional arg ispec) 
  "Brackets 'sentence after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'sentence arg ispec))

(defalias 'commented-sentence-atpt 'sentence-comment-atpt)
;;;###autoload
(defun sentence-comment-atpt (&optional arg ispec) 
  "Comments 'sentence at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'sentence arg ispec))

(defalias 'mark-sentence-atpt 'sentence-mark-atpt)
;;;###autoload
(defun sentence-mark-atpt (&optional arg) 
  "Marks 'sentence at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'sentence arg))

(defalias 'kill-sentence-atpt 'sentence-kill-atpt)
;;;###autoload
(defun sentence-kill-atpt (arg)
  "Kills sentence at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'sentence arg))

(defalias 'parentize-sentence-atpt 'sentence-parentize-atpt)
;;;###autoload
(defun sentence-parentize-atpt (&optional arg ispec) 
  "Parentizes 'sentence at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'sentence arg ispec))

(defalias 'separate-sentence-atpt 'sentence-separate-atpt)
;;;###autoload
(defun sentence-separate-atpt (&optional arg ispec) 
  "Separates 'sentence at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'sentence arg ispec))

(defalias 'singlequote-sentence-atpt 'sentence-singlequote-atpt)
;;;###autoload
(defun sentence-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'sentence at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'sentence arg ispec))

(defalias 'slash-sentence-atpt 'sentence-slash-atpt)
;;;###autoload
(defun sentence-slash-atpt (&optional arg ispec) 
  "Slash 'sentence at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'sentence arg ispec))

(defalias 'trim-sentence-atpt 'sentence-trim-atpt)
;;;###autoload
(defun sentence-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sentence t t))

(defalias 'trim-sentence-left-atpt 'sentence-left-trim-atpt)
;;;###autoload
(defun sentence-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sentence t nil))

(defalias 'trim-sentence-right-atpt 'sentence-right-trim-atpt)
;;;###autoload
(defun sentence-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sentence nil t))

(defalias 'forward-sentence-atpt 'sentence-forward-atpt)
;;;###autoload
(defun sentence-forward-atpt (&optional arg ispec) 
  "Moves forward over sentence at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'sentence arg ispec))

(defalias 'backward-sentence-atpt 'sentence-backward-atpt)
;;;###autoload
(defun sentence-backward-atpt (&optional arg ispec) 
  "Moves backward over sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'sentence arg ispec))

(defalias 'transpose-sentence-atpt 'sentence-transpose-atpt)
;;;###autoload
(defun sentence-transpose-atpt (&optional arg) 
  "Transposes sentence with sentence before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'sentence arg))

(defalias 'sort-sentence-atpt 'sentence-sort-atpt)
;;;###autoload
(defun sentence-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts sentence's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'sentence reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-sentence-atpt 'sentence-check-atpt)
;;;###autoload
(defun sentence-check-atpt (&optional arg ispec) 
  " sentence at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "sentence" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "sentence" "-end-position-atpt")))))
    (th-check 'sentence arg ispec)))
   

;;;###autoload
(defun sexp-atpt (&optional arg ispec) 
  "Returns sexp at point if any, nil otherwise"
  (interactive "P\np")
  (th 'sexp arg ispec))

(defalias 'bounds-of-sexp-atpt 'sexp-bounds-atpt)
;;;###autoload
(defun sexp-bounds-atpt (&optional arg ispec) 
  "Returns borders of sexp at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'sexp arg ispec))

;;;###autoload
(defun sexp-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'sexp arg ispec))

;;;###autoload
(defun sexp-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'sexp arg ispec))

(defalias 'beginning-of-sexp-atpt 'sexp-beginning-atpt)
;;;###autoload
(defun sexp-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'sexp arg ispec))

(defalias 'end-of-sexp-atpt 'sexp-end-atpt)
;;;###autoload
(defun sexp-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'sexp arg ispec))

(defalias 'length-of-sexp-atpt 'sexp-length-atpt)
;;;###autoload
(defun sexp-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'sexp arg ispec))

(defalias 'copy-sexp-atpt 'sexp-copy-atpt)
;;;###autoload
(defun sexp-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'sexp arg ispec))

(defalias 'escape-sexp-atpt 'sexp-escape-atpt)
;;;###autoload
(defun sexp-escape-atpt (arg) 
  "Makes a copy of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'sexp arg))

(defalias 'doublequote-sexp-atpt 'sexp-doublequote-atpt)
;;;###autoload
(defun sexp-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'sexp at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'sexp arg ispec))

(defalias 'dollar-sexp-atpt 'sexp-dollar-atpt)
;;;###autoload
(defun sexp-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'sexp at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'sexp arg ispec))

(defalias 'backslash-sexp-atpt 'sexp-backslash-atpt)
;;;###autoload
(defun sexp-backslash-atpt (&optional arg ispec) 
  "Backslash 'sexp at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'sexp arg ispec)) 

(defalias 'brace-sexp-atpt 'sexp-brace-atpt)
;;;###autoload
(defun sexp-brace-atpt (&optional arg ispec) 
  "Braces 'sexp at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'sexp arg ispec))

(defalias 'bracket-sexp-atpt 'sexp-bracket-atpt)
;;;###autoload
(defun sexp-bracket-atpt (&optional arg ispec) 
  "Brackets 'sexp after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'sexp arg ispec))

(defalias 'commented-sexp-atpt 'sexp-comment-atpt)
;;;###autoload
(defun sexp-comment-atpt (&optional arg ispec) 
  "Comments 'sexp at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'sexp arg ispec))

(defalias 'mark-sexp-atpt 'sexp-mark-atpt)
;;;###autoload
(defun sexp-mark-atpt (&optional arg) 
  "Marks 'sexp at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'sexp arg))

(defalias 'kill-sexp-atpt 'sexp-kill-atpt)
;;;###autoload
(defun sexp-kill-atpt (arg)
  "Kills sexp at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'sexp arg))

(defalias 'parentize-sexp-atpt 'sexp-parentize-atpt)
;;;###autoload
(defun sexp-parentize-atpt (&optional arg ispec) 
  "Parentizes 'sexp at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'sexp arg ispec))

(defalias 'separate-sexp-atpt 'sexp-separate-atpt)
;;;###autoload
(defun sexp-separate-atpt (&optional arg ispec) 
  "Separates 'sexp at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'sexp arg ispec))

(defalias 'singlequote-sexp-atpt 'sexp-singlequote-atpt)
;;;###autoload
(defun sexp-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'sexp at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'sexp arg ispec))

(defalias 'slash-sexp-atpt 'sexp-slash-atpt)
;;;###autoload
(defun sexp-slash-atpt (&optional arg ispec) 
  "Slash 'sexp at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'sexp arg ispec))

(defalias 'trim-sexp-atpt 'sexp-trim-atpt)
;;;###autoload
(defun sexp-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sexp t t))

(defalias 'trim-sexp-left-atpt 'sexp-left-trim-atpt)
;;;###autoload
(defun sexp-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sexp t nil))

(defalias 'trim-sexp-right-atpt 'sexp-right-trim-atpt)
;;;###autoload
(defun sexp-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sexp nil t))

(defalias 'forward-sexp-atpt 'sexp-forward-atpt)
;;;###autoload
(defun sexp-forward-atpt (&optional arg ispec) 
  "Moves forward over sexp at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'sexp arg ispec))

(defalias 'backward-sexp-atpt 'sexp-backward-atpt)
;;;###autoload
(defun sexp-backward-atpt (&optional arg ispec) 
  "Moves backward over sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'sexp arg ispec))

(defalias 'transpose-sexp-atpt 'sexp-transpose-atpt)
;;;###autoload
(defun sexp-transpose-atpt (&optional arg) 
  "Transposes sexp with sexp before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'sexp arg))

(defalias 'sort-sexp-atpt 'sexp-sort-atpt)
;;;###autoload
(defun sexp-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts sexp's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'sexp reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-sexp-atpt 'sexp-check-atpt)
;;;###autoload
(defun sexp-check-atpt (&optional arg ispec) 
  " sexp at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "sexp" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "sexp" "-end-position-atpt")))))
    (th-check 'sexp arg ispec)))
   

;;;###autoload
(defun singlequoted-atpt (&optional arg ispec) 
  "Returns singlequoted at point if any, nil otherwise"
  (interactive "P\np")
  (th 'singlequoted arg ispec))

(defalias 'bounds-of-singlequoted-atpt 'singlequoted-bounds-atpt)
;;;###autoload
(defun singlequoted-bounds-atpt (&optional arg ispec) 
  "Returns borders of singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'singlequoted arg ispec))

;;;###autoload
(defun singlequoted-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'singlequoted arg ispec))

;;;###autoload
(defun singlequoted-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'singlequoted arg ispec))

(defalias 'beginning-of-singlequoted-atpt 'singlequoted-beginning-atpt)
;;;###autoload
(defun singlequoted-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'singlequoted arg ispec))

(defalias 'end-of-singlequoted-atpt 'singlequoted-end-atpt)
;;;###autoload
(defun singlequoted-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'singlequoted arg ispec))

(defalias 'length-of-singlequoted-atpt 'singlequoted-length-atpt)
;;;###autoload
(defun singlequoted-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'singlequoted arg ispec))

(defalias 'copy-singlequoted-atpt 'singlequoted-copy-atpt)
;;;###autoload
(defun singlequoted-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'singlequoted arg ispec))

(defalias 'escape-singlequoted-atpt 'singlequoted-escape-atpt)
;;;###autoload
(defun singlequoted-escape-atpt (arg) 
  "Makes a copy of symbol or char-class singlequoted at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'singlequoted arg))

(defalias 'doublequote-singlequoted-atpt 'singlequoted-doublequote-atpt)
;;;###autoload
(defun singlequoted-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'singlequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'singlequoted arg ispec))

(defalias 'dollar-singlequoted-atpt 'singlequoted-dollar-atpt)
;;;###autoload
(defun singlequoted-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'singlequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'singlequoted arg ispec))

(defalias 'backslash-singlequoted-atpt 'singlequoted-backslash-atpt)
;;;###autoload
(defun singlequoted-backslash-atpt (&optional arg ispec) 
  "Backslash 'singlequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'singlequoted arg ispec)) 

(defalias 'brace-singlequoted-atpt 'singlequoted-brace-atpt)
;;;###autoload
(defun singlequoted-brace-atpt (&optional arg ispec) 
  "Braces 'singlequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'singlequoted arg ispec))

(defalias 'bracket-singlequoted-atpt 'singlequoted-bracket-atpt)
;;;###autoload
(defun singlequoted-bracket-atpt (&optional arg ispec) 
  "Brackets 'singlequoted after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'singlequoted arg ispec))

(defalias 'commented-singlequoted-atpt 'singlequoted-comment-atpt)
;;;###autoload
(defun singlequoted-comment-atpt (&optional arg ispec) 
  "Comments 'singlequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'singlequoted arg ispec))

(defalias 'mark-singlequoted-atpt 'singlequoted-mark-atpt)
;;;###autoload
(defun singlequoted-mark-atpt (&optional arg) 
  "Marks 'singlequoted at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'singlequoted arg))

(defalias 'kill-singlequoted-atpt 'singlequoted-kill-atpt)
;;;###autoload
(defun singlequoted-kill-atpt (arg)
  "Kills singlequoted at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'singlequoted arg))

(defalias 'parentize-singlequoted-atpt 'singlequoted-parentize-atpt)
;;;###autoload
(defun singlequoted-parentize-atpt (&optional arg ispec) 
  "Parentizes 'singlequoted at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'singlequoted arg ispec))

(defalias 'separate-singlequoted-atpt 'singlequoted-separate-atpt)
;;;###autoload
(defun singlequoted-separate-atpt (&optional arg ispec) 
  "Separates 'singlequoted at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'singlequoted arg ispec))

(defalias 'singlequote-singlequoted-atpt 'singlequoted-singlequote-atpt)
;;;###autoload
(defun singlequoted-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'singlequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'singlequoted arg ispec))

(defalias 'slash-singlequoted-atpt 'singlequoted-slash-atpt)
;;;###autoload
(defun singlequoted-slash-atpt (&optional arg ispec) 
  "Slash 'singlequoted at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'singlequoted arg ispec))

(defalias 'trim-singlequoted-atpt 'singlequoted-trim-atpt)
;;;###autoload
(defun singlequoted-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'singlequoted t t))

(defalias 'trim-singlequoted-left-atpt 'singlequoted-left-trim-atpt)
;;;###autoload
(defun singlequoted-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'singlequoted t nil))

(defalias 'trim-singlequoted-right-atpt 'singlequoted-right-trim-atpt)
;;;###autoload
(defun singlequoted-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'singlequoted nil t))

(defalias 'forward-singlequoted-atpt 'singlequoted-forward-atpt)
;;;###autoload
(defun singlequoted-forward-atpt (&optional arg ispec) 
  "Moves forward over singlequoted at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'singlequoted arg ispec))

(defalias 'backward-singlequoted-atpt 'singlequoted-backward-atpt)
;;;###autoload
(defun singlequoted-backward-atpt (&optional arg ispec) 
  "Moves backward over singlequoted before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'singlequoted arg ispec))

(defalias 'transpose-singlequoted-atpt 'singlequoted-transpose-atpt)
;;;###autoload
(defun singlequoted-transpose-atpt (&optional arg) 
  "Transposes singlequoted with singlequoted before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'singlequoted arg))

(defalias 'sort-singlequoted-atpt 'singlequoted-sort-atpt)
;;;###autoload
(defun singlequoted-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts singlequoted's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'singlequoted reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-singlequoted-atpt 'singlequoted-check-atpt)
;;;###autoload
(defun singlequoted-check-atpt (&optional arg ispec) 
  " singlequoted at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "singlequoted" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "singlequoted" "-end-position-atpt")))))
    (th-check 'singlequoted arg ispec)))
   

;;;###autoload
(defun slashed-atpt (&optional arg ispec) 
  "Returns slashed at point if any, nil otherwise"
  (interactive "P\np")
  (th 'slashed arg ispec))

(defalias 'bounds-of-slashed-atpt 'slashed-bounds-atpt)
;;;###autoload
(defun slashed-bounds-atpt (&optional arg ispec) 
  "Returns borders of slashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'slashed arg ispec))

;;;###autoload
(defun slashed-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class slashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'slashed arg ispec))

;;;###autoload
(defun slashed-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class slashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'slashed arg ispec))

(defalias 'beginning-of-slashed-atpt 'slashed-beginning-atpt)
;;;###autoload
(defun slashed-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class slashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'slashed arg ispec))

(defalias 'end-of-slashed-atpt 'slashed-end-atpt)
;;;###autoload
(defun slashed-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class slashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'slashed arg ispec))

(defalias 'length-of-slashed-atpt 'slashed-length-atpt)
;;;###autoload
(defun slashed-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class slashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'slashed arg ispec))

(defalias 'copy-slashed-atpt 'slashed-copy-atpt)
;;;###autoload
(defun slashed-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class slashed at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'slashed arg ispec))

(defalias 'escape-slashed-atpt 'slashed-escape-atpt)
;;;###autoload
(defun slashed-escape-atpt (arg) 
  "Makes a copy of symbol or char-class slashed at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'slashed arg))

(defalias 'doublequote-slashed-atpt 'slashed-doublequote-atpt)
;;;###autoload
(defun slashed-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'slashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'slashed arg ispec))

(defalias 'dollar-slashed-atpt 'slashed-dollar-atpt)
;;;###autoload
(defun slashed-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'slashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'slashed arg ispec))

(defalias 'backslash-slashed-atpt 'slashed-backslash-atpt)
;;;###autoload
(defun slashed-backslash-atpt (&optional arg ispec) 
  "Backslash 'slashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'slashed arg ispec)) 

(defalias 'brace-slashed-atpt 'slashed-brace-atpt)
;;;###autoload
(defun slashed-brace-atpt (&optional arg ispec) 
  "Braces 'slashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'slashed arg ispec))

(defalias 'bracket-slashed-atpt 'slashed-bracket-atpt)
;;;###autoload
(defun slashed-bracket-atpt (&optional arg ispec) 
  "Brackets 'slashed after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'slashed arg ispec))

(defalias 'commented-slashed-atpt 'slashed-comment-atpt)
;;;###autoload
(defun slashed-comment-atpt (&optional arg ispec) 
  "Comments 'slashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'slashed arg ispec))

(defalias 'mark-slashed-atpt 'slashed-mark-atpt)
;;;###autoload
(defun slashed-mark-atpt (&optional arg) 
  "Marks 'slashed at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'slashed arg))

(defalias 'kill-slashed-atpt 'slashed-kill-atpt)
;;;###autoload
(defun slashed-kill-atpt (arg)
  "Kills slashed at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'slashed arg))

(defalias 'parentize-slashed-atpt 'slashed-parentize-atpt)
;;;###autoload
(defun slashed-parentize-atpt (&optional arg ispec) 
  "Parentizes 'slashed at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'slashed arg ispec))

(defalias 'separate-slashed-atpt 'slashed-separate-atpt)
;;;###autoload
(defun slashed-separate-atpt (&optional arg ispec) 
  "Separates 'slashed at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'slashed arg ispec))

(defalias 'singlequote-slashed-atpt 'slashed-singlequote-atpt)
;;;###autoload
(defun slashed-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'slashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'slashed arg ispec))

(defalias 'slash-slashed-atpt 'slashed-slash-atpt)
;;;###autoload
(defun slashed-slash-atpt (&optional arg ispec) 
  "Slash 'slashed at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'slashed arg ispec))

(defalias 'trim-slashed-atpt 'slashed-trim-atpt)
;;;###autoload
(defun slashed-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'slashed t t))

(defalias 'trim-slashed-left-atpt 'slashed-left-trim-atpt)
;;;###autoload
(defun slashed-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'slashed t nil))

(defalias 'trim-slashed-right-atpt 'slashed-right-trim-atpt)
;;;###autoload
(defun slashed-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'slashed nil t))

(defalias 'forward-slashed-atpt 'slashed-forward-atpt)
;;;###autoload
(defun slashed-forward-atpt (&optional arg ispec) 
  "Moves forward over slashed at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'slashed arg ispec))

(defalias 'backward-slashed-atpt 'slashed-backward-atpt)
;;;###autoload
(defun slashed-backward-atpt (&optional arg ispec) 
  "Moves backward over slashed before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'slashed arg ispec))

(defalias 'transpose-slashed-atpt 'slashed-transpose-atpt)
;;;###autoload
(defun slashed-transpose-atpt (&optional arg) 
  "Transposes slashed with slashed before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'slashed arg))

(defalias 'sort-slashed-atpt 'slashed-sort-atpt)
;;;###autoload
(defun slashed-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts slashed's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'slashed reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-slashed-atpt 'slashed-check-atpt)
;;;###autoload
(defun slashed-check-atpt (&optional arg ispec) 
  " slashed at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "slashed" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "slashed" "-end-position-atpt")))))
    (th-check 'slashed arg ispec)))
   

;;;###autoload
(defun space-atpt (&optional arg ispec) 
  "Returns space at point if any, nil otherwise"
  (interactive "P\np")
  (th 'space arg ispec))

(defalias 'bounds-of-space-atpt 'space-bounds-atpt)
;;;###autoload
(defun space-bounds-atpt (&optional arg ispec) 
  "Returns borders of space at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'space arg ispec))

;;;###autoload
(defun space-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'space arg ispec))

;;;###autoload
(defun space-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'space arg ispec))

(defalias 'beginning-of-space-atpt 'space-beginning-atpt)
;;;###autoload
(defun space-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'space arg ispec))

(defalias 'end-of-space-atpt 'space-end-atpt)
;;;###autoload
(defun space-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'space arg ispec))

(defalias 'length-of-space-atpt 'space-length-atpt)
;;;###autoload
(defun space-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'space arg ispec))

(defalias 'copy-space-atpt 'space-copy-atpt)
;;;###autoload
(defun space-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'space arg ispec))

(defalias 'escape-space-atpt 'space-escape-atpt)
;;;###autoload
(defun space-escape-atpt (arg) 
  "Makes a copy of symbol or char-class space at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'space arg))

(defalias 'doublequote-space-atpt 'space-doublequote-atpt)
;;;###autoload
(defun space-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'space at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'space arg ispec))

(defalias 'dollar-space-atpt 'space-dollar-atpt)
;;;###autoload
(defun space-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'space at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'space arg ispec))

(defalias 'backslash-space-atpt 'space-backslash-atpt)
;;;###autoload
(defun space-backslash-atpt (&optional arg ispec) 
  "Backslash 'space at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'space arg ispec)) 

(defalias 'brace-space-atpt 'space-brace-atpt)
;;;###autoload
(defun space-brace-atpt (&optional arg ispec) 
  "Braces 'space at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'space arg ispec))

(defalias 'bracket-space-atpt 'space-bracket-atpt)
;;;###autoload
(defun space-bracket-atpt (&optional arg ispec) 
  "Brackets 'space after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'space arg ispec))

(defalias 'commented-space-atpt 'space-comment-atpt)
;;;###autoload
(defun space-comment-atpt (&optional arg ispec) 
  "Comments 'space at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'space arg ispec))

(defalias 'mark-space-atpt 'space-mark-atpt)
;;;###autoload
(defun space-mark-atpt (&optional arg) 
  "Marks 'space at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'space arg))

(defalias 'kill-space-atpt 'space-kill-atpt)
;;;###autoload
(defun space-kill-atpt (arg)
  "Kills space at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'space arg))

(defalias 'parentize-space-atpt 'space-parentize-atpt)
;;;###autoload
(defun space-parentize-atpt (&optional arg ispec) 
  "Parentizes 'space at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'space arg ispec))

(defalias 'separate-space-atpt 'space-separate-atpt)
;;;###autoload
(defun space-separate-atpt (&optional arg ispec) 
  "Separates 'space at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'space arg ispec))

(defalias 'singlequote-space-atpt 'space-singlequote-atpt)
;;;###autoload
(defun space-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'space at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'space arg ispec))

(defalias 'slash-space-atpt 'space-slash-atpt)
;;;###autoload
(defun space-slash-atpt (&optional arg ispec) 
  "Slash 'space at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'space arg ispec))

(defalias 'trim-space-atpt 'space-trim-atpt)
;;;###autoload
(defun space-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'space t t))

(defalias 'trim-space-left-atpt 'space-left-trim-atpt)
;;;###autoload
(defun space-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'space t nil))

(defalias 'trim-space-right-atpt 'space-right-trim-atpt)
;;;###autoload
(defun space-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'space nil t))

(defalias 'forward-space-atpt 'space-forward-atpt)
;;;###autoload
(defun space-forward-atpt (&optional arg ispec) 
  "Moves forward over space at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'space arg ispec))

(defalias 'backward-space-atpt 'space-backward-atpt)
;;;###autoload
(defun space-backward-atpt (&optional arg ispec) 
  "Moves backward over space before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'space arg ispec))

(defalias 'transpose-space-atpt 'space-transpose-atpt)
;;;###autoload
(defun space-transpose-atpt (&optional arg) 
  "Transposes space with space before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'space arg))

(defalias 'sort-space-atpt 'space-sort-atpt)
;;;###autoload
(defun space-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts space's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'space reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-space-atpt 'space-check-atpt)
;;;###autoload
(defun space-check-atpt (&optional arg ispec) 
  " space at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "space" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "space" "-end-position-atpt")))))
    (th-check 'space arg ispec)))
   

;;;###autoload
(defun string-atpt (&optional arg ispec) 
  "Returns string at point if any, nil otherwise"
  (interactive "P\np")
  (th 'string arg ispec))

(defalias 'bounds-of-string-atpt 'string-bounds-atpt)
;;;###autoload
(defun string-bounds-atpt (&optional arg ispec) 
  "Returns borders of string at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'string arg ispec))

;;;###autoload
(defun string-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'string arg ispec))

;;;###autoload
(defun string-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'string arg ispec))

(defalias 'beginning-of-string-atpt 'string-beginning-atpt)
;;;###autoload
(defun string-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'string arg ispec))

(defalias 'end-of-string-atpt 'string-end-atpt)
;;;###autoload
(defun string-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'string arg ispec))

(defalias 'length-of-string-atpt 'string-length-atpt)
;;;###autoload
(defun string-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'string arg ispec))

(defalias 'copy-string-atpt 'string-copy-atpt)
;;;###autoload
(defun string-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'string arg ispec))

(defalias 'escape-string-atpt 'string-escape-atpt)
;;;###autoload
(defun string-escape-atpt (arg) 
  "Makes a copy of symbol or char-class string at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'string arg))

(defalias 'doublequote-string-atpt 'string-doublequote-atpt)
;;;###autoload
(defun string-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'string at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'string arg ispec))

(defalias 'dollar-string-atpt 'string-dollar-atpt)
;;;###autoload
(defun string-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'string at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'string arg ispec))

(defalias 'backslash-string-atpt 'string-backslash-atpt)
;;;###autoload
(defun string-backslash-atpt (&optional arg ispec) 
  "Backslash 'string at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'string arg ispec)) 

(defalias 'brace-string-atpt 'string-brace-atpt)
;;;###autoload
(defun string-brace-atpt (&optional arg ispec) 
  "Braces 'string at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'string arg ispec))

(defalias 'bracket-string-atpt 'string-bracket-atpt)
;;;###autoload
(defun string-bracket-atpt (&optional arg ispec) 
  "Brackets 'string after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'string arg ispec))

(defalias 'commented-string-atpt 'string-comment-atpt)
;;;###autoload
(defun string-comment-atpt (&optional arg ispec) 
  "Comments 'string at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'string arg ispec))

(defalias 'mark-string-atpt 'string-mark-atpt)
;;;###autoload
(defun string-mark-atpt (&optional arg) 
  "Marks 'string at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'string arg))

(defalias 'kill-string-atpt 'string-kill-atpt)
;;;###autoload
(defun string-kill-atpt (arg)
  "Kills string at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'string arg))

(defalias 'parentize-string-atpt 'string-parentize-atpt)
;;;###autoload
(defun string-parentize-atpt (&optional arg ispec) 
  "Parentizes 'string at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'string arg ispec))

(defalias 'separate-string-atpt 'string-separate-atpt)
;;;###autoload
(defun string-separate-atpt (&optional arg ispec) 
  "Separates 'string at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'string arg ispec))

(defalias 'singlequote-string-atpt 'string-singlequote-atpt)
;;;###autoload
(defun string-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'string at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'string arg ispec))

(defalias 'slash-string-atpt 'string-slash-atpt)
;;;###autoload
(defun string-slash-atpt (&optional arg ispec) 
  "Slash 'string at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'string arg ispec))

(defalias 'trim-string-atpt 'string-trim-atpt)
;;;###autoload
(defun string-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'string t t))

(defalias 'trim-string-left-atpt 'string-left-trim-atpt)
;;;###autoload
(defun string-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'string t nil))

(defalias 'trim-string-right-atpt 'string-right-trim-atpt)
;;;###autoload
(defun string-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'string nil t))

(defalias 'forward-string-atpt 'string-forward-atpt)
;;;###autoload
(defun string-forward-atpt (&optional arg ispec) 
  "Moves forward over string at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'string arg ispec))

(defalias 'backward-string-atpt 'string-backward-atpt)
;;;###autoload
(defun string-backward-atpt (&optional arg ispec) 
  "Moves backward over string before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'string arg ispec))

(defalias 'transpose-string-atpt 'string-transpose-atpt)
;;;###autoload
(defun string-transpose-atpt (&optional arg) 
  "Transposes string with string before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'string arg))

(defalias 'sort-string-atpt 'string-sort-atpt)
;;;###autoload
(defun string-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts string's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'string reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-string-atpt 'string-check-atpt)
;;;###autoload
(defun string-check-atpt (&optional arg ispec) 
  " string at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "string" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "string" "-end-position-atpt")))))
    (th-check 'string arg ispec)))
   

;;;###autoload
(defun sh-struct-atpt (&optional arg ispec) 
  "Returns sh-struct at point if any, nil otherwise"
  (interactive "P\np")
  (th 'sh-struct arg ispec))

(defalias 'bounds-of-sh-struct-atpt 'sh-struct-bounds-atpt)
;;;###autoload
(defun sh-struct-bounds-atpt (&optional arg ispec) 
  "Returns borders of sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'sh-struct arg ispec))

;;;###autoload
(defun sh-struct-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'sh-struct arg ispec))

;;;###autoload
(defun sh-struct-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'sh-struct arg ispec))

(defalias 'beginning-of-sh-struct-atpt 'sh-struct-beginning-atpt)
;;;###autoload
(defun sh-struct-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'sh-struct arg ispec))

(defalias 'end-of-sh-struct-atpt 'sh-struct-end-atpt)
;;;###autoload
(defun sh-struct-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'sh-struct arg ispec))

(defalias 'length-of-sh-struct-atpt 'sh-struct-length-atpt)
;;;###autoload
(defun sh-struct-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'sh-struct arg ispec))

(defalias 'copy-sh-struct-atpt 'sh-struct-copy-atpt)
;;;###autoload
(defun sh-struct-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'sh-struct arg ispec))

(defalias 'escape-sh-struct-atpt 'sh-struct-escape-atpt)
;;;###autoload
(defun sh-struct-escape-atpt (arg) 
  "Makes a copy of symbol or char-class sh-struct at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'sh-struct arg))

(defalias 'doublequote-sh-struct-atpt 'sh-struct-doublequote-atpt)
;;;###autoload
(defun sh-struct-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'sh-struct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'sh-struct arg ispec))

(defalias 'dollar-sh-struct-atpt 'sh-struct-dollar-atpt)
;;;###autoload
(defun sh-struct-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'sh-struct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'sh-struct arg ispec))

(defalias 'backslash-sh-struct-atpt 'sh-struct-backslash-atpt)
;;;###autoload
(defun sh-struct-backslash-atpt (&optional arg ispec) 
  "Backslash 'sh-struct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'sh-struct arg ispec)) 

(defalias 'brace-sh-struct-atpt 'sh-struct-brace-atpt)
;;;###autoload
(defun sh-struct-brace-atpt (&optional arg ispec) 
  "Braces 'sh-struct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'sh-struct arg ispec))

(defalias 'bracket-sh-struct-atpt 'sh-struct-bracket-atpt)
;;;###autoload
(defun sh-struct-bracket-atpt (&optional arg ispec) 
  "Brackets 'sh-struct after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'sh-struct arg ispec))

(defalias 'commented-sh-struct-atpt 'sh-struct-comment-atpt)
;;;###autoload
(defun sh-struct-comment-atpt (&optional arg ispec) 
  "Comments 'sh-struct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'sh-struct arg ispec))

(defalias 'mark-sh-struct-atpt 'sh-struct-mark-atpt)
;;;###autoload
(defun sh-struct-mark-atpt (&optional arg) 
  "Marks 'sh-struct at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'sh-struct arg))

(defalias 'kill-sh-struct-atpt 'sh-struct-kill-atpt)
;;;###autoload
(defun sh-struct-kill-atpt (arg)
  "Kills sh-struct at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'sh-struct arg))

(defalias 'parentize-sh-struct-atpt 'sh-struct-parentize-atpt)
;;;###autoload
(defun sh-struct-parentize-atpt (&optional arg ispec) 
  "Parentizes 'sh-struct at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'sh-struct arg ispec))

(defalias 'separate-sh-struct-atpt 'sh-struct-separate-atpt)
;;;###autoload
(defun sh-struct-separate-atpt (&optional arg ispec) 
  "Separates 'sh-struct at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'sh-struct arg ispec))

(defalias 'singlequote-sh-struct-atpt 'sh-struct-singlequote-atpt)
;;;###autoload
(defun sh-struct-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'sh-struct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'sh-struct arg ispec))

(defalias 'slash-sh-struct-atpt 'sh-struct-slash-atpt)
;;;###autoload
(defun sh-struct-slash-atpt (&optional arg ispec) 
  "Slash 'sh-struct at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'sh-struct arg ispec))

(defalias 'trim-sh-struct-atpt 'sh-struct-trim-atpt)
;;;###autoload
(defun sh-struct-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sh-struct t t))

(defalias 'trim-sh-struct-left-atpt 'sh-struct-left-trim-atpt)
;;;###autoload
(defun sh-struct-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sh-struct t nil))

(defalias 'trim-sh-struct-right-atpt 'sh-struct-right-trim-atpt)
;;;###autoload
(defun sh-struct-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'sh-struct nil t))

(defalias 'forward-sh-struct-atpt 'sh-struct-forward-atpt)
;;;###autoload
(defun sh-struct-forward-atpt (&optional arg ispec) 
  "Moves forward over sh-struct at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'sh-struct arg ispec))

(defalias 'backward-sh-struct-atpt 'sh-struct-backward-atpt)
;;;###autoload
(defun sh-struct-backward-atpt (&optional arg ispec) 
  "Moves backward over sh-struct before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'sh-struct arg ispec))

(defalias 'transpose-sh-struct-atpt 'sh-struct-transpose-atpt)
;;;###autoload
(defun sh-struct-transpose-atpt (&optional arg) 
  "Transposes sh-struct with sh-struct before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'sh-struct arg))

(defalias 'sort-sh-struct-atpt 'sh-struct-sort-atpt)
;;;###autoload
(defun sh-struct-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts sh-struct's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'sh-struct reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-sh-struct-atpt 'sh-struct-check-atpt)
;;;###autoload
(defun sh-struct-check-atpt (&optional arg ispec) 
  " sh-struct at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "sh-struct" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "sh-struct" "-end-position-atpt")))))
    (th-check 'sh-struct arg ispec)))
   

;;;###autoload
(defun symbol-atpt (&optional arg ispec) 
  "Returns symbol at point if any, nil otherwise"
  (interactive "P\np")
  (th 'symbol arg ispec))

(defalias 'bounds-of-symbol-atpt 'symbol-bounds-atpt)
;;;###autoload
(defun symbol-bounds-atpt (&optional arg ispec) 
  "Returns borders of symbol at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'symbol arg ispec))

;;;###autoload
(defun symbol-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'symbol arg ispec))

;;;###autoload
(defun symbol-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'symbol arg ispec))

(defalias 'beginning-of-symbol-atpt 'symbol-beginning-atpt)
;;;###autoload
(defun symbol-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'symbol arg ispec))

(defalias 'end-of-symbol-atpt 'symbol-end-atpt)
;;;###autoload
(defun symbol-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'symbol arg ispec))

(defalias 'length-of-symbol-atpt 'symbol-length-atpt)
;;;###autoload
(defun symbol-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'symbol arg ispec))

(defalias 'copy-symbol-atpt 'symbol-copy-atpt)
;;;###autoload
(defun symbol-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'symbol arg ispec))

(defalias 'escape-symbol-atpt 'symbol-escape-atpt)
;;;###autoload
(defun symbol-escape-atpt (arg) 
  "Makes a copy of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'symbol arg))

(defalias 'doublequote-symbol-atpt 'symbol-doublequote-atpt)
;;;###autoload
(defun symbol-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'symbol at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'symbol arg ispec))

(defalias 'dollar-symbol-atpt 'symbol-dollar-atpt)
;;;###autoload
(defun symbol-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'symbol at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'symbol arg ispec))

(defalias 'backslash-symbol-atpt 'symbol-backslash-atpt)
;;;###autoload
(defun symbol-backslash-atpt (&optional arg ispec) 
  "Backslash 'symbol at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'symbol arg ispec)) 

(defalias 'brace-symbol-atpt 'symbol-brace-atpt)
;;;###autoload
(defun symbol-brace-atpt (&optional arg ispec) 
  "Braces 'symbol at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'symbol arg ispec))

(defalias 'bracket-symbol-atpt 'symbol-bracket-atpt)
;;;###autoload
(defun symbol-bracket-atpt (&optional arg ispec) 
  "Brackets 'symbol after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'symbol arg ispec))

(defalias 'commented-symbol-atpt 'symbol-comment-atpt)
;;;###autoload
(defun symbol-comment-atpt (&optional arg ispec) 
  "Comments 'symbol at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'symbol arg ispec))

(defalias 'mark-symbol-atpt 'symbol-mark-atpt)
;;;###autoload
(defun symbol-mark-atpt (&optional arg) 
  "Marks 'symbol at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'symbol arg))

(defalias 'kill-symbol-atpt 'symbol-kill-atpt)
;;;###autoload
(defun symbol-kill-atpt (arg)
  "Kills symbol at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'symbol arg))

(defalias 'parentize-symbol-atpt 'symbol-parentize-atpt)
;;;###autoload
(defun symbol-parentize-atpt (&optional arg ispec) 
  "Parentizes 'symbol at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'symbol arg ispec))

(defalias 'separate-symbol-atpt 'symbol-separate-atpt)
;;;###autoload
(defun symbol-separate-atpt (&optional arg ispec) 
  "Separates 'symbol at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'symbol arg ispec))

(defalias 'singlequote-symbol-atpt 'symbol-singlequote-atpt)
;;;###autoload
(defun symbol-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'symbol at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'symbol arg ispec))

(defalias 'slash-symbol-atpt 'symbol-slash-atpt)
;;;###autoload
(defun symbol-slash-atpt (&optional arg ispec) 
  "Slash 'symbol at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'symbol arg ispec))

(defalias 'trim-symbol-atpt 'symbol-trim-atpt)
;;;###autoload
(defun symbol-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'symbol t t))

(defalias 'trim-symbol-left-atpt 'symbol-left-trim-atpt)
;;;###autoload
(defun symbol-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'symbol t nil))

(defalias 'trim-symbol-right-atpt 'symbol-right-trim-atpt)
;;;###autoload
(defun symbol-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'symbol nil t))

(defalias 'forward-symbol-atpt 'symbol-forward-atpt)
;;;###autoload
(defun symbol-forward-atpt (&optional arg ispec) 
  "Moves forward over symbol at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'symbol arg ispec))

(defalias 'backward-symbol-atpt 'symbol-backward-atpt)
;;;###autoload
(defun symbol-backward-atpt (&optional arg ispec) 
  "Moves backward over symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'symbol arg ispec))

(defalias 'transpose-symbol-atpt 'symbol-transpose-atpt)
;;;###autoload
(defun symbol-transpose-atpt (&optional arg) 
  "Transposes symbol with symbol before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'symbol arg))

(defalias 'sort-symbol-atpt 'symbol-sort-atpt)
;;;###autoload
(defun symbol-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts symbol's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'symbol reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-symbol-atpt 'symbol-check-atpt)
;;;###autoload
(defun symbol-check-atpt (&optional arg ispec) 
  " symbol at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "symbol" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "symbol" "-end-position-atpt")))))
    (th-check 'symbol arg ispec)))
   

;;;###autoload
(defun unibyte-atpt (&optional arg ispec) 
  "Returns unibyte at point if any, nil otherwise"
  (interactive "P\np")
  (th 'unibyte arg ispec))

(defalias 'bounds-of-unibyte-atpt 'unibyte-bounds-atpt)
;;;###autoload
(defun unibyte-bounds-atpt (&optional arg ispec) 
  "Returns borders of unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'unibyte arg ispec))

;;;###autoload
(defun unibyte-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'unibyte arg ispec))

;;;###autoload
(defun unibyte-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'unibyte arg ispec))

(defalias 'beginning-of-unibyte-atpt 'unibyte-beginning-atpt)
;;;###autoload
(defun unibyte-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'unibyte arg ispec))

(defalias 'end-of-unibyte-atpt 'unibyte-end-atpt)
;;;###autoload
(defun unibyte-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'unibyte arg ispec))

(defalias 'length-of-unibyte-atpt 'unibyte-length-atpt)
;;;###autoload
(defun unibyte-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'unibyte arg ispec))

(defalias 'copy-unibyte-atpt 'unibyte-copy-atpt)
;;;###autoload
(defun unibyte-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'unibyte arg ispec))

(defalias 'escape-unibyte-atpt 'unibyte-escape-atpt)
;;;###autoload
(defun unibyte-escape-atpt (arg) 
  "Makes a copy of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'unibyte arg))

(defalias 'doublequote-unibyte-atpt 'unibyte-doublequote-atpt)
;;;###autoload
(defun unibyte-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'unibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'unibyte arg ispec))

(defalias 'dollar-unibyte-atpt 'unibyte-dollar-atpt)
;;;###autoload
(defun unibyte-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'unibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'unibyte arg ispec))

(defalias 'backslash-unibyte-atpt 'unibyte-backslash-atpt)
;;;###autoload
(defun unibyte-backslash-atpt (&optional arg ispec) 
  "Backslash 'unibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'unibyte arg ispec)) 

(defalias 'brace-unibyte-atpt 'unibyte-brace-atpt)
;;;###autoload
(defun unibyte-brace-atpt (&optional arg ispec) 
  "Braces 'unibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'unibyte arg ispec))

(defalias 'bracket-unibyte-atpt 'unibyte-bracket-atpt)
;;;###autoload
(defun unibyte-bracket-atpt (&optional arg ispec) 
  "Brackets 'unibyte after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'unibyte arg ispec))

(defalias 'commented-unibyte-atpt 'unibyte-comment-atpt)
;;;###autoload
(defun unibyte-comment-atpt (&optional arg ispec) 
  "Comments 'unibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'unibyte arg ispec))

(defalias 'mark-unibyte-atpt 'unibyte-mark-atpt)
;;;###autoload
(defun unibyte-mark-atpt (&optional arg) 
  "Marks 'unibyte at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'unibyte arg))

(defalias 'kill-unibyte-atpt 'unibyte-kill-atpt)
;;;###autoload
(defun unibyte-kill-atpt (arg)
  "Kills unibyte at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'unibyte arg))

(defalias 'parentize-unibyte-atpt 'unibyte-parentize-atpt)
;;;###autoload
(defun unibyte-parentize-atpt (&optional arg ispec) 
  "Parentizes 'unibyte at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'unibyte arg ispec))

(defalias 'separate-unibyte-atpt 'unibyte-separate-atpt)
;;;###autoload
(defun unibyte-separate-atpt (&optional arg ispec) 
  "Separates 'unibyte at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'unibyte arg ispec))

(defalias 'singlequote-unibyte-atpt 'unibyte-singlequote-atpt)
;;;###autoload
(defun unibyte-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'unibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'unibyte arg ispec))

(defalias 'slash-unibyte-atpt 'unibyte-slash-atpt)
;;;###autoload
(defun unibyte-slash-atpt (&optional arg ispec) 
  "Slash 'unibyte at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'unibyte arg ispec))

(defalias 'trim-unibyte-atpt 'unibyte-trim-atpt)
;;;###autoload
(defun unibyte-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'unibyte t t))

(defalias 'trim-unibyte-left-atpt 'unibyte-left-trim-atpt)
;;;###autoload
(defun unibyte-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'unibyte t nil))

(defalias 'trim-unibyte-right-atpt 'unibyte-right-trim-atpt)
;;;###autoload
(defun unibyte-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'unibyte nil t))

(defalias 'forward-unibyte-atpt 'unibyte-forward-atpt)
;;;###autoload
(defun unibyte-forward-atpt (&optional arg ispec) 
  "Moves forward over unibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'unibyte arg ispec))

(defalias 'backward-unibyte-atpt 'unibyte-backward-atpt)
;;;###autoload
(defun unibyte-backward-atpt (&optional arg ispec) 
  "Moves backward over unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'unibyte arg ispec))

(defalias 'transpose-unibyte-atpt 'unibyte-transpose-atpt)
;;;###autoload
(defun unibyte-transpose-atpt (&optional arg) 
  "Transposes unibyte with unibyte before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'unibyte arg))

(defalias 'sort-unibyte-atpt 'unibyte-sort-atpt)
;;;###autoload
(defun unibyte-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts unibyte's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'unibyte reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-unibyte-atpt 'unibyte-check-atpt)
;;;###autoload
(defun unibyte-check-atpt (&optional arg ispec) 
  " unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "unibyte" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "unibyte" "-end-position-atpt")))))
    (th-check 'unibyte arg ispec)))
   

;;;###autoload
(defun upper-atpt (&optional arg ispec) 
  "Returns upper at point if any, nil otherwise"
  (interactive "P\np")
  (th 'upper arg ispec))

(defalias 'bounds-of-upper-atpt 'upper-bounds-atpt)
;;;###autoload
(defun upper-bounds-atpt (&optional arg ispec) 
  "Returns borders of upper at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'upper arg ispec))

;;;###autoload
(defun upper-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'upper arg ispec))

;;;###autoload
(defun upper-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'upper arg ispec))

(defalias 'beginning-of-upper-atpt 'upper-beginning-atpt)
;;;###autoload
(defun upper-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'upper arg ispec))

(defalias 'end-of-upper-atpt 'upper-end-atpt)
;;;###autoload
(defun upper-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'upper arg ispec))

(defalias 'length-of-upper-atpt 'upper-length-atpt)
;;;###autoload
(defun upper-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'upper arg ispec))

(defalias 'copy-upper-atpt 'upper-copy-atpt)
;;;###autoload
(defun upper-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'upper arg ispec))

(defalias 'escape-upper-atpt 'upper-escape-atpt)
;;;###autoload
(defun upper-escape-atpt (arg) 
  "Makes a copy of symbol or char-class upper at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'upper arg))

(defalias 'doublequote-upper-atpt 'upper-doublequote-atpt)
;;;###autoload
(defun upper-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'upper at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'upper arg ispec))

(defalias 'dollar-upper-atpt 'upper-dollar-atpt)
;;;###autoload
(defun upper-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'upper at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'upper arg ispec))

(defalias 'backslash-upper-atpt 'upper-backslash-atpt)
;;;###autoload
(defun upper-backslash-atpt (&optional arg ispec) 
  "Backslash 'upper at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'upper arg ispec)) 

(defalias 'brace-upper-atpt 'upper-brace-atpt)
;;;###autoload
(defun upper-brace-atpt (&optional arg ispec) 
  "Braces 'upper at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'upper arg ispec))

(defalias 'bracket-upper-atpt 'upper-bracket-atpt)
;;;###autoload
(defun upper-bracket-atpt (&optional arg ispec) 
  "Brackets 'upper after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'upper arg ispec))

(defalias 'commented-upper-atpt 'upper-comment-atpt)
;;;###autoload
(defun upper-comment-atpt (&optional arg ispec) 
  "Comments 'upper at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'upper arg ispec))

(defalias 'mark-upper-atpt 'upper-mark-atpt)
;;;###autoload
(defun upper-mark-atpt (&optional arg) 
  "Marks 'upper at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'upper arg))

(defalias 'kill-upper-atpt 'upper-kill-atpt)
;;;###autoload
(defun upper-kill-atpt (arg)
  "Kills upper at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'upper arg))

(defalias 'parentize-upper-atpt 'upper-parentize-atpt)
;;;###autoload
(defun upper-parentize-atpt (&optional arg ispec) 
  "Parentizes 'upper at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'upper arg ispec))

(defalias 'separate-upper-atpt 'upper-separate-atpt)
;;;###autoload
(defun upper-separate-atpt (&optional arg ispec) 
  "Separates 'upper at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'upper arg ispec))

(defalias 'singlequote-upper-atpt 'upper-singlequote-atpt)
;;;###autoload
(defun upper-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'upper at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'upper arg ispec))

(defalias 'slash-upper-atpt 'upper-slash-atpt)
;;;###autoload
(defun upper-slash-atpt (&optional arg ispec) 
  "Slash 'upper at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'upper arg ispec))

(defalias 'trim-upper-atpt 'upper-trim-atpt)
;;;###autoload
(defun upper-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'upper t t))

(defalias 'trim-upper-left-atpt 'upper-left-trim-atpt)
;;;###autoload
(defun upper-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'upper t nil))

(defalias 'trim-upper-right-atpt 'upper-right-trim-atpt)
;;;###autoload
(defun upper-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'upper nil t))

(defalias 'forward-upper-atpt 'upper-forward-atpt)
;;;###autoload
(defun upper-forward-atpt (&optional arg ispec) 
  "Moves forward over upper at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'upper arg ispec))

(defalias 'backward-upper-atpt 'upper-backward-atpt)
;;;###autoload
(defun upper-backward-atpt (&optional arg ispec) 
  "Moves backward over upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'upper arg ispec))

(defalias 'transpose-upper-atpt 'upper-transpose-atpt)
;;;###autoload
(defun upper-transpose-atpt (&optional arg) 
  "Transposes upper with upper before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'upper arg))

(defalias 'sort-upper-atpt 'upper-sort-atpt)
;;;###autoload
(defun upper-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts upper's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'upper reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-upper-atpt 'upper-check-atpt)
;;;###autoload
(defun upper-check-atpt (&optional arg ispec) 
  " upper at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "upper" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "upper" "-end-position-atpt")))))
    (th-check 'upper arg ispec)))
   

;;;###autoload
(defun url-atpt (&optional arg ispec) 
  "Returns url at point if any, nil otherwise"
  (interactive "P\np")
  (th 'url arg ispec))

(defalias 'bounds-of-url-atpt 'url-bounds-atpt)
;;;###autoload
(defun url-bounds-atpt (&optional arg ispec) 
  "Returns borders of url at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'url arg ispec))

;;;###autoload
(defun url-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'url arg ispec))

;;;###autoload
(defun url-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'url arg ispec))

(defalias 'beginning-of-url-atpt 'url-beginning-atpt)
;;;###autoload
(defun url-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'url arg ispec))

(defalias 'end-of-url-atpt 'url-end-atpt)
;;;###autoload
(defun url-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'url arg ispec))

(defalias 'length-of-url-atpt 'url-length-atpt)
;;;###autoload
(defun url-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'url arg ispec))

(defalias 'copy-url-atpt 'url-copy-atpt)
;;;###autoload
(defun url-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'url arg ispec))

(defalias 'escape-url-atpt 'url-escape-atpt)
;;;###autoload
(defun url-escape-atpt (arg) 
  "Makes a copy of symbol or char-class url at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'url arg))

(defalias 'doublequote-url-atpt 'url-doublequote-atpt)
;;;###autoload
(defun url-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'url at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'url arg ispec))

(defalias 'dollar-url-atpt 'url-dollar-atpt)
;;;###autoload
(defun url-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'url at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'url arg ispec))

(defalias 'backslash-url-atpt 'url-backslash-atpt)
;;;###autoload
(defun url-backslash-atpt (&optional arg ispec) 
  "Backslash 'url at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'url arg ispec)) 

(defalias 'brace-url-atpt 'url-brace-atpt)
;;;###autoload
(defun url-brace-atpt (&optional arg ispec) 
  "Braces 'url at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'url arg ispec))

(defalias 'bracket-url-atpt 'url-bracket-atpt)
;;;###autoload
(defun url-bracket-atpt (&optional arg ispec) 
  "Brackets 'url after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'url arg ispec))

(defalias 'commented-url-atpt 'url-comment-atpt)
;;;###autoload
(defun url-comment-atpt (&optional arg ispec) 
  "Comments 'url at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'url arg ispec))

(defalias 'mark-url-atpt 'url-mark-atpt)
;;;###autoload
(defun url-mark-atpt (&optional arg) 
  "Marks 'url at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'url arg))

(defalias 'kill-url-atpt 'url-kill-atpt)
;;;###autoload
(defun url-kill-atpt (arg)
  "Kills url at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'url arg))

(defalias 'parentize-url-atpt 'url-parentize-atpt)
;;;###autoload
(defun url-parentize-atpt (&optional arg ispec) 
  "Parentizes 'url at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'url arg ispec))

(defalias 'separate-url-atpt 'url-separate-atpt)
;;;###autoload
(defun url-separate-atpt (&optional arg ispec) 
  "Separates 'url at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'url arg ispec))

(defalias 'singlequote-url-atpt 'url-singlequote-atpt)
;;;###autoload
(defun url-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'url at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'url arg ispec))

(defalias 'slash-url-atpt 'url-slash-atpt)
;;;###autoload
(defun url-slash-atpt (&optional arg ispec) 
  "Slash 'url at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'url arg ispec))

(defalias 'trim-url-atpt 'url-trim-atpt)
;;;###autoload
(defun url-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'url t t))

(defalias 'trim-url-left-atpt 'url-left-trim-atpt)
;;;###autoload
(defun url-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'url t nil))

(defalias 'trim-url-right-atpt 'url-right-trim-atpt)
;;;###autoload
(defun url-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'url nil t))

(defalias 'forward-url-atpt 'url-forward-atpt)
;;;###autoload
(defun url-forward-atpt (&optional arg ispec) 
  "Moves forward over url at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'url arg ispec))

(defalias 'backward-url-atpt 'url-backward-atpt)
;;;###autoload
(defun url-backward-atpt (&optional arg ispec) 
  "Moves backward over url before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'url arg ispec))

(defalias 'transpose-url-atpt 'url-transpose-atpt)
;;;###autoload
(defun url-transpose-atpt (&optional arg) 
  "Transposes url with url before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'url arg))

(defalias 'sort-url-atpt 'url-sort-atpt)
;;;###autoload
(defun url-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts url's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'url reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-url-atpt 'url-check-atpt)
;;;###autoload
(defun url-check-atpt (&optional arg ispec) 
  " url at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "url" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "url" "-end-position-atpt")))))
    (th-check 'url arg ispec)))
   

;;;###autoload
(defun whitespace-atpt (&optional arg ispec) 
  "Returns whitespace at point if any, nil otherwise"
  (interactive "P\np")
  (th 'whitespace arg ispec))

(defalias 'bounds-of-whitespace-atpt 'whitespace-bounds-atpt)
;;;###autoload
(defun whitespace-bounds-atpt (&optional arg ispec) 
  "Returns borders of whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'whitespace arg ispec))

;;;###autoload
(defun whitespace-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'whitespace arg ispec))

;;;###autoload
(defun whitespace-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'whitespace arg ispec))

(defalias 'beginning-of-whitespace-atpt 'whitespace-beginning-atpt)
;;;###autoload
(defun whitespace-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'whitespace arg ispec))

(defalias 'end-of-whitespace-atpt 'whitespace-end-atpt)
;;;###autoload
(defun whitespace-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'whitespace arg ispec))

(defalias 'length-of-whitespace-atpt 'whitespace-length-atpt)
;;;###autoload
(defun whitespace-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'whitespace arg ispec))

(defalias 'copy-whitespace-atpt 'whitespace-copy-atpt)
;;;###autoload
(defun whitespace-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'whitespace arg ispec))

(defalias 'escape-whitespace-atpt 'whitespace-escape-atpt)
;;;###autoload
(defun whitespace-escape-atpt (arg) 
  "Makes a copy of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'whitespace arg))

(defalias 'doublequote-whitespace-atpt 'whitespace-doublequote-atpt)
;;;###autoload
(defun whitespace-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'whitespace at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'whitespace arg ispec))

(defalias 'dollar-whitespace-atpt 'whitespace-dollar-atpt)
;;;###autoload
(defun whitespace-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'whitespace at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'whitespace arg ispec))

(defalias 'backslash-whitespace-atpt 'whitespace-backslash-atpt)
;;;###autoload
(defun whitespace-backslash-atpt (&optional arg ispec) 
  "Backslash 'whitespace at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'whitespace arg ispec)) 

(defalias 'brace-whitespace-atpt 'whitespace-brace-atpt)
;;;###autoload
(defun whitespace-brace-atpt (&optional arg ispec) 
  "Braces 'whitespace at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'whitespace arg ispec))

(defalias 'bracket-whitespace-atpt 'whitespace-bracket-atpt)
;;;###autoload
(defun whitespace-bracket-atpt (&optional arg ispec) 
  "Brackets 'whitespace after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'whitespace arg ispec))

(defalias 'commented-whitespace-atpt 'whitespace-comment-atpt)
;;;###autoload
(defun whitespace-comment-atpt (&optional arg ispec) 
  "Comments 'whitespace at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'whitespace arg ispec))

(defalias 'mark-whitespace-atpt 'whitespace-mark-atpt)
;;;###autoload
(defun whitespace-mark-atpt (&optional arg) 
  "Marks 'whitespace at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'whitespace arg))

(defalias 'kill-whitespace-atpt 'whitespace-kill-atpt)
;;;###autoload
(defun whitespace-kill-atpt (arg)
  "Kills whitespace at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'whitespace arg))

(defalias 'parentize-whitespace-atpt 'whitespace-parentize-atpt)
;;;###autoload
(defun whitespace-parentize-atpt (&optional arg ispec) 
  "Parentizes 'whitespace at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'whitespace arg ispec))

(defalias 'separate-whitespace-atpt 'whitespace-separate-atpt)
;;;###autoload
(defun whitespace-separate-atpt (&optional arg ispec) 
  "Separates 'whitespace at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'whitespace arg ispec))

(defalias 'singlequote-whitespace-atpt 'whitespace-singlequote-atpt)
;;;###autoload
(defun whitespace-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'whitespace at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'whitespace arg ispec))

(defalias 'slash-whitespace-atpt 'whitespace-slash-atpt)
;;;###autoload
(defun whitespace-slash-atpt (&optional arg ispec) 
  "Slash 'whitespace at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'whitespace arg ispec))

(defalias 'trim-whitespace-atpt 'whitespace-trim-atpt)
;;;###autoload
(defun whitespace-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'whitespace t t))

(defalias 'trim-whitespace-left-atpt 'whitespace-left-trim-atpt)
;;;###autoload
(defun whitespace-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'whitespace t nil))

(defalias 'trim-whitespace-right-atpt 'whitespace-right-trim-atpt)
;;;###autoload
(defun whitespace-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'whitespace nil t))

(defalias 'forward-whitespace-atpt 'whitespace-forward-atpt)
;;;###autoload
(defun whitespace-forward-atpt (&optional arg ispec) 
  "Moves forward over whitespace at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'whitespace arg ispec))

(defalias 'backward-whitespace-atpt 'whitespace-backward-atpt)
;;;###autoload
(defun whitespace-backward-atpt (&optional arg ispec) 
  "Moves backward over whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'whitespace arg ispec))

(defalias 'transpose-whitespace-atpt 'whitespace-transpose-atpt)
;;;###autoload
(defun whitespace-transpose-atpt (&optional arg) 
  "Transposes whitespace with whitespace before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'whitespace arg))

(defalias 'sort-whitespace-atpt 'whitespace-sort-atpt)
;;;###autoload
(defun whitespace-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts whitespace's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'whitespace reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-whitespace-atpt 'whitespace-check-atpt)
;;;###autoload
(defun whitespace-check-atpt (&optional arg ispec) 
  " whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "whitespace" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "whitespace" "-end-position-atpt")))))
    (th-check 'whitespace arg ispec)))
   

;;;###autoload
(defun word-atpt (&optional arg ispec) 
  "Returns word at point if any, nil otherwise"
  (interactive "P\np")
  (th 'word arg ispec))

(defalias 'bounds-of-word-atpt 'word-bounds-atpt)
;;;###autoload
(defun word-bounds-atpt (&optional arg ispec) 
  "Returns borders of word at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'word arg ispec))

;;;###autoload
(defun word-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'word arg ispec))

;;;###autoload
(defun word-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'word arg ispec))

(defalias 'beginning-of-word-atpt 'word-beginning-atpt)
;;;###autoload
(defun word-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'word arg ispec))

(defalias 'end-of-word-atpt 'word-end-atpt)
;;;###autoload
(defun word-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'word arg ispec))

(defalias 'length-of-word-atpt 'word-length-atpt)
;;;###autoload
(defun word-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'word arg ispec))

(defalias 'copy-word-atpt 'word-copy-atpt)
;;;###autoload
(defun word-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'word arg ispec))

(defalias 'escape-word-atpt 'word-escape-atpt)
;;;###autoload
(defun word-escape-atpt (arg) 
  "Makes a copy of symbol or char-class word at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'word arg))

(defalias 'doublequote-word-atpt 'word-doublequote-atpt)
;;;###autoload
(defun word-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'word at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'word arg ispec))

(defalias 'dollar-word-atpt 'word-dollar-atpt)
;;;###autoload
(defun word-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'word at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'word arg ispec))

(defalias 'backslash-word-atpt 'word-backslash-atpt)
;;;###autoload
(defun word-backslash-atpt (&optional arg ispec) 
  "Backslash 'word at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'word arg ispec)) 

(defalias 'brace-word-atpt 'word-brace-atpt)
;;;###autoload
(defun word-brace-atpt (&optional arg ispec) 
  "Braces 'word at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'word arg ispec))

(defalias 'bracket-word-atpt 'word-bracket-atpt)
;;;###autoload
(defun word-bracket-atpt (&optional arg ispec) 
  "Brackets 'word after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'word arg ispec))

(defalias 'commented-word-atpt 'word-comment-atpt)
;;;###autoload
(defun word-comment-atpt (&optional arg ispec) 
  "Comments 'word at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'word arg ispec))

(defalias 'mark-word-atpt 'word-mark-atpt)
;;;###autoload
(defun word-mark-atpt (&optional arg) 
  "Marks 'word at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'word arg))

(defalias 'kill-word-atpt 'word-kill-atpt)
;;;###autoload
(defun word-kill-atpt (arg)
  "Kills word at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'word arg))

(defalias 'parentize-word-atpt 'word-parentize-atpt)
;;;###autoload
(defun word-parentize-atpt (&optional arg ispec) 
  "Parentizes 'word at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'word arg ispec))

(defalias 'separate-word-atpt 'word-separate-atpt)
;;;###autoload
(defun word-separate-atpt (&optional arg ispec) 
  "Separates 'word at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'word arg ispec))

(defalias 'singlequote-word-atpt 'word-singlequote-atpt)
;;;###autoload
(defun word-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'word at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'word arg ispec))

(defalias 'slash-word-atpt 'word-slash-atpt)
;;;###autoload
(defun word-slash-atpt (&optional arg ispec) 
  "Slash 'word at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'word arg ispec))

(defalias 'trim-word-atpt 'word-trim-atpt)
;;;###autoload
(defun word-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'word t t))

(defalias 'trim-word-left-atpt 'word-left-trim-atpt)
;;;###autoload
(defun word-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'word t nil))

(defalias 'trim-word-right-atpt 'word-right-trim-atpt)
;;;###autoload
(defun word-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'word nil t))

(defalias 'forward-word-atpt 'word-forward-atpt)
;;;###autoload
(defun word-forward-atpt (&optional arg ispec) 
  "Moves forward over word at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'word arg ispec))

(defalias 'backward-word-atpt 'word-backward-atpt)
;;;###autoload
(defun word-backward-atpt (&optional arg ispec) 
  "Moves backward over word before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'word arg ispec))

(defalias 'transpose-word-atpt 'word-transpose-atpt)
;;;###autoload
(defun word-transpose-atpt (&optional arg) 
  "Transposes word with word before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'word arg))

(defalias 'sort-word-atpt 'word-sort-atpt)
;;;###autoload
(defun word-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts word's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'word reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-word-atpt 'word-check-atpt)
;;;###autoload
(defun word-check-atpt (&optional arg ispec) 
  " word at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "word" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "word" "-end-position-atpt")))))
    (th-check 'word arg ispec)))
   

;;;###autoload
(defun xdigit-atpt (&optional arg ispec) 
  "Returns xdigit at point if any, nil otherwise"
  (interactive "P\np")
  (th 'xdigit arg ispec))

(defalias 'bounds-of-xdigit-atpt 'xdigit-bounds-atpt)
;;;###autoload
(defun xdigit-bounds-atpt (&optional arg ispec) 
  "Returns borders of xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (th-bounds 'xdigit arg ispec))

;;;###autoload
(defun xdigit-beginning-position-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (th-beg 'xdigit arg ispec))

;;;###autoload
(defun xdigit-end-position-atpt (&optional arg ispec) 
  "Returns end position of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (th-end 'xdigit arg ispec))

(defalias 'beginning-of-xdigit-atpt 'xdigit-beginning-atpt)
;;;###autoload
(defun xdigit-beginning-atpt (&optional arg ispec) 
  "Goto beginning of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotobeg 'xdigit arg ispec))

(defalias 'end-of-xdigit-atpt 'xdigit-end-atpt)
;;;###autoload
(defun xdigit-end-atpt (&optional arg ispec) 
  "Goto end of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (th-gotoend 'xdigit arg ispec))

(defalias 'length-of-xdigit-atpt 'xdigit-length-atpt)
;;;###autoload
(defun xdigit-length-atpt (&optional arg ispec) 
  "Returns beginning of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (th-length 'xdigit arg ispec))

(defalias 'copy-xdigit-atpt 'xdigit-copy-atpt)
;;;###autoload
(defun xdigit-copy-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (th-copy 'xdigit arg ispec))

(defalias 'escape-xdigit-atpt 'xdigit-escape-atpt)
;;;###autoload
(defun xdigit-escape-atpt (arg) 
  "Makes a copy of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "*P")
  (th-escape 'xdigit arg))

(defalias 'doublequote-xdigit-atpt 'xdigit-doublequote-atpt)
;;;###autoload
(defun xdigit-doublequote-atpt (&optional arg ispec) 
  "Doublequotes 'xdigit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-doublequote 'xdigit arg ispec))

(defalias 'dollar-xdigit-atpt 'xdigit-dollar-atpt)
;;;###autoload
(defun xdigit-dollar-atpt (&optional arg ispec) 
  "Doublequotes 'xdigit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-dollar 'xdigit arg ispec))

(defalias 'backslash-xdigit-atpt 'xdigit-backslash-atpt)
;;;###autoload
(defun xdigit-backslash-atpt (&optional arg ispec) 
  "Backslash 'xdigit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-backslash 'xdigit arg ispec)) 

(defalias 'brace-xdigit-atpt 'xdigit-brace-atpt)
;;;###autoload
(defun xdigit-brace-atpt (&optional arg ispec) 
  "Braces 'xdigit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-brace 'xdigit arg ispec))

(defalias 'bracket-xdigit-atpt 'xdigit-bracket-atpt)
;;;###autoload
(defun xdigit-bracket-atpt (&optional arg ispec) 
  "Brackets 'xdigit after point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-bracket 'xdigit arg ispec))

(defalias 'commented-xdigit-atpt 'xdigit-comment-atpt)
;;;###autoload
(defun xdigit-comment-atpt (&optional arg ispec) 
  "Comments 'xdigit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-comment 'xdigit arg ispec))

(defalias 'mark-xdigit-atpt 'xdigit-mark-atpt)
;;;###autoload
(defun xdigit-mark-atpt (&optional arg) 
  "Marks 'xdigit at point if any, does nothing otherwise "
  (interactive "p")
  (th-mark 'xdigit arg))

(defalias 'kill-xdigit-atpt 'xdigit-kill-atpt)
;;;###autoload
(defun xdigit-kill-atpt (arg)
  "Kills xdigit at point if any, does nothing otherwise "
  (interactive "*P")
  (th-kill 'xdigit arg))

(defalias 'parentize-xdigit-atpt 'xdigit-parentize-atpt)
;;;###autoload
(defun xdigit-parentize-atpt (&optional arg ispec) 
  "Parentizes 'xdigit at point if any, does nothing otherwise"
  (interactive "*P\np")
  (th-parentize 'xdigit arg ispec))

(defalias 'separate-xdigit-atpt 'xdigit-separate-atpt)
;;;###autoload
(defun xdigit-separate-atpt (&optional arg ispec) 
  "Separates 'xdigit at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*P\np")
  (th-separate 'xdigit arg ispec))

(defalias 'singlequote-xdigit-atpt 'xdigit-singlequote-atpt)
;;;###autoload
(defun xdigit-singlequote-atpt (&optional arg ispec) 
  "Singlequotes 'xdigit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-singlequote 'xdigit arg ispec))

(defalias 'slash-xdigit-atpt 'xdigit-slash-atpt)
;;;###autoload
(defun xdigit-slash-atpt (&optional arg ispec) 
  "Slash 'xdigit at point if any, does nothing otherwise "
  (interactive "*P\np")
  (th-slash 'xdigit arg ispec))

(defalias 'trim-xdigit-atpt 'xdigit-trim-atpt)
;;;###autoload
(defun xdigit-trim-atpt (&optional arg ispec) 
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'xdigit t t))

(defalias 'trim-xdigit-left-atpt 'xdigit-left-trim-atpt)
;;;###autoload
(defun xdigit-left-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'xdigit t nil))

(defalias 'trim-xdigit-right-atpt 'xdigit-right-trim-atpt)
;;;###autoload
(defun xdigit-right-trim-atpt (&optional arg ispec)
  "Removes leading and trailing char. "
  (interactive "*P\np")
  (th-trim 'xdigit nil t))

(defalias 'forward-xdigit-atpt 'xdigit-forward-atpt)
;;;###autoload
(defun xdigit-forward-atpt (&optional arg ispec) 
  "Moves forward over xdigit at point if any, does nothing otherwise "
  (interactive "P\np")
  (th-forward 'xdigit arg ispec))

(defalias 'backward-xdigit-atpt 'xdigit-backward-atpt)
;;;###autoload
(defun xdigit-backward-atpt (&optional arg ispec) 
  "Moves backward over xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (th-backward 'xdigit arg ispec))

(defalias 'transpose-xdigit-atpt 'xdigit-transpose-atpt)
;;;###autoload
(defun xdigit-transpose-atpt (&optional arg) 
  "Transposes xdigit with xdigit before point if any, does nothing otherwise "
  (interactive "*P")
  (th-transpose 'xdigit arg))

(defalias 'sort-xdigit-atpt 'xdigit-sort-atpt)
;;;###autoload
(defun xdigit-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts xdigit's in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let (reverse startkeyfun endkeyfun predicate)
    (th-sort 'xdigit reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'check-xdigit-atpt 'xdigit-check-atpt)
;;;###autoload
(defun xdigit-check-atpt (&optional arg ispec) 
  " xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "xdigit" "-beginning-position-atpt"))))
	(end (funcall (intern-soft (concat "xdigit" "-end-position-atpt")))))
    (th-check 'xdigit arg ispec)))
   
(provide 'thing-at-point-utils)
;;; thing-at-point-utils.el ends here
